@@ -80,8 +80,8 @@
 
 //---------------------------------------------------------
 #ifdef _SAGA_MSW
-	#define	_SAGA_DLL_EXPORT		__declspec( dllexport )
-	#define	_SAGA_DLL_IMPORT		__declspec( dllimport )
+	#define	_SAGA_DLL_EXPORT __declspec( dllexport )
+	#define	_SAGA_DLL_IMPORT __declspec( dllimport )
 #else
 	#define	_SAGA_DLL_EXPORT
 	#define	_SAGA_DLL_IMPORT
@@ -89,9 +89,9 @@
 
 //---------------------------------------------------------
 #ifdef _SAGA_API_EXPORTS
-	#define	SAGA_API_DLL_EXPORT		_SAGA_DLL_EXPORT
+	#define	SAGA_API_DLL_EXPORT _SAGA_DLL_EXPORT
 #else
-	#define	SAGA_API_DLL_EXPORT		_SAGA_DLL_IMPORT
+	#define	SAGA_API_DLL_EXPORT _SAGA_DLL_IMPORT
 #endif
 
 
@@ -962,7 +962,7 @@ protected:
 
 	void *					Get_Record_Pop	(void)
 	{
-		if( m_Stack.Get_Size() > 0 )
+		if( m_Stack.Get_Size() > 1 )
 		{
 			memcpy(m_Stack.Get_Array(), m_Stack.Get_Entry(m_Stack.Get_Size() - 1), m_Stack.Get_Value_Size());
 
@@ -1242,6 +1242,7 @@ SAGA_API_DLL_EXPORT CSG_String		SG_File_Get_Path_Absolute	(const CSG_String &ful
 SAGA_API_DLL_EXPORT CSG_String		SG_File_Get_Path_Relative	(const CSG_String &Directory, const CSG_String &full_Path);
 SAGA_API_DLL_EXPORT CSG_String		SG_File_Make_Path			(const CSG_String &Directory, const CSG_String &Name);
 SAGA_API_DLL_EXPORT CSG_String		SG_File_Make_Path			(const CSG_String &Directory, const CSG_String &Name, const CSG_String &Extension);
+SAGA_API_DLL_EXPORT bool			SG_File_Cmp_Path			(const CSG_String &Path1, const CSG_String &Path2);
 SAGA_API_DLL_EXPORT bool			SG_File_Cmp_Extension		(const CSG_String &FileName, const CSG_String &Extension);
 SAGA_API_DLL_EXPORT CSG_String		SG_File_Get_Extension		(const CSG_String &FileName);
 SAGA_API_DLL_EXPORT bool			SG_File_Set_Extension		(      CSG_String &FileName, const CSG_String &Extension);
@@ -1328,7 +1329,7 @@ enum ESG_Colors
 SAGA_API_DLL_EXPORT CSG_String		SG_Colors_Get_Name	(int Index);
 
 SAGA_API_DLL_EXPORT long			SG_Color_Get_Random	(void);
-
+SAGA_API_DLL_EXPORT long			SG_Color_From_RGB	(int Red, int Green, int Blue, int Alpha = 0);
 SAGA_API_DLL_EXPORT bool			SG_Color_From_Text	(const CSG_String &Text, long &Color);
 SAGA_API_DLL_EXPORT CSG_String		SG_Color_To_Text	(long Color, bool bHexadecimal = true);
 
