@@ -70,9 +70,10 @@
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-#define m_pStream_Base	((wxStreamBase   *)m_pStream)
-#define m_pStream_In	((wxInputStream  *)m_pStream)
-#define m_pStream_Out	((wxOutputStream *)m_pStream)
+#define m_pStream_Base ((wxStreamBase        *)m_pStream)
+#define m_pStream_I    ((wxFFileInputStream  *)m_pStream)
+#define m_pStream_O    ((wxFFileOutputStream *)m_pStream)
+#define m_pStream_IO   ((wxFFileStream       *)m_pStream)
 
 
 ///////////////////////////////////////////////////////////
@@ -111,28 +112,34 @@ bool CSG_File::Open(const CSG_String &FileName, int Mode, bool bBinary, int Enco
 {
 	Close();
 
+	CSG_String Path(SG_File_Get_Path(FileName));
+
+	if( !Path.is_Empty() && !SG_Dir_Exists(Path) )
+	{
+		return( false );
+	}
+
 	if( Mode == SG_FILE_R && !SG_File_Exists(FileName) )
 	{
 		return( false );
 	}
 
-	m_FileName	= FileName;
-	m_Mode		= Mode;
+	m_FileName = FileName; m_Mode = Mode;
 
 	Set_Encoding(Encoding);
 
 	switch( m_Mode )
 	{
 	case SG_FILE_W:
-		m_pStream	= new wxFFileOutputStream(FileName.c_str(), bBinary ? "wb" : "w");
+		m_pStream = new wxFFileOutputStream(FileName.c_str(), bBinary ? "wb" : "w");
 		break;
 
 	case SG_FILE_R:
-		m_pStream	= new wxFFileInputStream (FileName.c_str(), bBinary ? "rb" : "r");
+		m_pStream = new wxFFileInputStream (FileName.c_str(), bBinary ? "rb" : "r");
 		break;
 
 	default: // SG_FILE_RW
-		m_pStream	= new wxFFileStream      (FileName.c_str(), SG_File_Exists(FileName)
+		m_pStream = new wxFFileStream      (FileName.c_str(), SG_File_Exists(FileName)
 			? (bBinary ? "r+b" : "r+")
 			: (bBinary ? "w+b" : "w+")
 		);
@@ -156,7 +163,7 @@ bool CSG_File::Close(void)
 	{
 		delete(m_pStream_Base);
 
-		m_pStream	= NULL;
+		m_pStream = NULL;
 	}
 
 	Set_Encoding(SG_FILE_ENCODING_UNDEFINED);
@@ -224,7 +231,7 @@ sLong CSG_File::Length(void) const
 //---------------------------------------------------------
 bool CSG_File::is_EOF(void)	const
 {
-	return( is_Reading() && m_pStream_In->Eof() );
+	return( is_Reading() && (m_Mode == SG_FILE_R ? m_pStream_I->Eof() : m_pStream_IO->Eof()) );
 }
 
 //---------------------------------------------------------
@@ -232,14 +239,14 @@ bool CSG_File::Seek(sLong Offset, int Origin) const
 {
 	if( m_pStream )
 	{
-		wxSeekMode	Seek = Origin == SG_FILE_CURRENT ? wxFromCurrent : Origin == SG_FILE_END ? wxFromEnd : wxFromStart;
+		wxSeekMode Seek = Origin == SG_FILE_CURRENT ? wxFromCurrent : Origin == SG_FILE_END ? wxFromEnd : wxFromStart;
 
 		switch( m_Mode )
 		{
-		case SG_FILE_R : return( m_pStream_In ->SeekI(Offset, Seek) != wxInvalidOffset );
-		case SG_FILE_W : return( m_pStream_Out->SeekO(Offset, Seek) != wxInvalidOffset );
-		case SG_FILE_RW: return( m_pStream_In ->SeekI(Offset, Seek) != wxInvalidOffset
-							&&   m_pStream_Out->SeekO(Offset, Seek) != wxInvalidOffset );
+		case SG_FILE_R : return( m_pStream_I ->SeekI(Offset, Seek) != wxInvalidOffset );
+		case SG_FILE_W : return( m_pStream_O ->SeekO(Offset, Seek) != wxInvalidOffset );
+		default        : return( m_pStream_IO->SeekI(Offset, Seek) != wxInvalidOffset
+		                      && m_pStream_IO->SeekO(Offset, Seek) != wxInvalidOffset );
 		}
 	}
 
@@ -257,9 +264,9 @@ sLong CSG_File::Tell(void) const
 	{
 		switch( m_Mode )
 		{
-		case SG_FILE_R : return( m_pStream_In ->TellI() );
-		case SG_FILE_W : return( m_pStream_Out->TellO() );
-		case SG_FILE_RW: return( m_pStream_In ->TellI() );
+		case SG_FILE_R : return( m_pStream_I ->TellI() );
+		case SG_FILE_W : return( m_pStream_O ->TellO() );
+		default        : return( m_pStream_IO->TellI() );
 		}
 	}
 
@@ -320,8 +327,9 @@ int CSG_File::Printf(const wchar_t *Format, ...)
 //---------------------------------------------------------
 size_t CSG_File::Read(void *Buffer, size_t Size, size_t Count) const
 {
-	return( !is_Reading() || Size == 0 || Count == 0 ? 0 :
-		m_pStream_In->Read(Buffer, Size * Count).LastRead() / Size
+	return( !is_Reading() || Size == 0 || Count == 0 ? 0 : m_Mode == SG_FILE_R
+		? m_pStream_I ->Read(Buffer, Size * Count).LastRead() / Size
+		: m_pStream_IO->Read(Buffer, Size * Count).LastRead() / Size
 	);
 }
 
@@ -351,8 +359,9 @@ size_t CSG_File::Read(CSG_String &Buffer, size_t Size) const
 //---------------------------------------------------------
 size_t CSG_File::Write(void *Buffer, size_t Size, size_t Count) const
 {
-	return( !is_Writing() || Size == 0 || Count == 0 ? 0 :
-		m_pStream_Out->Write(Buffer, Size * Count).LastWrite()
+	return( !is_Writing() || Size == 0 || Count == 0 ? 0 : m_Mode == SG_FILE_W
+		? m_pStream_O ->Write(Buffer, Size * Count).LastWrite()
+		: m_pStream_IO->Write(Buffer, Size * Count).LastWrite()
 	);
 }
 
@@ -360,16 +369,16 @@ size_t CSG_File::Write(const CSG_String &Buffer) const
 {
 	if( m_pConvert )
 	{
-		wxString	_Buffer(Buffer.w_str());
+		wxString _Buffer(Buffer.w_str());
 
 		const wxScopedCharBuffer s(_Buffer.mb_str(*((wxMBConv *)m_pConvert)));
 
 		return( Write((void *)s.data(), sizeof(char), s.length()) );
 	}
 
-	CSG_Buffer	s(Buffer.to_ASCII());
+	CSG_Buffer s(Buffer.to_ASCII()); // returns NULL terminated char sequence, Get_Size() count includes terminating NULL!!!
 
-	return( Write((void *)s.Get_Data(), sizeof(char), s.Get_Size()) );
+	return( s.Get_Size() > 1 ? Write((void *)s.Get_Data(), sizeof(char), s.Get_Size() - 1) : 0 );
 }
 
 //---------------------------------------------------------
@@ -380,32 +389,46 @@ bool CSG_File::Read_Line(CSG_String &sLine)	const
 		return( false );
 	}
 
+	wxString s;
+
 	if( m_pConvert )
 	{
-		wxTextInputStream	Stream(*m_pStream_In, " \t", *((wxMBConv *)m_pConvert));
-
-		wxString	s(Stream.ReadLine());	sLine	= CSG_String(&s);
+		if( m_Mode == SG_FILE_R )
+		{
+			wxTextInputStream Stream(*m_pStream_I , " \t", *((wxMBConv *)m_pConvert)); s = Stream.ReadLine();
+		}
+		else
+		{
+			wxTextInputStream Stream(*m_pStream_IO, " \t", *((wxMBConv *)m_pConvert)); s = Stream.ReadLine();
+		}
 	}
 	else
 	{
-		wxTextInputStream	Stream(*m_pStream_In, " \t");
-
-		wxString	s(Stream.ReadLine());	sLine	= CSG_String(&s);
+		if( m_Mode == SG_FILE_R )
+		{
+			wxTextInputStream Stream(*m_pStream_I , " \t"                           ); s = Stream.ReadLine();
+		}
+		else
+		{
+			wxTextInputStream Stream(*m_pStream_IO, " \t"                           ); s = Stream.ReadLine();
+		}
 	}
 
+	sLine = CSG_String(&s);
+
 	return( !sLine.is_Empty() || !is_EOF() );
 }
 
 //---------------------------------------------------------
 int CSG_File::Read_Char(void) const
 {
-	return( !is_Reading() ? 0 : m_pStream_In->GetC() );
+	return( !is_Reading() ? 0 : m_Mode == SG_FILE_R ? m_pStream_I->GetC() : m_pStream_IO->GetC() );
 }
 
 //---------------------------------------------------------
 int CSG_File::Read_Int(bool bByteOrderBig) const
 {
-	int		Value	= 0;
+	int Value = 0;
 
 	if( Read(&Value, sizeof(Value)) == 1 )
 	{
@@ -431,7 +454,7 @@ bool CSG_File::Write_Int(int Value, bool bByteOrderBig)
 //---------------------------------------------------------
 double CSG_File::Read_Double(bool bByteOrderBig) const
 {
-	double	Value	= 0;
+	double Value = 0;
 
 	if( Read(&Value, sizeof(Value)) == 1 )
 	{
@@ -459,17 +482,15 @@ bool CSG_File::Scan(int &Value) const
 {
 	if( is_Reading() )
 	{
-		int		c;
-
-		while( !is_EOF() && isspace(c = Read_Char()) );	// remove leading white space
+		int c; while( !is_EOF() && isspace(c = Read_Char()) ); // remove leading white space
 
 		if( isdigit(c) || strchr("-+", c) )
 		{
-			CSG_String	s	= (char)c;
+			CSG_String s = (char)c;
 
 			while( !is_EOF() && isdigit(c = Read_Char()) )
 			{
-				s	+= (char)c;
+				s += (char)c;
 			}
 
 			return( s.asInt(Value) );
@@ -483,17 +504,15 @@ bool CSG_File::Scan(double &Value) const
 {
 	if( is_Reading() )
 	{
-		int		c;
-
-		while( !is_EOF() && isspace(c = Read_Char()) );	// remove leading white space
+		int c; while( !is_EOF() && isspace(c = Read_Char()) ); // remove leading white space
 
 		if( isdigit(c) || strchr("-+.,eE", c) )
 		{
-			CSG_String	s	= (char)c;
+			CSG_String s = (char)c;
 
 			while( !is_EOF() && (isdigit(c = Read_Char()) || strchr(".,eE", c) || strchr("", c)) )
 			{
-				s	+= (char)c;
+				s += (char)c;
 			}
 
 			return( s.asDouble(Value) );
@@ -509,11 +528,9 @@ bool CSG_File::Scan(CSG_String &Value, SG_Char Separator) const
 	{
 		Value.Clear();
 
-		int		c;
-
-		while( !is_EOF() && (c = Read_Char()) != Separator && c != EOF )
+		int c; while( !is_EOF() && (c = Read_Char()) != Separator && c != EOF )
 		{
-			Value	+= (char)c;
+			Value += (char)c;
 		}
 
 		return( true );
@@ -525,25 +542,17 @@ bool CSG_File::Scan(CSG_String &Value, SG_Char Separator) const
 //---------------------------------------------------------
 int CSG_File::Scan_Int(void) const
 {
-	int		Value;
-
-	return( Scan(Value) ? Value : 0 );
+	int    Value; return( Scan(Value) ? Value : 0   );
 }
 
 double CSG_File::Scan_Double(void) const
 {
-	double	Value;
-
-	return( Scan(Value) ? Value : 0.0 );
+	double Value; return( Scan(Value) ? Value : 0.0 );
 }
 
 CSG_String CSG_File::Scan_String(SG_Char Separator) const
 {
-	CSG_String	Value;
-
-	Scan(Value, Separator);
-
-	return( Value );
+	CSG_String Value; Scan(Value, Separator); return( Value );
 }
 
 
@@ -576,21 +585,31 @@ CSG_File_Zip::~CSG_File_Zip(void)
 //---------------------------------------------------------
 bool CSG_File_Zip::Open(const CSG_String &FileName, int Mode, int Encoding)
 {
-	wxLogNull	logNo;	// suppress user notification dialog for invalid zip files
-
 	Close();
 
-	m_Mode	= Mode;
+	CSG_String Path(SG_File_Get_Path(FileName));
 
-	Set_Encoding(Encoding);
+	if( !Path.is_Empty() && !SG_Dir_Exists(Path) )
+	{
+		return( false );
+	}
+
+	if( Mode == SG_FILE_R && !SG_File_Exists(FileName) )
+	{
+		return( false );
+	}
+
+	wxLogNull logNo; // suppress user notification dialog for invalid zip files
+
+	m_Mode = Mode; Set_Encoding(Encoding);
 
 	if( Mode == SG_FILE_W )
 	{
-		m_pStream	= new wxZipOutputStream(new wxFileOutputStream(FileName.c_str()));
+		m_pStream = new wxZipOutputStream(new wxFileOutputStream(FileName.c_str()));
 	}
 	else if( Mode == SG_FILE_R && SG_File_Exists(FileName) )
 	{
-		m_pStream	= new wxZipInputStream (new wxFileInputStream (FileName.c_str()));
+		m_pStream = new wxZipInputStream (new wxFileInputStream (FileName.c_str()));
 	}
 
 	if( !m_pStream || !m_pStream_Base->IsOk() )
@@ -602,11 +621,11 @@ bool CSG_File_Zip::Open(const CSG_String &FileName, int Mode, int Encoding)
 
 	if( is_Reading() )
 	{
-		wxZipEntry	*pEntry;
+		wxZipEntry *pEntry;
 
 		while( (pEntry = ((wxZipInputStream *)m_pStream)->GetNextEntry()) != NULL )
 		{
-			m_Files	+= pEntry;
+			m_Files += pEntry;
 		}
 	}
 
@@ -616,7 +635,7 @@ bool CSG_File_Zip::Open(const CSG_String &FileName, int Mode, int Encoding)
 //---------------------------------------------------------
 bool CSG_File_Zip::Close(void)
 {
-	for(size_t i=0; i<m_Files.Get_Size(); i++)
+	for(sLong i=0; i<m_Files.Get_Size(); i++)
 	{
 		delete((wxZipEntry *)m_Files[i]);
 	}
@@ -688,7 +707,7 @@ bool CSG_File_Zip::Get_File(const CSG_String &Name)
 {
 	if( is_Reading() )
 	{
-		for(size_t i=0; i<m_Files.Get_Size(); i++)
+		for(sLong i=0; i<m_Files.Get_Size(); i++)
 		{
 			if( !((wxZipEntry *)m_Files[i])->GetName().Cmp(Name.c_str()) )
 			{
@@ -727,14 +746,14 @@ bool			SG_Dir_Exists(const CSG_String &Directory)
 }
 
 //---------------------------------------------------------
-bool			SG_Dir_Create(const CSG_String &Directory)
+bool			SG_Dir_Create(const CSG_String &Directory, bool bFullPath)
 {
 	if( SG_Dir_Exists(Directory) )
 	{
 		return( true );
 	}
 
-	return( wxFileName::Mkdir(Directory.c_str()) );
+	return( wxFileName::Mkdir(Directory.c_str(), wxS_DIR_DEFAULT, bFullPath ? wxPATH_MKDIR_FULL : 0) );
 }
 
 //---------------------------------------------------------
@@ -921,6 +940,14 @@ CSG_String		SG_File_Make_Path(const CSG_String &Directory, const CSG_String &Nam
 	wxString s(fn.GetFullPath()); return( &s );
 }
 
+//---------------------------------------------------------
+bool			SG_File_Cmp_Path(const CSG_String &Path1, const CSG_String &Path2)
+{
+	wxFileName a(wxString(Path1.c_str())), b(wxString(Path2.c_str()));
+
+	return( a.SameAs(b) );
+}
+
 //---------------------------------------------------------
 bool			SG_File_Cmp_Extension(const CSG_String &FileName, const CSG_String &Extension)
 {
