@@ -266,11 +266,15 @@ bool CSG_Data_Object::m_Track = false; int CSG_Data_Object::m_Track_nObjects = 0
 //---------------------------------------------------------
 void CSG_Data_Object::Track(bool Track, bool Offset)
 {
+	#ifdef WITH_LIFETIME_TRACKER
 	m_Track = Track; m_Track_Offset = Offset ? m_Track_nObjects : 0;
 
 	SG_UI_Console_Print_StdOut(CSG_String::Format("data object construction/destruction tracker, state=%s, offset=%s, current object count is %d",
 		m_Track ? SG_T("ON") : SG_T("OFF"), m_Track_Offset ? SG_T("ON") : SG_T("OFF"), m_Track_nObjects
 	));
+	#else
+	SG_UI_Console_Print_StdOut("CSG_Data_Object::Track() functionality (aka data object lifetime tracker) has not been built for this configuration!");
+	#endif // WITH_LIFETIME_TRACKER
 }
 
 //---------------------------------------------------------
@@ -291,6 +295,8 @@ bool CSG_Data_Object::Destroy(void)
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
+void CSG_Data_Object::Set_Name(const char       *Name) { Set_Name(CSG_String(Name)); }
+void CSG_Data_Object::Set_Name(const wchar_t    *Name) { Set_Name(CSG_String(Name)); }
 void CSG_Data_Object::Set_Name(const CSG_String &Name)
 {
 	if( Name.is_Empty() )
@@ -752,7 +758,7 @@ bool CSG_Data_Object::Save_MetaData(CSG_File &Stream)
 		m_MetaData.Add_Child("DESCRIPTION", Get_Description());
 
 	//-----------------------------------------------------
-	if( m_Projection.Get_Type() == SG_PROJ_TYPE_CS_Undefined )
+	if( m_Projection.Get_Type() == ESG_CRS_Type::Undefined )
 		m_MetaData.Del_Child(SG_META_PROJECTION);
 	else if( m_MetaData(SG_META_PROJECTION) )
 		m_Projection.Save(*m_MetaData(SG_META_PROJECTION));
@@ -790,8 +796,8 @@ bool CSG_Data_Object::Assign(CSG_Data_Object *pObject)
 	{
 		Destroy();
 
-		m_Name = pObject->Get_Name();
-
+		m_Name         = pObject->Get_Name();
+		m_Projection   = pObject->m_Projection;
 		Get_MetaData() = pObject->Get_MetaData();
 	//	Get_History () = pObject->Get_History ();
 
