@@ -55,9 +55,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -70,9 +70,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -81,9 +81,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -91,9 +91,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -118,9 +118,9 @@ enum class TSG_Point_Type
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -256,7 +256,7 @@ private:
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -349,7 +349,7 @@ private:
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -410,7 +410,7 @@ public:
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -454,9 +454,9 @@ private:
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -478,24 +478,26 @@ public:
 
 	~CSG_Rect(void);
 
-	bool						operator ==		(const CSG_Rect &Rect) const;
-	bool						operator !=		(const CSG_Rect &Rect) const;
+	bool						Create			(double xMin, double yMin, double xMax, double yMax);
+	bool						Create			(const CSG_Point &A, const CSG_Point &B);
+	bool						Create			(const CSG_Rect &Rect);
 
-	CSG_Rect &					operator  =		(const CSG_Rect &Rect);
-	void						operator +=		(const CSG_Point &Point);
-	void						operator -=		(const CSG_Point &Point);
+	bool						operator ==		(const CSG_Rect &Rect) const { return(  is_Equal(Rect) ); }
+	bool						operator !=		(const CSG_Rect &Rect) const { return( !is_Equal(Rect) ); }
 
-	void						Assign			(double xMin, double yMin, double xMax, double yMax);
-	void						Assign			(const CSG_Point &A, const CSG_Point &B);
-	void						Assign			(const CSG_Rect &Rect);
+	CSG_Rect &					operator  =		(const CSG_Rect &Rect)   { Assign(Rect); return( *this ); }
 
-	void						Set_BottomLeft	(double x, double y);
-	void						Set_BottomLeft	(const CSG_Point &Point);
-	void						Set_TopRight	(double x, double y);
-	void						Set_TopRight	(const CSG_Point &Point);
+	CSG_Rect &					operator +=		(const CSG_Point &Point) { Move(  Point.x,  Point.y); return( *this ); }
+	CSG_Rect &					operator -=		(const CSG_Point &Point) { Move( -Point.x, -Point.y); return( *this ); }
 
-	bool						is_Equal		(double xMin, double yMin, double xMax, double yMax, double epsilon = 0.) const;
-	bool						is_Equal		(const CSG_Rect &Rect                              , double epsilon = 0.) const;
+	CSG_Rect &					Assign			(double xMin, double yMin, double xMax, double yMax);
+	CSG_Rect &					Assign			(const CSG_Point &A, const CSG_Point &B);
+	CSG_Rect &					Assign			(const CSG_Rect &Rect);
+
+	CSG_Rect &					Set_BottomLeft	(double x, double y);
+	CSG_Rect &					Set_BottomLeft	(const CSG_Point &Point);
+	CSG_Rect &					Set_TopRight	(double x, double y);
+	CSG_Rect &					Set_TopRight	(const CSG_Point &Point);
 
 	double						Get_XMin		(void) const	{	return( xMin );	}
 	double						Get_XMax		(void) const	{	return( xMax );	}
@@ -515,24 +517,27 @@ public:
 	double						Get_XCenter		(void) const	{	return( (xMin + xMax) / 2. );	}
 	double						Get_YCenter		(void) const	{	return( (yMin + yMax) / 2. );	}
 
-	void						Move			(double dx, double dy);
-	void						Move			(const CSG_Point &Point);
+	CSG_Rect &					Move			(double dx, double dy);
+	CSG_Rect &					Move			(const CSG_Point &Point);
 
-	void						Inflate			(double d, bool bPercent = true);
-	void						Deflate			(double d, bool bPercent = true);
-	void						Inflate			(double dx, double dy, bool bPercent = true);
-	void						Deflate			(double dx, double dy, bool bPercent = true);
+	CSG_Rect &					Inflate			(double d, bool bPercent = true);
+	CSG_Rect &					Deflate			(double d, bool bPercent = true);
+	CSG_Rect &					Inflate			(double dx, double dy, bool bPercent = true);
+	CSG_Rect &					Deflate			(double dx, double dy, bool bPercent = true);
 
-	void						Union			(double x, double y);
-	void						Union			(const CSG_Point &Point);
-	void						Union			(const CSG_Rect &Rect);
+	CSG_Rect &					Union			(double x, double y);
+	CSG_Rect &					Union			(const CSG_Point &Point);
+	CSG_Rect &					Union			(const CSG_Rect &Rect);
 	bool						Intersect		(const CSG_Rect &Rect);
 
-	TSG_Intersection			Intersects		(const CSG_Rect &Rect)		const;
+	bool						is_Equal		(double xMin, double yMin, double xMax, double yMax, double epsilon = 0.) const;
+	bool						is_Equal		(const CSG_Rect &Rect                              , double epsilon = 0.) const;
 
 	bool						Contains		(double x, double y)		const;
 	bool						Contains		(const CSG_Point &Point)	const;
 
+	TSG_Intersection			Intersects		(const CSG_Rect &Rect)		const;
+
 };
 
 //---------------------------------------------------------
@@ -568,7 +573,7 @@ private:
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -590,24 +595,26 @@ public:
 
 	~CSG_Rect_Int(void);
 
-	bool						operator ==		(const CSG_Rect_Int &Rect) const;
-	bool						operator !=		(const CSG_Rect_Int &Rect) const;
+	bool						Create			(int xMin, int yMin, int xMax, int yMax);
+	bool						Create			(const TSG_Point_Int &A, const TSG_Point_Int &B);
+	bool						Create			(const CSG_Rect_Int &Rect);
 
-	CSG_Rect_Int &				operator  =		(const CSG_Rect_Int &Rect);
-	void						operator +=		(const TSG_Point_Int &Point);
-	void						operator -=		(const TSG_Point_Int &Point);
+	bool						operator ==		(const CSG_Rect_Int &Rect) const { return(  is_Equal(Rect) ); }
+	bool						operator !=		(const CSG_Rect_Int &Rect) const { return( !is_Equal(Rect) ); }
 
-	void						Assign			(int xMin, int yMin, int xMax, int yMax);
-	void						Assign			(const TSG_Point_Int &A, const TSG_Point_Int &B);
-	void						Assign			(const CSG_Rect_Int &Rect);
+	CSG_Rect_Int &				operator  =		(const CSG_Rect_Int &Rect)   { Assign(Rect); return( *this ); }
 
-	void						Set_BottomLeft	(int x, int y);
-	void						Set_BottomLeft	(const TSG_Point_Int &Point);
-	void						Set_TopRight	(int x, int y);
-	void						Set_TopRight	(const TSG_Point_Int &Point);
+	CSG_Rect_Int &				operator +=		(const TSG_Point_Int &Point) { Move( Point.x,  Point.y); return( *this ); }
+	CSG_Rect_Int &				operator -=		(const TSG_Point_Int &Point) { Move(-Point.x, -Point.y); return( *this ); }
 
-	bool						is_Equal		(int xMin, int yMin, int xMax, int yMax) const;
-	bool						is_Equal		(const CSG_Rect_Int &Rect              ) const;
+	CSG_Rect_Int &				Assign			(int xMin, int yMin, int xMax, int yMax);
+	CSG_Rect_Int &				Assign			(const TSG_Point_Int &A, const TSG_Point_Int &B);
+	CSG_Rect_Int &				Assign			(const CSG_Rect_Int &Rect);
+
+	CSG_Rect_Int &				Set_BottomLeft	(int x, int y);
+	CSG_Rect_Int &				Set_BottomLeft	(const TSG_Point_Int &Point);
+	CSG_Rect_Int &				Set_TopRight	(int x, int y);
+	CSG_Rect_Int &				Set_TopRight	(const TSG_Point_Int &Point);
 
 	int							Get_XMin		(void) const	{	return( xMin );	}
 	int							Get_XMax		(void) const	{	return( xMax );	}
@@ -623,24 +630,27 @@ public:
 	TSG_Point_Int				Get_TopLeft		(void) const	{	TSG_Point_Int p; p.x = xMin; p.y = yMax; return( p );	}
 	TSG_Point_Int				Get_BottomRight	(void) const	{	TSG_Point_Int p; p.x = xMax; p.y = yMin; return( p );	}
 
-	void						Move			(int dx, int dy);
-	void						Move			(const TSG_Point_Int &Point);
+	CSG_Rect_Int &				Move			(int dx, int dy);
+	CSG_Rect_Int &				Move			(const TSG_Point_Int &Point);
 
-	void						Inflate			(int d);
-	void						Deflate			(int d);
-	void						Inflate			(int dx, int dy);
-	void						Deflate			(int dx, int dy);
+	CSG_Rect_Int &				Inflate			(int d);
+	CSG_Rect_Int &				Deflate			(int d);
+	CSG_Rect_Int &				Inflate			(int dx, int dy);
+	CSG_Rect_Int &				Deflate			(int dx, int dy);
 
-	void						Union			(int x, int y);
-	void						Union			(const TSG_Point_Int &Point);
-	void						Union			(const CSG_Rect_Int &Rect);
+	CSG_Rect_Int &				Union			(int x, int y);
+	CSG_Rect_Int &				Union			(const TSG_Point_Int &Point);
+	CSG_Rect_Int &				Union			(const CSG_Rect_Int &Rect);
 	bool						Intersect		(const CSG_Rect_Int &Rect);
 
-	TSG_Intersection			Intersects		(const CSG_Rect_Int &Rect)   const;
+	bool						is_Equal		(int xMin, int yMin, int xMax, int yMax) const;
+	bool						is_Equal		(const CSG_Rect_Int &Rect              ) const;
 
 	bool						Contains		(double x, double y)         const;
 	bool						Contains		(const TSG_Point_Int &Point) const;
 
+	TSG_Intersection			Intersects		(const CSG_Rect_Int &Rect)   const;
+
 };
 
 //---------------------------------------------------------
@@ -675,9 +685,9 @@ private:
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -692,7 +702,7 @@ TSG_Distance_Weighting;
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -760,72 +770,53 @@ private:
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-typedef enum
+enum class ESG_CRS_Format
 {
-	SG_PROJ_FMT_WKT,
-	SG_PROJ_FMT_Proj4,
-	SG_PROJ_FMT_EPSG,
-	SG_PROJ_FMT_Undefined
-}
-TSG_Projection_Format;
+	WKT1, WKT2, PROJ, ESRI, CODE, Undefined, WKT = WKT1
+};
 
 //---------------------------------------------------------
-typedef enum
+enum class ESG_CRS_Type
 {
-	SG_PROJ_TYPE_CS_Projected,
-	SG_PROJ_TYPE_CS_Geographic,
-	SG_PROJ_TYPE_CS_Geocentric,
-	SG_PROJ_TYPE_CS_Undefined
-}
-TSG_Projection_Type;
+	Geographic, Geocentric, Projection, Undefined
+};
 
 //---------------------------------------------------------
-typedef enum
+enum class ESG_Projection_Unit
 {
-	SG_PROJ_UNIT_Kilometer,
-	SG_PROJ_UNIT_Meter,
-	SG_PROJ_UNIT_Decimeter,
-	SG_PROJ_UNIT_Centimeter,
-	SG_PROJ_UNIT_Millimeter,
-	SG_PROJ_UNIT_Int_Nautical_Mile,
-	SG_PROJ_UNIT_Int_Inch,
-	SG_PROJ_UNIT_Int_Foot,
-	SG_PROJ_UNIT_Int_Yard,
-	SG_PROJ_UNIT_Int_Statute_Mile,
-	SG_PROJ_UNIT_Int_Fathom,
-	SG_PROJ_UNIT_Int_Chain,
-	SG_PROJ_UNIT_Int_Link,
-	SG_PROJ_UNIT_US_Inch,
-	SG_PROJ_UNIT_US_Foot,
-	SG_PROJ_UNIT_US_Yard,
-	SG_PROJ_UNIT_US_Chain,
-	SG_PROJ_UNIT_US_Statute_Mile,
-	SG_PROJ_UNIT_Indian_Yard,
-	SG_PROJ_UNIT_Indian_Foot,
-	SG_PROJ_UNIT_Indian_Chain,
-	SG_PROJ_UNIT_Undefined
-}
-TSG_Projection_Unit;
-
-//---------------------------------------------------------
-SAGA_API_DLL_EXPORT TSG_Projection_Type	SG_Get_Projection_Type				(const CSG_String &Identifier);
-SAGA_API_DLL_EXPORT CSG_String			SG_Get_Projection_Type_Identifier	(TSG_Projection_Type Type);
-SAGA_API_DLL_EXPORT CSG_String			SG_Get_Projection_Type_Name			(TSG_Projection_Type Type);
-
-SAGA_API_DLL_EXPORT TSG_Projection_Unit	SG_Get_Projection_Unit				(const CSG_String &Identifier);
-SAGA_API_DLL_EXPORT CSG_String			SG_Get_Projection_Unit_Identifier	(TSG_Projection_Unit Unit);
-SAGA_API_DLL_EXPORT CSG_String			SG_Get_Projection_Unit_Name			(TSG_Projection_Unit Unit, bool bSimple = false);
-SAGA_API_DLL_EXPORT double				SG_Get_Projection_Unit_To_Meter		(TSG_Projection_Unit Unit);
+	Kilometer,
+	Meter,
+	Decimeter,
+	Centimeter,
+	Millimeter,
+	Int_Nautical_Mile,
+	Int_Inch,
+	Int_Foot,
+	Int_Yard,
+	Int_Statute_Mile,
+	Int_Fathom,
+	Int_Chain,
+	Int_Link,
+	US_Inch,
+	US_Foot,
+	US_Yard,
+	US_Chain,
+	US_Statute_Mile,
+	Indian_Yard,
+	Indian_Foot,
+	Indian_Chain,
+	Undefined, First = Kilometer
+};
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -841,82 +832,94 @@ public:
 
 									CSG_Projection			(const CSG_Projection &Projection);
 	bool							Create					(const CSG_Projection &Projection);
-	bool							Assign					(const CSG_Projection &Projection);
-	CSG_Projection &				operator =				(const CSG_Projection &Projection)	{	Assign(Projection);	return( *this );	}
+	CSG_Projection &				operator =				(const CSG_Projection &Projection) { Create(Projection); return( *this ); }
 
-									CSG_Projection			(int Authority_ID, const SG_Char *Authority = NULL);
-	bool							Create					(int Authority_ID, const SG_Char *Authority = NULL);
-	bool							Assign					(int Authority_ID, const SG_Char *Authority = NULL);
-	CSG_Projection &				operator =				(int Authority_ID)					{	Assign(Authority_ID);	return( *this );	}
+									CSG_Projection			(const char       *Definition);
+	bool							Create					(const char       *Definition);
+	CSG_Projection &				operator =				(const char       *Definition)     { Create(Definition); return( *this ); }
 
-									CSG_Projection			(const CSG_String &Projection, TSG_Projection_Format Format = SG_PROJ_FMT_WKT);
-	bool							Create					(const CSG_String &Projection, TSG_Projection_Format Format = SG_PROJ_FMT_WKT);
-	bool							Assign					(const CSG_String &Projection, TSG_Projection_Format Format = SG_PROJ_FMT_WKT);
-	CSG_Projection &				operator =				(const CSG_String &Projection)		{	Assign(Projection);	return( *this );	}
+									CSG_Projection			(const wchar_t    *Definition);
+	bool							Create					(const wchar_t    *Definition);
+	CSG_Projection &				operator =				(const wchar_t    *Definition)     { Create(Definition); return( *this ); }
 
-									CSG_Projection			(const CSG_String &WKT, const CSG_String &Proj4);
-	bool							Create					(const CSG_String &WKT, const CSG_String &Proj4);
-	bool							Assign					(const CSG_String &WKT, const CSG_String &Proj4);
+									CSG_Projection			(const CSG_String &Definition);
+	bool							Create					(const CSG_String &Definition);
+	CSG_Projection &				operator =				(const CSG_String &Definition)     { Create(Definition); return( *this ); }
 
-	bool							is_Okay					(void)	const	{	return( m_Type != SG_PROJ_TYPE_CS_Undefined );	}
-	bool							is_Equal				(const CSG_Projection &Projection)	const;
-	bool							operator ==				(const CSG_Projection &Projection)	const	{	return( is_Equal(Projection) == true  );	}
-	bool							operator !=				(const CSG_Projection &Projection)	const	{	return( is_Equal(Projection) == false );	}
+									CSG_Projection			(int Code, const SG_Char *Authority = NULL);
+	bool							Create					(int Code, const SG_Char *Authority = NULL);
+	CSG_Projection &				operator =				(int Code)                         { Create(Code      ); return( *this ); }
 
+	bool							Assign					(const CSG_Projection &Projection)          { return( Create(Projection      ) ); }
+	bool							Assign					(const CSG_String &Definition)              { return( Create(Definition      ) ); }
+	bool							Assign					(int Code, const SG_Char *Authority = NULL) { return( Create(Code, Authority ) ); }
+
+	bool							is_Okay					(void)	const	{	return( m_Type != ESG_CRS_Type::Undefined );	}
+	bool							is_Equal				(const CSG_Projection &Projection) const;
+	bool							operator ==				(const CSG_Projection &Projection) const { return( is_Equal(Projection) == true  ); }
+	bool							operator !=				(const CSG_Projection &Projection) const { return( is_Equal(Projection) == false ); }
+
+	static const CSG_Projection &	Get_GCS_WGS84			(void);
 	bool							Set_GCS_WGS84			(void);
+
+	static CSG_Projection			Get_UTM_WGS84			(int Zone, bool bSouth = false);
 	bool							Set_UTM_WGS84			(int Zone, bool bSouth = false);
 
-	bool							Load					(const CSG_String &FileName, TSG_Projection_Format Format = SG_PROJ_FMT_WKT);
-	bool							Save					(const CSG_String &FileName, TSG_Projection_Format Format = SG_PROJ_FMT_WKT)	const;
+	bool							Load					(const CSG_String &File);
+	bool							Save					(const CSG_String &File, ESG_CRS_Format Format = ESG_CRS_Format::WKT) const;
 
-	bool							Load					(CSG_File &Stream, TSG_Projection_Format Format = SG_PROJ_FMT_WKT);
-	bool							Save					(CSG_File &Stream, TSG_Projection_Format Format = SG_PROJ_FMT_WKT)	const;
+	bool							Load					(CSG_File &Stream);
+	bool							Save					(CSG_File &Stream      , ESG_CRS_Format Format = ESG_CRS_Format::WKT) const;
 
 	bool							Load					(const CSG_MetaData &Projection);
-	bool							Save					(      CSG_MetaData &Projection)	const;
+	bool							Save					(      CSG_MetaData &Projection) const;
 
-	const CSG_String &				Get_Name				(void)	const	{	return( m_Name          );	}
-	const CSG_String &				Get_WKT					(void)	const	{	return( m_WKT           );	}
-	const CSG_String &				Get_Proj4				(void)	const	{	return( m_Proj4         );	}
-	const CSG_String &				Get_Authority			(void)	const	{	return( m_Authority     );	}
-	int								Get_Authority_ID		(void)	const	{	return( m_Authority_ID  );	}
-	int								Get_EPSG				(void)	const	{	return( m_Authority.Cmp("EPSG") ? -1 : m_Authority_ID );	}
+	CSG_String						Get_Description			(bool bDetails = false)	const;
 
-	CSG_String						Get_Description			(void)	const;
+	const CSG_String &				Get_Name				(void)	const	{	return( m_Name      );	}
 
-	TSG_Projection_Type				Get_Type				(void)	const	{	return( m_Type  );	}
-	CSG_String						Get_Type_Identifier		(void)	const	{	return( SG_Get_Projection_Type_Identifier(m_Type) );	}
-	CSG_String						Get_Type_Name			(void)	const	{	return( SG_Get_Projection_Type_Name      (m_Type) );	}
+	const CSG_String &				Get_WKT					(void)	const	{	return( m_WKT1      );	}
+	const CSG_String &				Get_WKT1				(void)	const	{	return( m_WKT1      );	}
+	const CSG_String &				Get_WKT2				(void)	const	{	return( m_WKT2      );	}
+	const CSG_String &				Get_PROJ				(void)	const	{	return( m_PROJ      );	}
+	const CSG_String &				Get_ESRI				(void)	const	{	return( m_ESRI      );	}
+	const CSG_String &				Get_Authority			(void)	const	{	return( m_Authority );	}
+	int								Get_Code				(void)	const	{	return( m_Code      );	}
 
-	bool							is_Projection			(void)	const	{	return( m_Type == SG_PROJ_TYPE_CS_Projected  );	}
-	bool							is_Geographic			(void)	const	{	return( m_Type == SG_PROJ_TYPE_CS_Geographic );	}
-	bool							is_Geocentric			(void)	const	{	return( m_Type == SG_PROJ_TYPE_CS_Geocentric );	}
+	const CSG_String &				Get_Proj4				(void)	const	{	return( m_PROJ      );	}
+	int								Get_Authority_ID		(void)	const	{	return( m_Code      );	}
+	int								Get_EPSG				(void)	const	{	return( m_Authority.CmpNoCase("EPSG") ? -1 : m_Code );	}
 
+	bool							is_Geographic			(void)	const	{	return( m_Type == ESG_CRS_Type::Geographic );	}
+	bool							is_Geocentric			(void)	const	{	return( m_Type == ESG_CRS_Type::Geocentric );	}
+	bool							is_Projection			(void)	const	{	return( m_Type == ESG_CRS_Type::Projection );	}
 
-	TSG_Projection_Unit				Get_Unit				(void)	const	{	return( m_Unit  );	}
-	CSG_String						Get_Unit_Identifier		(void)	const	{	return( SG_Get_Projection_Unit_Identifier(m_Unit) );	}
-	CSG_String						Get_Unit_Name			(void)	const	{	return( m_Unit_Name     );	}
-	double							Get_Unit_To_Meter		(void)	const	{	return( m_Unit_To_Meter );	}
+	ESG_CRS_Type					Get_Type				(void)	const	{	return( m_Type );	}
+	CSG_String						Get_Type_Identifier		(void)	const;
+	CSG_String						Get_Type_Name			(void)	const;
+
+	ESG_Projection_Unit				Get_Unit				(void)	const	{	return( m_Unit );	}
+	CSG_String						Get_Unit_Identifier		(void)	const;
+	CSG_String						Get_Unit_Name			(void)	const;
+	double							Get_Unit_To_Meter		(void)	const;
 
 
 private:
 
-	int								m_Authority_ID;
+	int								m_Code;
 
-	double							m_Unit_To_Meter;
+	ESG_CRS_Type					m_Type;
 
-	TSG_Projection_Type				m_Type;
+	ESG_Projection_Unit				m_Unit;
 
-	TSG_Projection_Unit				m_Unit;
-
-	CSG_String						m_Name, m_WKT, m_Proj4, m_Authority, m_Unit_Name;
+	CSG_String						m_Name, m_Authority, m_PROJ, m_WKT1, m_WKT2, m_ESRI;
 
 
 };
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -932,57 +935,59 @@ public:
 	CSG_Projections(void);
 	virtual ~CSG_Projections(void);
 
-									CSG_Projections			(bool bLoad_DB);
-	bool							Create					(bool bLoad_DB = true);
+									CSG_Projections			(bool LoadDefault);
+	bool							Create					(bool LoadDefault = true);
 
-									CSG_Projections			(const CSG_String &File_DB);
-	bool							Create					(const CSG_String &File_DB);
+									CSG_Projections			(const CSG_String &File);
+	bool							Create					(const CSG_String &File);
 
 	void							Destroy					(void);
 
-	bool							Reset_Dictionary		(void);
-	bool							Load_Dictionary			(const CSG_String &FileName);
-	bool							Save_Dictionary			(const CSG_String &FileName);
+	static bool						Parse					(const CSG_String &Definition, CSG_String *WKT1 = NULL, CSG_String *WKT2 = NULL, CSG_String *PROJ = NULL, CSG_String *ESRI = NULL);
 
-	bool							Load_DB					(const CSG_String &FileName, bool bAppend = false);
-	bool							Save_DB					(const CSG_String &FileName);
-
-	sLong							Get_Count				(void)	const;
+	bool							Load					(const CSG_String &File, bool bAppend = false);
+	bool							Save					(const CSG_String &File);
 
 	bool							Add						(const CSG_Projection &Projection);
 	bool							Add						(const SG_Char *WKT, const SG_Char *Proj4, const SG_Char *Authority, int Authority_ID);
 
-	CSG_Projection					Get_Projection			(sLong Index)	const;
+	sLong							Get_Count				(void)	const;
+
 	CSG_Projection					operator []				(sLong Index)	const	{	return( Get_Projection(Index) );	}
+	CSG_Projection					Get_Projection			(sLong Index)	const;
+	const SG_Char *					Get_Projection			(                            int Code, const SG_Char *Authority = NULL) const;
+	bool							Get_Projection			(CSG_Projection &Projection, int Code, const SG_Char *Authority = NULL) const;
 
-	bool							Get_Projection			(CSG_Projection &Projection,                              int EPSG_ID     )	const;
-	bool							Get_Projection			(CSG_Projection &Projection, const CSG_String &Authority, int Authority_ID)	const;
+	CSG_String						Get_Names_List			(ESG_CRS_Type Type = ESG_CRS_Type::Undefined, bool bAddSelect = true)	const;
 
-	CSG_String						Get_Names_List			(TSG_Projection_Type Type = SG_PROJ_TYPE_CS_Undefined)	const;
+	static ESG_CRS_Type				Get_CRS_Type			(const CSG_String &Identifier);
+	static CSG_String				Get_CRS_Type_Identifier	(ESG_CRS_Type Type);
+	static CSG_String				Get_CRS_Type_Name		(ESG_CRS_Type Type);
 
-	static CSG_MetaData				WKT_to_MetaData			(const CSG_String &WKT);
-
-	bool							WKT_to_Proj4			(CSG_String &Proj4, const CSG_String &WKT  )	const;
-	bool							WKT_from_Proj4			(CSG_String &WKT  , const CSG_String &Proj4)	const;
-
-	bool							EPSG_to_Proj4			(CSG_String &Proj4, int EPSG_Code)				const;
-	bool							EPSG_to_WKT				(CSG_String &WKT  , int EPSG_Code)				const;
-
-	static const CSG_Projection &	Get_GCS_WGS84			(void);
-	static CSG_Projection			Get_UTM_WGS84			(int Zone, bool bSouth = false);
+	static ESG_Projection_Unit		Get_Unit				(const CSG_String &Identifier);
+	static const CSG_String			Get_Unit_Identifier		(ESG_Projection_Unit Unit);
+	static const CSG_String			Get_Unit_Name			(ESG_Projection_Unit Unit, bool bSimple = true);
+	static double					Get_Unit_To_Meter		(ESG_Projection_Unit Unit);
 
 
 private:
 
-	CSG_Translator					m_WKT_to_Proj4, m_Proj4_to_WKT, m_EPSG_to_Idx;
-
 	class CSG_Table					*m_pProjections;
 
 
 	void							_On_Construction			(void);
 
+
+private:
+
+	CSG_Translator					m_WKT_to_Proj4, m_Proj4_to_WKT, m_EPSG_to_Idx;
+
+
+	static CSG_MetaData				_WKT_to_MetaData			(const CSG_String &WKT);
 	static bool						_WKT_to_MetaData			(CSG_MetaData &MetaData, const CSG_String &WKT);
 
+	bool							_WKT_to_Proj4				(CSG_String &Proj4, const CSG_String &WKT  )	const;
+	bool							_WKT_from_Proj4				(CSG_String &WKT  , const CSG_String &Proj4)	const;
 	bool							_WKT_to_Proj4_Set_Datum		(CSG_String &Proj4, const CSG_MetaData &WKT)	const;
 
 	static bool						_Proj4_Find_Parameter		(                   const CSG_String &Proj4, const CSG_String &Key);
@@ -992,28 +997,31 @@ private:
 	static bool						_Proj4_Get_Prime_Meridian	(CSG_String &Value, const CSG_String &Proj4);
 	static bool						_Proj4_Get_Unit				(CSG_String &Value, const CSG_String &Proj4);
 
-	bool							_Set_Dictionary				(CSG_Table      &Dictionary, int Direction);
-	bool							_Set_Dictionary				(CSG_Translator &Dictionary, int Direction);
+	bool							_EPSG_to_Proj4				(CSG_String &Proj4, int EPSG_Code)	const;
+	bool							_EPSG_to_WKT				(CSG_String &WKT  , int EPSG_Code)	const;
+
+	bool							_Set_Dictionary				(void);
+	bool							_Set_Dictionary				(CSG_Table &Dictionary, int Direction);
 
 };
 
 //---------------------------------------------------------
-SAGA_API_DLL_EXPORT CSG_Projections &	SG_Get_Projections	(void);
+SAGA_API_DLL_EXPORT CSG_Projections &	SG_Get_Projections		(void);
 
 //---------------------------------------------------------
-SAGA_API_DLL_EXPORT bool		SG_Get_Projected				(class CSG_Shapes *pSource, class CSG_Shapes *pTarget, const CSG_Projection &Target);
+SAGA_API_DLL_EXPORT bool				SG_Get_Projected		(class CSG_Shapes *pSource, class CSG_Shapes *pTarget, const CSG_Projection &Target);
 
-SAGA_API_DLL_EXPORT bool		SG_Get_Projected				(const CSG_Projection &Source, const CSG_Projection &Target, TSG_Point &Point    );
-SAGA_API_DLL_EXPORT bool		SG_Get_Projected				(const CSG_Projection &Source, const CSG_Projection &Target, TSG_Rect  &Rectangle);
+SAGA_API_DLL_EXPORT bool				SG_Get_Projected		(const CSG_Projection &Source, const CSG_Projection &Target, TSG_Point &Point    );
+SAGA_API_DLL_EXPORT bool				SG_Get_Projected		(const CSG_Projection &Source, const CSG_Projection &Target, TSG_Rect  &Rectangle);
 
 //---------------------------------------------------------
-SAGA_API_DLL_EXPORT bool		SG_Grid_Get_Geographic_Coordinates		(CSG_Grid *pGrid, CSG_Grid *pLon, CSG_Grid *pLat);
+SAGA_API_DLL_EXPORT bool				SG_Grid_Get_Geographic_Coordinates	(CSG_Grid *pGrid, CSG_Grid *pLon, CSG_Grid *pLat);
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Functions						 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1059,9 +1067,9 @@ SAGA_API_DLL_EXPORT double		SG_Get_Polygon_Area				(const CSG_Points &Points);
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
