@@ -53,9 +53,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -68,9 +68,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -78,9 +78,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -105,50 +105,48 @@ public:
 	void						Destroy				(void);
 
 	bool						Load				(const CSG_String &File, const SG_Char *Extension = NULL);
-	bool						Save				(const CSG_String &File, const SG_Char *Extension = NULL)	const;
+	bool						Save				(const CSG_String &File, const SG_Char *Extension = NULL) const;
 
 	bool						Load				(CSG_File &Stream);
-	bool						Save				(CSG_File &Stream)			const;
+	bool						Save				(CSG_File &Stream)       const;
 
 	bool						Load_HTTP			(const CSG_String &Server, const CSG_String &Path, const SG_Char *Username = NULL, const SG_Char *Password = NULL);
 
 	bool						from_XML			(const CSG_String &XML);
-	bool						to_XML				(      CSG_String &XML)		const;
-
-	bool						from_WKT			(const CSG_String &WKT);
-	bool						to_WKT				(      CSG_String &WKT)		const;
+	bool						to_XML				(      CSG_String &XML)  const;
 
 	bool						Load_JSON			(const CSG_String &File);
-	bool						Save_JSON			(const CSG_String &File)	const;
+	bool						Save_JSON			(const CSG_String &File) const;
 
 	bool						from_JSON			(const CSG_String &JSON);
-	bool						to_JSON				(      CSG_String &JSON)	const;
+	bool						to_JSON				(      CSG_String &JSON) const;
 
 	bool						Assign				(const CSG_MetaData &MetaData, bool bAddChildren = true);
 
-	CSG_MetaData &				operator  =			(const CSG_MetaData &MetaData)		{	Assign   (MetaData, true);	return( *this );	}
-	CSG_MetaData &				operator +=			(const CSG_MetaData &MetaData)		{	Add_Child(MetaData, true);	return( *this );	}
+	CSG_MetaData &				operator  =			(const CSG_MetaData &MetaData) { Assign   (MetaData, true);	return( *this ); }
+	CSG_MetaData &				operator +=			(const CSG_MetaData &MetaData) { Add_Child(MetaData, true);	return( *this ); }
 
-	const CSG_String &			Get_Name			(void)						const	{	return( m_Name );		}
-	void						Set_Name			(const CSG_String &Name)			{	m_Name		= Name;		}
-	bool						Cmp_Name			(const CSG_String &String, bool bNoCase =  true)	const;
-	const CSG_String &			Get_Content			(void)						const	{	return( m_Content );	}
-	const SG_Char *				Get_Content			(int Index)					const	{	return( Get_Child(Index) ? Get_Child(Index)->Get_Content().c_str() : NULL );	}
-	const SG_Char *				Get_Content			(const CSG_String &Name)	const	{	return( Get_Content(_Get_Child(Name)) );	}
+	void						Set_Name			(const CSG_String &Name) { m_Name = Name; }
+	bool						Cmp_Name			(const CSG_String &String, bool bNoCase =  true) const;
+	const CSG_String &			Get_Name			(void)                   const { return( m_Name ); }
+	const CSG_String &			Get_Content			(void)                   const { return( m_Content );	}
+	const SG_Char *				Get_Content			(int Index)              const { return( Get_Child(Index) ? Get_Child(Index)->Get_Content().c_str() : NULL );	}
+	const SG_Char *				Get_Content			(const CSG_String &Name) const;
 	bool						Get_Content			(const CSG_String &Name, CSG_String &Value)	const;
 	bool						Get_Content			(const CSG_String &Name, double     &Value)	const;
 	bool						Get_Content			(const CSG_String &Name, int        &Value)	const;
 	bool						Get_Content			(const CSG_String &Name, sLong      &Value)	const;
-	void						Set_Content			(const CSG_String &Content)			{	m_Content	= Content;	}
+	void						Set_Content			(const CSG_String &Content)        { m_Content = Content; }
 	void						Fmt_Content			(const char    *Format, ...);
 	void						Fmt_Content			(const wchar_t *Format, ...);
-	bool						Cmp_Content			(const CSG_String &String, bool bNoCase = false)	const;
+	bool						Cmp_Content			(const CSG_String &String, bool bNoCase = false) const;
 
-	CSG_MetaData *				Get_Parent			(void)						const	{	return( m_pParent );	}
+	CSG_MetaData *				Get_Parent			(void) const	{	return( m_pParent );	}
 
-	int							Get_Children_Count	(void)						const	{	return( (int)m_Children.Get_Size() );	}
-	CSG_MetaData *				Get_Child			(int Index)					const	{	return( Index >= 0 ? *((CSG_MetaData **)m_Children.Get_Entry((size_t)Index)) : NULL );	}
-	CSG_MetaData *				Get_Child			(const CSG_String &Name)	const	{	return( Get_Child(_Get_Child(Name)) );	}
+	int							Get_Count			(void) const                    { return( (int)m_Children.Get_Size() ); }
+	int							Get_Children_Count	(void) const                    { return( (int)m_Children.Get_Size() ); }
+	CSG_MetaData *				Get_Child			(int Index)              const	{ return( Index >= 0 ? *((CSG_MetaData **)m_Children.Get_Entry((size_t)Index)) : NULL ); }
+	CSG_MetaData *				Get_Child			(const CSG_String &Name) const;
 	CSG_MetaData *				Add_Child			(void);
 	CSG_MetaData *				Add_Child			(const CSG_String &Name);
 	CSG_MetaData *				Add_Child			(const CSG_String &Name, const CSG_String &Content);
@@ -165,25 +163,26 @@ public:
 	CSG_MetaData *				Ins_Child			(const CSG_MetaData &MetaData                     , int Position, bool bAddChildren = true);
 	bool						Mov_Child			(int from_Index, int to_Index);
 	bool						Del_Child			(int Index);
-	bool						Del_Child			(const CSG_String &Name)			{	return( Del_Child(_Get_Child(Name)) );	}
+	bool						Del_Child			(const CSG_String &Name);
 
 	bool						Add_Children		(const CSG_MetaData &MetaData);
 	bool						Del_Children		(int Depth = 0, const SG_Char *Name = NULL);
 
-	CSG_MetaData *				operator ()			(int Index)					const	{	return(  Get_Child(Index           ) );	}
-	CSG_MetaData *				operator ()			(const CSG_String &Name)	const	{	return(  Get_Child(_Get_Child(Name)) );	}
+	CSG_MetaData *				operator ()			(int Index             ) const { return(  Get_Child(Index) ); }
+	CSG_MetaData *				operator ()			(const CSG_String &Name) const { return(  Get_Child(Name ) ); }
+	CSG_MetaData &				operator []			(int Index             )       { return( *Get_Child(Index) ); }
+	CSG_MetaData &				operator []			(const CSG_String &Name)       { return( *Get_Child(Name ) ); }
+	const CSG_MetaData &		operator []			(int Index             ) const { return( *Get_Child(Index) ); }
+	const CSG_MetaData &		operator []			(const CSG_String &Name) const { return( *Get_Child(Name ) ); }
 
-	const CSG_MetaData &		operator []			(int Index)					const	{	return( *Get_Child(Index           ) );	}
-	const CSG_MetaData &		operator []			(const CSG_String &Name)	const	{	return( *Get_Child(_Get_Child(Name)) );	}
-
-	int							Get_Property_Count	(void)						const	{	return( m_Prop_Names.Get_Count() );	}
-	const CSG_String &			Get_Property_Name	(int i)						const	{	return( m_Prop_Names [i] );			}
-	const SG_Char *				Get_Property		(int i)						const	{	return( i >= 0 && i < m_Prop_Values.Get_Count() ? m_Prop_Values[i].c_str() : NULL );	}
-	const SG_Char *				Get_Property		(const CSG_String &Name)	const	{	return( Get_Property(_Get_Property(Name)) );	}
-	bool						Get_Property		(const CSG_String &Name, CSG_String &Value)	const;
-	bool						Get_Property		(const CSG_String &Name, double     &Value)	const;
-	bool						Get_Property		(const CSG_String &Name, int        &Value)	const;
-	bool						Get_Property		(const CSG_String &Name, sLong      &Value)	const;
+	int							Get_Property_Count	(void)                   const { return( m_Prop_Names.Get_Count() ); }
+	const CSG_String &			Get_Property_Name	(int Index)              const { return( m_Prop_Names[Index] ); }
+	const SG_Char *				Get_Property		(int Index)              const { return( Index >= 0 && Index < m_Prop_Values.Get_Count() ? m_Prop_Values[Index].c_str() : NULL ); }
+	const SG_Char *				Get_Property		(const CSG_String &Name) const { return( Get_Property(_Get_Property(Name)) ); }
+	bool						Get_Property		(const CSG_String &Name, CSG_String &Value) const;
+	bool						Get_Property		(const CSG_String &Name, double     &Value) const;
+	bool						Get_Property		(const CSG_String &Name, int        &Value) const;
+	bool						Get_Property		(const CSG_String &Name, sLong      &Value) const;
 	bool						Add_Property		(const CSG_String &Name, const CSG_String &Value);
 	bool						Add_Property		(const CSG_String &Name, double            Value);
 	bool						Add_Property		(const CSG_String &Name, int               Value);
@@ -192,7 +191,7 @@ public:
 	bool						Set_Property		(const CSG_String &Name, double            Value, bool bAddIfNotExists = true);
 	bool						Set_Property		(const CSG_String &Name, int               Value, bool bAddIfNotExists = true);
 	bool						Set_Property		(const CSG_String &Name, sLong             Value, bool bAddIfNotExists = true);
-	bool						Cmp_Property		(const CSG_String &Name, const CSG_String &String, bool bNoCase = false)	const;
+	bool						Cmp_Property		(const CSG_String &Name, const CSG_String &String, bool bNoCase = false) const;
 	bool						Del_Property		(const CSG_String &Name);
 	bool						Del_Property		(int i);
 
@@ -216,22 +215,19 @@ private:
 
 	void						_On_Construction	(void);
 
-	int							_Get_Child			(const CSG_String &Name)	const;
-	int							_Get_Property		(const CSG_String &Name)	const;
+	int							_Get_Child			(const CSG_String &Name) const;
+	int							_Get_Property		(const CSG_String &Name) const;
 
 	void						_Load				(class wxXmlNode *pNode);
-	void						_Save				(class wxXmlNode *pNode)	const;
-
-	bool						_Load_WKT			(const CSG_String &WKT);
-	bool						_Save_WKT			(      CSG_String &WKT)		const;
+	void						_Save				(class wxXmlNode *pNode) const;
 
 };
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -271,9 +267,9 @@ SAGA_API_DLL_EXPORT bool	SG_FTP_Download		(const CSG_String &Target_Directory, c
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
