@@ -51,12 +51,13 @@
 #include "parameters.h"
 #include "data_manager.h"
 #include "tool.h"
+#include "tool_library.h"
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -92,7 +93,7 @@ CSG_Parameter::~CSG_Parameter(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -115,7 +116,7 @@ CSG_Data_Manager * CSG_Parameter::Get_Manager(void)	const
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -132,7 +133,7 @@ CSG_String CSG_Parameter::Get_Type_Name(void)	const
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -188,7 +189,7 @@ void CSG_Parameter::ignore_Projection(bool bIgnore)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -539,7 +540,7 @@ TSG_Data_Object_Type CSG_Parameter::Get_DataObject_Type(void)	const
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -593,7 +594,7 @@ const SG_Char * CSG_Parameter::Get_Name(void)	const
 //---------------------------------------------------------
 bool CSG_Parameter::Set_Description(const CSG_String &Description)
 {
-	m_Description	= Description;
+	m_Description = Description;
 
 	return( true );
 }
@@ -653,7 +654,10 @@ CSG_String CSG_Parameter::Get_Description(int Flags, const SG_Char *Separator)	c
 
 		if( do_UseInGUI() != do_UseInCMD() )
 		{
-			s += CSG_String::Format(", %s", do_UseInGUI() ? SG_T("GUI") : SG_T("CMD"));
+			if( m_pParameters->has_GUI() || do_UseInGUI() )
+			{
+				s += CSG_String::Format("\n[%s]", do_UseInGUI() ? SG_T("GUI") : SG_T("CMD"));
+			}
 		}
 	}
 
@@ -671,8 +675,7 @@ CSG_String CSG_Parameter::Get_Description(int Flags, const SG_Char *Separator)	c
 		default:
 			break;
 
-		case PARAMETER_TYPE_Data_Type:
-		case PARAMETER_TYPE_Choice:
+		case PARAMETER_TYPE_Data_Type  :
 			SEPARATE; s += CSG_String::Format("%s:", _TL("Available Choices"));
 
 			for(int i=0; i<asChoice()->Get_Count(); i++)
@@ -681,16 +684,39 @@ CSG_String CSG_Parameter::Get_Description(int Flags, const SG_Char *Separator)	c
 			}
 			break;
 
-		case PARAMETER_TYPE_Choices:
-			SEPARATE; s += CSG_String::Format("%s:", _TL("Available Choices"));
-
-			for(int i=0; i<asChoices()->Get_Item_Count(); i++)
+		case PARAMETER_TYPE_Choice     :
+			if( do_UseInCMD() || asChoice()->Get_Count() < 32 )
 			{
-				s += CSG_String::Format("%s[%d] %s", Separator, i, asChoices()->Get_Item(i).c_str());
+				SEPARATE; s += CSG_String::Format("%s:", _TL("Available Choices"));
+
+				for(int i=0; i<asChoice()->Get_Count(); i++)
+				{
+					s += CSG_String::Format("%s[%d] %s", Separator, i, asChoice()->Get_Item(i));
+				}
+			}
+			else
+			{
+				SEPARATE; s += CSG_String::Format("%d %s:", asChoice()->Get_Count(), _TL("Choices"));
 			}
 			break;
 
-		case PARAMETER_TYPE_Int:
+		case PARAMETER_TYPE_Choices   :
+			if( do_UseInCMD() || asChoices()->Get_Item_Count() < 32 )
+			{
+				SEPARATE; s += CSG_String::Format("%s:", _TL("Available Choices"));
+
+				for(int i=0; i<asChoices()->Get_Item_Count(); i++)
+				{
+					s += CSG_String::Format("%s[%d] %s", Separator, i, asChoices()->Get_Item(i).c_str());
+				}
+			}
+			else
+			{
+				SEPARATE; s += CSG_String::Format("%d %s:", asChoices()->Get_Item_Count(), _TL("Choices"));
+			}
+			break;
+
+		case PARAMETER_TYPE_Int       :
 			if( asValue()->has_Minimum() )
 			{
 				SEPARATE; s += CSG_String::Format("%s: %d", _TL("Minimum"), (int)asValue()->Get_Minimum());
@@ -702,9 +728,9 @@ CSG_String CSG_Parameter::Get_Description(int Flags, const SG_Char *Separator)	c
 			}
 			break;
 
-		case PARAMETER_TYPE_Double:
-		case PARAMETER_TYPE_Degree:
-//		case PARAMETER_TYPE_Range:
+		case PARAMETER_TYPE_Double    :
+		case PARAMETER_TYPE_Degree    :
+//		case PARAMETER_TYPE_Range     :
 			if( asValue()->has_Minimum() )
 			{
 				SEPARATE; s += CSG_String::Format("%s: %f", _TL("Minimum"), asValue()->Get_Minimum());
@@ -717,7 +743,7 @@ CSG_String CSG_Parameter::Get_Description(int Flags, const SG_Char *Separator)	c
 			break;
 
 		case PARAMETER_TYPE_FixedTable:
-			SEPARATE;	s	+= CSG_String::Format("%d %s:%s", asTable()->Get_Field_Count(), _TL("Fields"), Separator);
+			SEPARATE; s += CSG_String::Format("%d %s:%s", asTable()->Get_Field_Count(), _TL("Fields"), Separator);
 
 			for(int i=0; i<asTable()->Get_Field_Count(); i++)
 			{
@@ -726,11 +752,16 @@ CSG_String CSG_Parameter::Get_Description(int Flags, const SG_Char *Separator)	c
 			break;
 
 		case PARAMETER_TYPE_Parameters:
-			SEPARATE; s += CSG_String::Format("%d %s:%s", asParameters()->Get_Count(), _TL("Parameters"), Separator);
+			SEPARATE; s += CSG_String::Format("%d %s", asParameters()->Get_Count(), _TL("Parameters"));
 
-			for(int i=0; i<asParameters()->Get_Count(); i++)
+			if( do_UseInCMD() )
 			{
-				s += CSG_String::Format("- %d. %s%s", i + 1, asParameters()->Get_Parameter(i)->Get_Description(Flags, Separator).c_str(), Separator);
+				s += CSG_String::Format(":%s", Separator);
+
+				for(int i=0; i<asParameters()->Get_Count(); i++)
+				{
+					s += CSG_String::Format("- %d. %s%s", i + 1, asParameters()->Get_Parameter(i)->Get_Description(Flags, Separator).c_str(), Separator);
+				}
 			}
 			break;
 		}
@@ -755,7 +786,7 @@ CSG_String CSG_Parameter::Get_Description(int Flags, const SG_Char *Separator)	c
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -867,7 +898,7 @@ void CSG_Parameter::_Set_String(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -914,7 +945,7 @@ bool CSG_Parameter::Restore_Default(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -991,7 +1022,7 @@ bool CSG_Parameter::Check(bool bSilent)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1091,7 +1122,7 @@ CSG_Parameter_PointCloud_List * CSG_Parameter::asPointCloudList(void) const {	re
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1103,7 +1134,7 @@ void CSG_Parameter::_Add_Child(CSG_Parameter *pChild)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1176,7 +1207,128 @@ bool CSG_Parameter::_Serialize(CSG_MetaData &Entry, bool bSave)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
+//         Coordinate System Reference Picker            //
+//                                                       //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+CSG_Parameters_CRSPicker::CSG_Parameters_CRSPicker(void)
+{
+	// nop...
+}
+
+//---------------------------------------------------------
+bool CSG_Parameters_CRSPicker::Create(CSG_Parameters &Parameters, const CSG_String &ParentID)
+{
+	m_pParameters = &Parameters;
+
+	Parameters.Add_String(ParentID, "CRS_STRING", _TL("Coordinate System Definition"),
+		_TL("Supported formats comprise PROJ and WKT strings, object codes (e.g. \"EPSG:4326\")."), ""
+	)->Set_UseInGUI(false);
+
+	return( true );
+}
+
+
+///////////////////////////////////////////////////////////
+//                                                       //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+bool CSG_Parameters_CRSPicker::Activate_GUI(bool bReset)
+{
+	if( !m_pParameters || !m_pParameters->has_GUI() || m_pCRS )
+	{
+		return( false );
+	}
+
+	m_pCRS = SG_Get_Tool_Library_Manager().Create_Tool("pj_proj4", 15, true); // CCRS_Picker
+
+	if( !m_pCRS )
+	{
+		return( false );
+	}
+
+	m_pCRS->Set_Parameter("CRS_STRING", (*m_pParameters)["CRS_STRING"].asString());
+
+	m_pParameters->Add_Parameters((*m_pParameters)("CRS_STRING")->Get_Parent(),
+		"CRS_PICKER", _TL("Coordinate Reference System"), _TL("")
+	)->asParameters()->Create(*m_pCRS->Get_Parameters());
+
+	return( true );
+}
+
+//---------------------------------------------------------
+bool CSG_Parameters_CRSPicker::Deactivate_GUI(void)
+{
+	if( m_pCRS )
+	{
+		m_pParameters->Del_Parameter("CRS_PICKER");
+
+		SG_Get_Tool_Library_Manager().Delete_Tool(m_pCRS);
+
+		m_pCRS = NULL;
+
+		return( true );
+	}
+
+	return( false );
+}
+
+
+///////////////////////////////////////////////////////////
+//                                                       //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+bool CSG_Parameters_CRSPicker::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
+{
+	if( pParameter->Cmp_Identifier("CRS_PICKER") )
+	{
+		pParameters->Set_Parameter("CRS_STRING", (*pParameter->asParameters())("CRS_WKT")->asString());
+	}
+
+	return( true );
+}
+
+//---------------------------------------------------------
+bool CSG_Parameters_CRSPicker::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
+{
+	return( true );
+}
+
+
+///////////////////////////////////////////////////////////
+//                                                       //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+bool CSG_Parameters_CRSPicker::Get_CRS(CSG_Projection &Projection, bool bMessage) const
+{
+	if( Projection.Create((*m_pParameters)["CRS_STRING"].asString()) )
+	{
+		if( bMessage )
+		{
+			SG_UI_Msg_Add_Execution(CSG_String::Format("\n%s: %s\n", _TL("CRS"), Projection.Get_PROJ().c_str()), false);
+		}
+
+		return( true );
+	}
+
+	if( bMessage )
+	{
+		SG_UI_Msg_Add_Execution(CSG_String::Format("\n%s: %s\n", _TL("Warning"), _TL("undefined coordinate reference system")), false);
+	}
+
+	return( false );
+}
+
+
+///////////////////////////////////////////////////////////
+//                                                       //
+//                Grid Target Selector                   //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1246,7 +1398,7 @@ bool CSG_Parameters_Grid_Target::Create(CSG_Parameters *pParameters, bool bAddDe
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1445,7 +1597,7 @@ bool CSG_Parameters_Grid_Target::On_Parameters_Enable(CSG_Parameters *pParameter
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1627,7 +1779,7 @@ bool CSG_Parameters_Grid_Target::Set_User_Defined_ZLevels(CSG_Parameters *pParam
 		zMax += 0.5 * Size;
 	}
 
-	bool	bCallback	= pParameters->Set_Callback(false);
+	bool bCallback = pParameters->Set_Callback(false);
 
 	pParameters->Set_Parameter(m_Prefix + "USER_ZSIZE", Size   );
 	pParameters->Set_Parameter(m_Prefix + "USER_ZMIN" , zMin   );
@@ -1641,7 +1793,7 @@ bool CSG_Parameters_Grid_Target::Set_User_Defined_ZLevels(CSG_Parameters *pParam
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1728,37 +1880,51 @@ bool CSG_Parameters_Grid_Target::Add_Grids(const CSG_String &Identifier, const C
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-CSG_Grid_System CSG_Parameters_Grid_Target::Get_System(void)
+CSG_Grid_System CSG_Parameters_Grid_Target::Get_System(void) const
+{
+	return( Get_System(m_pParameters) );
+}
+
+//---------------------------------------------------------
+CSG_Grid_System CSG_Parameters_Grid_Target::Get_System(CSG_Parameters *pParameters) const
 {
 	CSG_Grid_System System;
 
-	if( m_pParameters )
+	if( pParameters && (*pParameters)(m_Prefix + "DEFINITION") )
 	{
-		if( (*m_pParameters)(m_Prefix + "DEFINITION")->asInt() == 0 )	// user defined
+		if( (*pParameters)(m_Prefix + "DEFINITION")->asInt() == 0 )	// user defined
 		{
-			double Size = (*m_pParameters)(m_Prefix + "USER_SIZE")->asDouble();
-
-			CSG_Rect r(
-				(*m_pParameters)(m_Prefix + "USER_XMIN")->asDouble(),
-				(*m_pParameters)(m_Prefix + "USER_YMIN")->asDouble(),
-				(*m_pParameters)(m_Prefix + "USER_XMAX")->asDouble(),
-				(*m_pParameters)(m_Prefix + "USER_YMAX")->asDouble()
-			);
-
-			if( (*m_pParameters)(m_Prefix + "USER_FITS")->asInt() == 1 )
+			if( (*pParameters)(m_Prefix + "USER_SIZE")
+			&&  (*pParameters)(m_Prefix + "USER_XMIN")
+			&&  (*pParameters)(m_Prefix + "USER_YMIN")
+			&&  (*pParameters)(m_Prefix + "USER_XMAX")
+			&&  (*pParameters)(m_Prefix + "USER_YMAX")
+			&&  (*pParameters)(m_Prefix + "USER_FITS") )
 			{
-				r.Deflate(0.5 * Size, false);
-			}
+				double Size = (*pParameters)(m_Prefix + "USER_SIZE")->asDouble();
 
-			System.Assign(Size, r);
+				CSG_Rect r(
+					(*pParameters)(m_Prefix + "USER_XMIN")->asDouble(),
+					(*pParameters)(m_Prefix + "USER_YMIN")->asDouble(),
+					(*pParameters)(m_Prefix + "USER_XMAX")->asDouble(),
+					(*pParameters)(m_Prefix + "USER_YMAX")->asDouble()
+				);
+
+				if( (*pParameters)(m_Prefix + "USER_FITS")->asInt() == 1 )
+				{
+					r.Deflate(0.5 * Size, false);
+				}
+
+				System.Assign(Size, r);
+			}
 		}
-		else
+		else if( (*pParameters)(m_Prefix + "SYSTEM") )
 		{
-			CSG_Parameter *pParameter = (*m_pParameters)(m_Prefix + "SYSTEM");
+			CSG_Parameter *pParameter = (*pParameters)(m_Prefix + "SYSTEM");
 
 			if( pParameter->asGrid_System() )
 			{
@@ -1833,7 +1999,7 @@ CSG_Grid * CSG_Parameters_Grid_Target::Get_Grid(const CSG_String &Identifier, TS
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1866,10 +2032,10 @@ CSG_Grids * CSG_Parameters_Grid_Target::Get_Grids(const CSG_String &Identifier,
 
 	CSG_Grids *pGrids = NULL;
 
-	if( (*m_pParameters)(m_Prefix + "DEFINITION")->asInt() == 0
-	&&  (*m_pParameters)(Identifier + "_CREATE") )
+	if( (*m_pParameters)(m_Prefix + "DEFINITION")->asInt() == 0 && m_pParameters->Get_Tool()->has_GUI() )
 	{
-		if( (*m_pParameters)(Identifier + "_CREATE")->asBool() )
+		if( (*m_pParameters)(Identifier + "_CREATE") == NULL
+		||  (*m_pParameters)(Identifier + "_CREATE")->asBool() )
 		{
 			pGrids = SG_Create_Grids(System, 0, 0., Type);
 		}
@@ -1882,6 +2048,10 @@ CSG_Grids * CSG_Parameters_Grid_Target::Get_Grids(const CSG_String &Identifier,
 		{
 			pGrids = SG_Create_Grids(System, 0, 0., Type);
 		}
+		else if( pGrids && (pGrids->Get_Type() != Type || !pGrids->Get_System().is_Equal(System)) )
+		{
+			pGrids->Create(System, 0, 0., Type);
+		}
 	}
 
 	if( pGrids && pGrids != pParameter->asGrids() )
@@ -1889,6 +2059,7 @@ CSG_Grids * CSG_Parameters_Grid_Target::Get_Grids(const CSG_String &Identifier,
 		pParameter->Set_Value(pGrids);
 	}
 
+	//-----------------------------------------------------
 	if( pGrids
 	&&  (*m_pParameters)(m_Prefix + "USER_ZSIZE")
 	&&  (*m_pParameters)(m_Prefix + "USER_ZMIN" )
@@ -1917,9 +2088,9 @@ CSG_Grids * CSG_Parameters_Grid_Target::Get_Grids(TSG_Data_Type Type)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
