@@ -228,9 +228,19 @@ bool CSG_Projection::Load(const CSG_String &FileName)
 //---------------------------------------------------------
 bool CSG_Projection::Save(const CSG_String &FileName, ESG_CRS_Format Format) const
 {
-	CSG_File Stream(FileName, SG_FILE_W, false);
+	if( is_Okay() )
+	{
+		CSG_File Stream(FileName, SG_FILE_W, false);
 
-	return( is_Okay() && Save(Stream, Format) );
+		return( Save(Stream, Format) );
+	}
+
+	if( SG_File_Exists(FileName) )
+	{
+		SG_File_Delete(FileName);
+	}
+
+	return( false );
 }
 
 //---------------------------------------------------------
@@ -578,12 +588,21 @@ bool CSG_Projection::Set_UTM_WGS84(int Zone, bool bSouth)
 	}
 
 	//-----------------------------------------------------
-	#define WKT_GCS_WGS84 "GEOGCS[\"WGS 84\",AUTHORITY[\"EPSG\",\"4326\"]],"\
+	#define WKT1_GCS_WGS84 "GEOGCS[\"WGS 84\",AUTHORITY[\"EPSG\",\"4326\"]],"\
 		"DATUM[\"WGS_1984\",AUTHORITY[\"EPSG\",\"6326\"]],"\
 			"SPHEROID[\"WGS 84\",6378137,298.257223563,AUTHORITY[\"EPSG\",\"7030\"]],"\
 		"PRIMEM[\"Greenwich\",0,AUTHORITY[\"EPSG\",\"8901\"]],"\
 		"UNIT[\"degree\",0.0174532925199433,AUTHORITY[\"EPSG\",\"9122\"]]"
 
+	#define WKT2_GCS_WGS84 "GEODCRS[\"WGS 84\","\
+		"DATUM[\"World Geodetic System 1984\","\
+			"ELLIPSOID[\"WGS 84\",6378137,298.257223563]],"\
+		"CS[ellipsoidal,2],"\
+			"AXIS[\"geodetic longitude (Lon)\",east],"\
+			"AXIS[\"geodetic latitude (Lat)\",north],"\
+			"UNIT[\"degree\",0.0174532925199433],"\
+		"ID[\"EPSG\",4326]]"
+
 	CSG_String WKT;
 
 	WKT.Printf("PROJCS[\"WGS 84 / UTM zone %d%c\",%s"						// Zone, N/S, Datum
@@ -596,7 +615,7 @@ bool CSG_Projection::Set_UTM_WGS84(int Zone, bool bSouth)
 			"AXIS[\"Easting\",EAST],"
 			"AXIS[\"Northing\",NORTH],"
 			"UNIT[\"metre\",1,AUTHORITY[\"EPSG\",\"9001\"]]",
-		Zone, bSouth ? 'S' : 'N', CSG_String(WKT_GCS_WGS84).c_str(), EPSG_ID, 6 * (Zone - 1) - 177, bSouth ? 10000000 : 0
+		Zone, bSouth ? 'S' : 'N', CSG_String(WKT2_GCS_WGS84).c_str(), EPSG_ID, 6 * (Zone - 1) - 177, bSouth ? 10000000 : 0
 	);
 
 	return( Create(WKT) );
@@ -844,6 +863,11 @@ bool CSG_Projections::Save(const CSG_String &File)
 //---------------------------------------------------------
 bool CSG_Projections::Parse(const CSG_String &Definition, CSG_String *WKT1, CSG_String *WKT2, CSG_String *PROJ, CSG_String *ESRI)
 {
+	if( Definition.is_Empty() )
+	{
+		return( false );
+	}
+
 	CSG_Tool *pTool = SG_Get_Tool_Library_Manager().Create_Tool("pj_proj4", 19); // Coordinate Reference System Format Conversion
 
 	if( pTool )
@@ -870,7 +894,7 @@ bool CSG_Projections::Parse(const CSG_String &Definition, CSG_String *WKT1, CSG_
 	}
 
 	//-----------------------------------------------------
-	else if( !Definition.is_Empty() ) // proj.lib parser not available ...fallback!
+	else // proj.lib parser not available ...fallback!
 	{
 		if( Definition.Find("+proj") == 0 )
 		{
