@@ -90,6 +90,101 @@ bool CSG_Shapes::On_Delete(void)
 }
 
 
+///////////////////////////////////////////////////////////
+//														 //
+//														 //
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+static TSG_Shape_File_Format	gSG_Shape_File_Format_Default	= SHAPE_FILE_FORMAT_ESRI;
+
+//---------------------------------------------------------
+bool					SG_Shapes_Set_File_Format_Default	(int Format)
+{
+	switch( Format )
+	{
+	case SHAPE_FILE_FORMAT_ESRI      :
+	case SHAPE_FILE_FORMAT_GeoPackage:
+	case SHAPE_FILE_FORMAT_GeoJSON   :
+		gSG_Shape_File_Format_Default	= (TSG_Shape_File_Format)Format;
+		return( true );
+	}
+
+	return( false );
+}
+
+//---------------------------------------------------------
+TSG_Shape_File_Format	SG_Shapes_Get_File_Format_Default	(void)
+{
+	return( gSG_Shape_File_Format_Default );
+}
+
+//---------------------------------------------------------
+CSG_String				SG_Shapes_Get_File_Extension_Default	(void)
+{
+	switch( gSG_Shape_File_Format_Default )
+	{
+	default:
+	case SHAPE_FILE_FORMAT_ESRI      :	return( "shp"     );
+	case SHAPE_FILE_FORMAT_GeoPackage:	return( "gpkg"    );
+	case SHAPE_FILE_FORMAT_GeoJSON   :	return( "geojson" );
+	}
+}
+
+
+///////////////////////////////////////////////////////////
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+bool CSG_Shapes::Save(const CSG_String &File, int Format)
+{
+	if( Format == SHAPE_FILE_FORMAT_Undefined )
+	{
+		Format = gSG_Shape_File_Format_Default;
+
+		if( SG_File_Cmp_Extension(File, "shp"    ) ) { Format = SHAPE_FILE_FORMAT_ESRI      ; }
+		if( SG_File_Cmp_Extension(File, "gpkg"   ) ) { Format = SHAPE_FILE_FORMAT_GeoPackage; }
+		if( SG_File_Cmp_Extension(File, "geojson") ) { Format = SHAPE_FILE_FORMAT_GeoJSON   ; }
+
+		if( SG_File_Cmp_Extension(File, "txt"    ) ) { return( _Save_Text (File, true, '\t') ); }
+		if( SG_File_Cmp_Extension(File, "csv"    ) ) { return( _Save_Text (File, true,  ',') ); }
+		if( SG_File_Cmp_Extension(File, "dbf"    ) ) { return( _Save_DBase(File)             ); }
+	}
+
+	//-----------------------------------------------------
+	bool bResult = false;
+
+	SG_UI_Msg_Add(CSG_String::Format("%s %s: %s...", _TL("Saving"), _TL("shapes"), File.c_str()), true);
+
+	switch( Format )
+	{
+	case SHAPE_FILE_FORMAT_ESRI      : bResult = _Save_ESRI(File           ); break;
+	case SHAPE_FILE_FORMAT_GeoPackage: bResult = _Save_GDAL(File, "GPKG"   ); break;
+	case SHAPE_FILE_FORMAT_GeoJSON   : bResult = _Save_GDAL(File, "GeoJSON"); break;
+	}
+
+	//-----------------------------------------------------
+	if( bResult )
+	{
+		Set_Modified(false);
+
+		Set_File_Name(File, true);
+
+		SG_UI_Process_Set_Ready();
+		SG_UI_Msg_Add(_TL("okay"), false, SG_UI_MSG_STYLE_SUCCESS);
+
+		return( true );
+	}
+
+	SG_UI_Process_Set_Ready();
+	SG_UI_Msg_Add(_TL("failed"), false, SG_UI_MSG_STYLE_FAILURE);
+
+	return( false );
+}
+
+
 ///////////////////////////////////////////////////////////
 //														 //
 //														 //
@@ -99,13 +194,13 @@ bool CSG_Shapes::On_Delete(void)
 //---------------------------------------------------------
 bool CSG_Shapes::_Load_GDAL(const CSG_String &File_Name)
 {
-	CSG_Data_Manager	Data;
+	CSG_Data_Manager Manager;
 
-	CSG_Tool	*pTool	= SG_Get_Tool_Library_Manager().Create_Tool("io_gdal", 3);	// Import Shapes
+	CSG_Tool *pTool = SG_Get_Tool_Library_Manager().Create_Tool("io_gdal", 3);	// Import Shapes
 
 	if( pTool )
 	{
-		if( pTool->Settings_Push(&Data) && pTool->Set_Parameter("FILES", File_Name, PARAMETER_TYPE_FilePath) )
+		if( pTool->Settings_Push(&Manager) && pTool->Set_Parameter("FILES", File_Name, PARAMETER_TYPE_FilePath) )
 		{
 			SG_UI_Msg_Lock(true);
 			pTool->Execute();
@@ -116,15 +211,15 @@ bool CSG_Shapes::_Load_GDAL(const CSG_String &File_Name)
 	}
 
 	//-----------------------------------------------------
-	CSG_Shapes	*pShapes	= Data.Get_Shapes()->Count() ? Data.Get_Shapes()->Get(0)->asShapes() : NULL;
+	CSG_Shapes *pShapes = Manager.Shapes().Count() ? Manager.Shapes()[0].asShapes() : NULL;
 
 	if( !pShapes || !Create(*pShapes) )
 	{
 		return( false );
 	}
 
-	Get_MetaData  ()	= pShapes->Get_MetaData  ();
-	Get_Projection()	= pShapes->Get_Projection();
+	Get_MetaData  () = pShapes->Get_MetaData  ();
+	Get_Projection() = pShapes->Get_Projection();
 
 	//-----------------------------------------------------
 	if( SG_File_Cmp_Extension(File_Name, "gpkg"   )
@@ -143,7 +238,9 @@ bool CSG_Shapes::_Load_GDAL(const CSG_String &File_Name)
 //---------------------------------------------------------
 bool CSG_Shapes::_Save_GDAL(const CSG_String &File_Name, const CSG_String &Driver)
 {
-	bool	bResult;
+	bool bResult;
+
+	SG_UI_Msg_Lock(true);
 
 	SG_RUN_TOOL(bResult, "io_gdal", 4,	// Export Shapes
 		    SG_TOOL_PARAMETER_SET("SHAPES", this)
@@ -151,6 +248,8 @@ bool CSG_Shapes::_Save_GDAL(const CSG_String &File_Name, const CSG_String &Drive
 		&&	SG_TOOL_PARAMETER_SET("FILE"  , File_Name)
 	);
 
+	SG_UI_Msg_Lock(false);
+
 	return( bResult );
 }
 
@@ -452,7 +551,7 @@ bool CSG_Shapes::_Load_ESRI(const CSG_String &File_Name)
 	}
 
 	//-----------------------------------------------------
-	Get_Projection().Load(SG_File_Make_Path("", File_Name, "prj"), SG_PROJ_FMT_WKT);
+	Get_Projection().Load(SG_File_Make_Path("", File_Name, "prj"));
 
 	//-----------------------------------------------------
 	Load_MetaData(File_Name);
@@ -773,7 +872,7 @@ bool CSG_Shapes::_Save_ESRI(const CSG_String &File_Name)
 	fSHX.Write_Int(fSHX_Size, true);
 
 	//-----------------------------------------------------
-	Get_Projection().Save(SG_File_Make_Path("", File_Name, "prj"), SG_PROJ_FMT_WKT);
+	Get_Projection().Save(SG_File_Make_Path("", File_Name, "prj"));
 
 	//-----------------------------------------------------
 	CSG_MetaData	*pFields	= Get_MetaData_DB().Get_Child("FIELDS");
