@@ -800,14 +800,16 @@ bool CSG_Tool_Library_Manager::Create_Python_ToolBox(const CSG_String &Destinati
 	}
 
 	//-----------------------------------------------------
+	// skip tool chains in 1st run...
 	for(int iLibrary=0; iLibrary<Get_Count() && SG_UI_Process_Set_Progress(iLibrary, Get_Count()); iLibrary++)
 	{
 		CSG_Tool_Library *pLibrary = Get_Library(iLibrary);
 
 		if( !pLibrary->Get_Category    ().Cmp("SAGA Development" ) // generally exclude certain categories/libraries
 		||  !pLibrary->Get_Category    ().Cmp("Garden"           )
-		||  !pLibrary->Get_Library_Name().Cmp("vis_3d_viewer"    )
 		||  !pLibrary->Get_Library_Name().Cmp("grid_calculus_bsl")
+		||  !pLibrary->Get_Library_Name().Cmp("pj_geotrans"      )
+		||  !pLibrary->Get_Library_Name().Cmp("vis_3d_viewer"    )
 		||   pLibrary->Get_Type() == TOOL_CHAINS                 ) // exclude tool chains in 1st run
 		{
 			continue;
@@ -831,19 +833,25 @@ bool CSG_Tool_Library_Manager::Create_Python_ToolBox(const CSG_String &Destinati
 
 			if( pTool && pTool != TLB_INTERFACE_SKIP_TOOL && !pTool->needs_GUI() && !pTool->is_Interactive() && pTool->Get_Parameters_Count() == 0 )
 			{
-				Stream.Write(pTool->Get_Script(bName ? TOOL_SCRIPT_PYTHON_WRAP_NAME : TOOL_SCRIPT_PYTHON_WRAP_ID, false));
+				if( bName )
+				{
+					Stream.Write(pTool->Get_Script(TOOL_SCRIPT_PYTHON_WRAP_NAME, false));
+				}
+
+				Stream.Write(pTool->Get_Script(TOOL_SCRIPT_PYTHON_WRAP_ID, false));
 			}
 		}
 	}
 
 	//-----------------------------------------------------
+	// add tool chains in 2nd run...
 	for(int iLibrary=0; iLibrary<Get_Count() && SG_UI_Process_Set_Progress(iLibrary, Get_Count()); iLibrary++)
 	{
 		CSG_Tool_Library *pLibrary = Get_Library(iLibrary);
 
 		if( !pLibrary->Get_Category().Cmp("SAGA Development" ) // generally exclude certain categories
 		||  !pLibrary->Get_Category().Cmp("Garden"           )
-		||   pLibrary->Get_Type() != TOOL_CHAINS             ) // process tool chains in 2nd run
+		||   pLibrary->Get_Type() != TOOL_CHAINS             ) // only process tool chains in 2nd run
 		{
 			continue;
 		}
@@ -880,7 +888,12 @@ bool CSG_Tool_Library_Manager::Create_Python_ToolBox(const CSG_String &Destinati
 
 			if( pTool && pTool != TLB_INTERFACE_SKIP_TOOL && !pTool->needs_GUI() && !pTool->is_Interactive() && pTool->Get_Parameters_Count() == 0 )
 			{
-				Stream.Write(pTool->Get_Script(bName ? TOOL_SCRIPT_PYTHON_WRAP_NAME : TOOL_SCRIPT_PYTHON_WRAP_ID, false));
+				if( bName )
+				{
+					Stream.Write(pTool->Get_Script(TOOL_SCRIPT_PYTHON_WRAP_NAME, false));
+				}
+
+				Stream.Write(pTool->Get_Script(TOOL_SCRIPT_PYTHON_WRAP_ID, false));
 			}
 		}
 	}
