@@ -55,9 +55,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -72,9 +72,9 @@ enum
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -86,31 +86,56 @@ CSG_3DView_Canvas::CSG_3DView_Canvas(void)
 	m_bgColor     = SG_COLOR_WHITE;
 	m_bBox        = true;
 	m_BoxBuffer   = 0.01;
-	m_bStereo     = false;
-	m_dStereo     = 1.;
+	m_Stereo      = 0;
+	m_dStereo     = 10.;
 	m_North       = 1;
 	m_North_Size  = 15.;
 	m_Labels      = 0;
 	m_Label_Res   = 50;
 	m_Label_Scale = 1.;
+	m_Label_zType = SG_DATATYPE_Undefined; // number
 }
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-void CSG_3DView_Canvas::Set_Image(BYTE *pRGB, int NX, int NY)
+bool CSG_3DView_Canvas::Set_Image(wxImage &Image)
 {
-	m_Image_pRGB = pRGB;
+	if( Image.IsOk() && Image.GetWidth() > 0 && Image.GetHeight() > 0 )
+	{
+		m_Image_pRGB = Image.GetData  (); m_Image_pTwin = NULL;
+		m_Image_NX   = Image.GetWidth ();
+		m_Image_NY   = Image.GetHeight();
+		m_Image_zMax.Create   (m_Image_NX, m_Image_NY);
+		m_Projector.Set_Screen(m_Image_NX, m_Image_NY);
 
-	m_Image_NX   = NX;
-	m_Image_NY   = NY;
+		return( true );
+	}
 
-	m_Image_zMax.Create(m_Image_NX, m_Image_NY);
+	m_Image_pRGB = NULL; m_Image_pTwin = NULL;
+	m_Image_NX   = 0;
+	m_Image_NY   = 0;
+	m_Image_zMax.Destroy();
 
-	m_Projector.Set_Screen(m_Image_NX, m_Image_NY);
+	return( false );
+}
+
+//---------------------------------------------------------
+bool CSG_3DView_Canvas::Set_Image_Twin(wxImage &Image)
+{
+	if( Image.IsOk() && Image.GetWidth() == m_Image_NX && Image.GetHeight() == m_Image_NY )
+	{
+		m_Image_pTwin = Image.GetData();
+
+		return( true );
+	}
+
+	m_Image_pTwin = NULL;
+
+	return( false );
 }
 
 //---------------------------------------------------------
@@ -170,7 +195,7 @@ bool CSG_3DView_Canvas::Draw(void)
 	int Front = _Draw_Get_Box_Front();
 
 	//-----------------------------------------------------
-	if( m_bStereo == false )
+	if( m_Stereo == 0 || (m_Stereo == 2 && m_Image_pTwin == NULL) )
 	{
 		m_Color_Mode = COLOR_MODE_RGB;
 
@@ -178,7 +203,7 @@ bool CSG_3DView_Canvas::Draw(void)
 	}
 
 	//-----------------------------------------------------
-	else
+	else if( m_Stereo == 1 )
 	{
 		double rx = m_Projector.Get_xRotation();
 		double ry = m_Projector.Get_yRotation(), dy = cos(rx) * m_dStereo * M_DEG_TO_RAD / 2.;
@@ -205,6 +230,36 @@ bool CSG_3DView_Canvas::Draw(void)
 		m_Projector.Set_zRotation(rz);
 	}
 
+	//-----------------------------------------------------
+	else // if( m_Image_pTwin )
+	{
+		m_Color_Mode = COLOR_MODE_RGB;
+
+		double rx = m_Projector.Get_xRotation();
+		double ry = m_Projector.Get_yRotation(), dy = cos(rx) * m_dStereo * M_DEG_TO_RAD / 2.;
+		double rz = m_Projector.Get_zRotation(), dz = sin(rx) * m_dStereo * M_DEG_TO_RAD / 2.;
+
+		//-------------------------------------------------
+		m_Projector.Set_yRotation(ry - dy);
+		m_Projector.Set_zRotation(rz - dz);
+
+		m_Image_zMax.Assign(999999.); On_Draw(); _Draw_Box(); _Draw_Labels(Front); _Draw_North();
+
+		//-------------------------------------------------
+		m_Projector.Set_yRotation(ry + dy);
+		m_Projector.Set_zRotation(rz + dz);
+
+		BYTE *pRGB = m_Image_pRGB; m_Image_pRGB = m_Image_pTwin; _Draw_Background();
+		m_Image_zMax.Assign(999999.); On_Draw(); _Draw_Box(); _Draw_Labels(Front); _Draw_North();
+		m_Image_pRGB = pRGB;
+
+		//-------------------------------------------------
+		m_Projector.Set_yRotation(ry);
+		m_Projector.Set_zRotation(rz);
+	}
+
+	On_After_Draw();
+
 	bDrawing = false;
 
 	return( true );
@@ -212,7 +267,7 @@ bool CSG_3DView_Canvas::Draw(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -220,7 +275,7 @@ void CSG_3DView_Canvas::_Draw_Background(void)
 {
 	BYTE r, g, b;
 
-	if( m_bStereo )	// greyscale
+	if( m_Stereo == 1 ) // anaglyph => greyscale
 	{
 		r = g = b = (int)((SG_GET_R(m_bgColor) + SG_GET_G(m_bgColor) + SG_GET_B(m_bgColor)) / 3.);
 	}
@@ -247,7 +302,7 @@ void CSG_3DView_Canvas::_Draw_Background(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -319,7 +374,7 @@ void CSG_3DView_Canvas::_Draw_Box(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -398,7 +453,7 @@ void CSG_3DView_Canvas::_Draw_North(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -539,9 +594,18 @@ void CSG_3DView_Canvas::_Draw_Labels(int Axis, const TSG_Point_3D &A, const TSG_
 			continue;
 		}
 
-		double i = (Value - Min) / (Max - Min); CSG_Point_3D p(A.x + i * D.x, A.y + i * D.y, A.z + i * D.z);
+		double i = (Value - Min) / (Max - Min); CSG_Point_3D p(A.x + i * D.x, A.y + i * D.y, A.z + i * D.z); CSG_String s;
 
-		_Draw_Label(SG_Get_String(Value, -Decimals), p, Rx, Ry, Rz, Align, Resolution, Scale);
+		if( Axis == 2 && m_Label_zType == SG_DATATYPE_Date )
+		{
+			CSG_DateTime d(Value); s = d.Format_ISODate();
+		}
+		else
+		{
+			s = SG_Get_String(Value, -Decimals);
+		}
+
+		_Draw_Label(s, p, Rx, Ry, Rz, Align, Resolution, Scale);
 	}
 }
 
@@ -590,7 +654,7 @@ void CSG_3DView_Canvas::_Draw_Label(const CSG_String &Text, const TSG_Point_3D &
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -657,7 +721,7 @@ void CSG_3DView_Canvas::_Draw_Image(wxImage &Image, const CSG_Vector &Move, cons
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -772,7 +836,7 @@ inline void CSG_3DView_Canvas::_Draw_Pixel(int x, int y, double z, int color)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -802,7 +866,7 @@ void CSG_3DView_Canvas::Draw_Point(int x, int y, double z, int Color, int Size)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -924,7 +988,7 @@ void CSG_3DView_Canvas::Draw_Line(const TSG_Point_3D &a, const TSG_Point_3D &b,
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1160,7 +1224,7 @@ inline void CSG_3DView_Canvas::_Draw_Triangle_Line(int y, double a[], double b[]
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1244,9 +1308,9 @@ void CSG_3DView_Canvas::Draw_Polygon(CSG_Shape_Polygon &Polygon, int Color)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
