@@ -472,6 +472,32 @@ int CSG_3DView_Panel::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Para
 	return( 1 );
 }
 
+//---------------------------------------------------------
+CSG_Parameters & CSG_3DView_Panel::Get_Parameters(bool bUpdate)
+{
+	if( bUpdate )
+	{
+		Update_Parameters(true);
+	}
+
+	return( m_Parameters );
+}
+
+//---------------------------------------------------------
+bool CSG_3DView_Panel::Set_Parameters(CSG_Parameters *pParameters)
+{
+	if( pParameters )
+	{
+		m_Parameters.Assign_Values(pParameters);
+	}
+
+	Update_Parameters(false);
+	Update_Parent();
+	Update_View(true);
+
+	return( true );
+}
+
 //---------------------------------------------------------
 bool CSG_3DView_Panel::Parameters_Dialog(void)
 {
