@@ -250,11 +250,11 @@ void CParameters_Control::On_PG_Changed(wxPropertyGridEvent &event)
 //---------------------------------------------------------
 bool CParameters_Control::Save_Changes(bool bSilent)
 {
-	if( m_pOriginal && m_bModified && (bSilent || DLG_Message_Confirm(_TL("Save changes?"), wxString::Format(wxT("%s: %s"), _TL("Parameters"), m_pParameters->Get_Name().w_str()))) )
+	if( m_pOriginal && m_bModified && (bSilent || DLG_Message_Confirm(_TL("Save changes?"), wxString::Format("%s: %s", _TL("Parameters"), m_pParameters->Get_Name().w_str()))) )
 	{
 		m_pOriginal->Assign_Values(m_pParameters);
 
-		m_bModified	= false;
+		m_bModified = false;
 
 		m_pPG->ClearModifiedStatus();
 		m_pPG->Refresh();
@@ -335,6 +335,11 @@ bool CParameters_Control::Save(void)
 
 	if( DLG_Save(File_Path, ID_DLG_PARAMETERS_SAVE) )
 	{
+		if( !SG_File_Cmp_Extension(&File_Path, "sg-parameters") )
+		{
+			File_Path += ".sg-parameters";
+		}
+
 		if( m_pParameters->Serialize(&File_Path, true) )
 		{
 			return( true );
@@ -712,35 +717,36 @@ void CParameters_Control::_Set_Parameter(wxPGProperty *pProperty)
 		default:
 			break;
 
-		case PARAMETER_TYPE_Date:
-			pParameter->Set_Value(((wxDateProperty *)pProperty)->GetDateValue().GetJDN());
-			break;
-
-		case PARAMETER_TYPE_String:
+		case PARAMETER_TYPE_String  :
 		case PARAMETER_TYPE_FilePath:
 			pParameter->Set_Value(m_pPG->GetPropertyValueAsString(pProperty).wx_str());
 			break;
 
-		case PARAMETER_TYPE_Bool:
-			pParameter->Set_Value(m_pPG->GetPropertyValueAsBool(pProperty));
+		case PARAMETER_TYPE_Bool    :
+			pParameter->Set_Value(m_pPG->GetPropertyValueAsBool  (pProperty));
 			break;
 
-		case PARAMETER_TYPE_Int:
-			pParameter->Set_Value(m_pPG->GetPropertyValueAsInt(pProperty));
+		case PARAMETER_TYPE_Int     :
+			pParameter->Set_Value(m_pPG->GetPropertyValueAsInt   (pProperty));
 			break;
 
-		case PARAMETER_TYPE_Double:
+		case PARAMETER_TYPE_Double  :
 			pParameter->Set_Value(m_pPG->GetPropertyValueAsDouble(pProperty));
 			break;
 
-		case PARAMETER_TYPE_Color:
+		case PARAMETER_TYPE_Color   :
 			pParameter->Set_Value(Get_Color_asInt(((wxColourProperty *)pProperty)->GetVal().m_colour));
 			break;
+
+		case PARAMETER_TYPE_Date    :
+			pParameter->Set_Value(((wxDateProperty *)pProperty)->GetDateValue().GetJDN());
+			pParameter = NULL; // no further processing
+			break;
 		}
 
-		if( pParameter->Get_Type() != PARAMETER_TYPE_Date )
+		if( pParameter )
 		{
-			_Update_Parameters(pParameter);
+			_Update_Parameters();
 
 			m_pPG->SelectProperty(pProperty);
 		}
