@@ -221,14 +221,16 @@ bool DLG_Get_FILE_Filter_GDAL_Read(int Type, wxString &Filter)
 
 	if( Type == 2 )					// all recognized
 	{
-		ADD_FILTER("sprj"    );
-		ADD_FILTER("sg-pts"  );
-		ADD_FILTER("sg-pts-z");
-		ADD_FILTER("spc"     );
-		ADD_FILTER("las"     );
-		ADD_FILTER("txt"     );
-		ADD_FILTER("csv"     );
-		ADD_FILTER("dbf"     );
+		ADD_FILTER("sg-project");
+		ADD_FILTER("sprj"      );
+		ADD_FILTER("sg-pts"    );
+		ADD_FILTER("sg-pts-z"  );
+		ADD_FILTER("spc"       );
+		ADD_FILTER("las"       );
+		ADD_FILTER("laz"       );
+		ADD_FILTER("txt"       );
+		ADD_FILTER("csv"       );
+		ADD_FILTER("dbf"       );
 	}
 
 	return( bResult );
@@ -248,7 +250,7 @@ wxString DLG_Get_FILE_Filter(int ID_DLG)
 		return( wxString::Format(
 			"%s|%s|"
 			"%s (*.dll, *.so, *.xml)|*.dll;*.so;*.xml;*.dylib|"
-			"%s (*.sprj)|*.sprj|"
+			"%s (*.sg-project, *.sprj)|*.sg-project;*.sprj|"
 			"%s (*.sgrd, *.sg-grd-z)|*.sgrd;*.sg-grd;*.sg-grd-z;*.dgm;*.grd|"
 			"%s (*.sg-gds, *.sg-gds-z)|*.sg-gds;*.sg-gds-z|"
 			"%s (*.shp)|*.shp|"
@@ -281,9 +283,16 @@ wxString DLG_Get_FILE_Filter(int ID_DLG)
 
 	//-----------------------------------------------------
 	case ID_DLG_PROJECT_OPEN:
+		return( wxString::Format(
+			"%s (*.sg-project, *.sprj)|*.sg-project;*.sprj|"
+			"%s|*.*",
+			_TL("SAGA Projects"),
+			_TL("All Files")
+		));
+
 	case ID_DLG_PROJECT_SAVE:
 		return( wxString::Format(
-			"%s (*.sprj)|*.sprj|"
+			"%s (*.sg-project)|*.sg-project|"
 			"%s|*.*",
 			_TL("SAGA Projects"),
 			_TL("All Files")
@@ -502,9 +511,16 @@ wxString DLG_Get_FILE_Filter(int ID_DLG)
 
 	//-----------------------------------------------------
 	case ID_DLG_PARAMETERS_OPEN:
+		return( wxString::Format(
+			"%s (*.sg-parameters, *.sprm)|*.sg-parameters;*.sprm|"
+			"%s|*.*",
+			_TL("SAGA Parameter Files"),
+			_TL("All Files")
+		));
+
 	case ID_DLG_PARAMETERS_SAVE:
 		return( wxString::Format(
-			"%s (*.sprm)|*.sprm|"
+			"%s (*.sg-parameters)|*.sg-parameters|"
 			"%s|*.*",
 			_TL("SAGA Parameter Files"),
 			_TL("All Files")
@@ -1122,29 +1138,29 @@ bool		DLG_Open(wxArrayString &File_Paths, const wxString &Caption, const wxStrin
 //---------------------------------------------------------
 bool		DLG_Image_Save(wxString &File_Path, int &Type, const wxString &def_Dir, const wxString &def_File)
 {
-	static	int	Filter_Index	= 3;
+	static int Filter_Index = 0;
 
-	wxString	Dir(def_Dir);
+	wxString Dir(def_Dir);
 
 	if( !wxDirExists(def_Dir) )
 	{
 		CONFIG_Read(CONFIG_GROUP_FILE_DLG, DLG_Get_FILE_Config(-1), Dir);
 	}
 
-	wxFileDialog	dlg(
+	wxFileDialog dlg(
 		MDI_Get_Top_Window(), _TL("Save As Image"), Dir, def_File, wxString::Format(
-			"%s (*.bmp)|*.bmp|"
+			"%s (*.png)|*.png|"
 			"%s (*.jpg)|*.jpg;*.jif;*.jpeg|"
 			"%s (*.tif)|*.tif;*.tiff|"
-			"%s (*.png)|*.png|"
 			"%s (*.gif)|*.gif|"
+			"%s (*.bmp)|*.bmp|"
 			"%s (*.pcx)|*.pcx",
-			_TL("Windows or OS/2 Bitmap"),
-			_TL("JPEG - JFIF Compliant"),
-			_TL("Tagged Image File Format"),
-			_TL("Portable Network Graphics"),
-			_TL("CompuServe Graphics Interchange"),
-			_TL("Zsoft Paintbrush")
+			_TL("Portable Network Graphics"  ),
+			_TL("JPEG - JFIF Compliant"      ),
+			_TL("Tagged Image File Format"   ),
+			_TL("Graphics Interchange Format"),
+			_TL("Windows or OS/2 Bitmap"     ),
+			_TL("Zsoft Paintbrush"           )
 		), wxFD_SAVE|wxFD_OVERWRITE_PROMPT
 	);
 
@@ -1152,18 +1168,18 @@ bool		DLG_Image_Save(wxString &File_Path, int &Type, const wxString &def_Dir, co
 
 	if( dlg.ShowModal() == wxID_OK )
 	{
-		File_Path		= dlg.GetPath();
-		Filter_Index	= dlg.GetFilterIndex();
+		File_Path    = dlg.GetPath();
+		Filter_Index = dlg.GetFilterIndex();
 
 		switch( Filter_Index )
 		{
-		default: Type	= wxBITMAP_TYPE_BMP ;	break;
-		case  1: Type	= wxBITMAP_TYPE_JPEG;	break;
-		case  2: Type	= wxBITMAP_TYPE_TIF ;	break;
-		case  3: Type	= wxBITMAP_TYPE_PNG ;	break;
-		case  4: Type	= wxBITMAP_TYPE_GIF ;	break;
- 		case  5: Type	= wxBITMAP_TYPE_PCX ;	break;
-		case  6: Type	= wxBITMAP_TYPE_PNM ;	break;
+		default: Type = wxBITMAP_TYPE_PNG ; break;
+		case  1: Type = wxBITMAP_TYPE_JPEG; break;
+		case  2: Type = wxBITMAP_TYPE_TIF ; break;
+		case  3: Type = wxBITMAP_TYPE_GIF ; break;
+		case  4: Type = wxBITMAP_TYPE_BMP ; break;
+ 		case  5: Type = wxBITMAP_TYPE_PCX ; break;
+		case  6: Type = wxBITMAP_TYPE_PNM ; break;
 		}
 
 		if( !wxDirExists(def_Dir) )
