@@ -98,9 +98,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -120,9 +120,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -167,9 +167,9 @@ wxStatusBar * CSAGA_Frame::OnCreateStatusBar(int number, long style, wxWindowID
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -177,9 +177,9 @@ CSAGA_Frame *g_pSAGA_Frame = NULL;
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -245,9 +245,9 @@ END_EVENT_TABLE()
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -437,9 +437,9 @@ CSAGA_Frame::~CSAGA_Frame(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -495,9 +495,9 @@ void CSAGA_Frame::On_Size(wxSizeEvent &event)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -529,9 +529,9 @@ void CSAGA_Frame::On_Tips(wxCommandEvent &WXUNUSED(event))
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -587,7 +587,7 @@ void CSAGA_Frame::Split(int Arrange)
 		GetNotebook()->Freeze();
 
 		int iActive = GetNotebook()->GetSelection(); if( iActive < 0 ) iActive = 0;
-		int nSqrt   = (int)sqrt((double)n);
+	//	int nSqrt   = (int)sqrt((double)n);
 
 		switch( Arrange )
 		{
@@ -766,9 +766,9 @@ bool CSAGA_Frame::Arrange_Children(int Arrange)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -817,9 +817,9 @@ void CSAGA_Frame::On_INFO_Show_UI(wxUpdateUIEvent &event)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -867,9 +867,9 @@ void CSAGA_Frame::On_Command_Child_UI(wxUpdateUIEvent &event)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -904,9 +904,9 @@ void CSAGA_Frame::Show_Tips(bool bShow)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -985,9 +985,9 @@ void CSAGA_Frame::Set_Project_Name(wxString Project_Name)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1044,9 +1044,9 @@ wxWindow * CSAGA_Frame::Top_Window_Get(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1132,9 +1132,9 @@ CVIEW_Base * CSAGA_Frame::Get_Active_Child(int View_ID)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						MenuBar							 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1205,9 +1205,9 @@ wxMenuBar * CSAGA_Frame::_Create_MenuBar(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						ToolBar							 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1252,9 +1252,9 @@ void CSAGA_Frame::Add_Toolbar(wxToolBarBase *pToolBar, const wxString &Name)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1324,9 +1324,9 @@ void CSAGA_Frame::_Bar_Show(wxWindow *pWindow, bool bShow)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
