@@ -82,6 +82,7 @@
 
 #include "wksp_map_manager.h"
 
+#include "wksp_tool_manager.h"
 #include "wksp_tool.h"
 
 #include "active.h"
@@ -89,9 +90,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -99,9 +100,9 @@ CWKSP_Data_Manager	*g_pData	= NULL;
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -146,7 +147,7 @@ CWKSP_Data_Manager::CWKSP_Data_Manager(void)
 	m_Parameters.Add_Choice("NODE_PROJECT",
 		"PROJECT_MAP_ARRANGE", _TL("Map Window Arrangement"),
 		_TL("Initial map window arrangement after a project has been loaded."),
-		#ifdef _SAGA_MSW
+		#ifndef MDI_TABBED
 		CSG_String::Format("%s|%s|%s|%s|%s",
 			_TL("Cascade"),
 			_TL("Tile Horizontally"),
@@ -250,8 +251,8 @@ CWKSP_Data_Manager::CWKSP_Data_Manager(void)
 
 	m_Parameters.Add_Int("NODE_GRID",
 		"GRID_COORD_PRECISION"	, _TL("Coordinate Precision"),
-		_TL("Precision used to store coordinates and cell sizes (i.e. number of decimals)."),
-		10, 0, true
+		_TL("Precision used to store coordinates and cell sizes (i.e. number of decimals). Ignored if negative."),
+		10, -1, true
 	);
 
 	m_Parameters.Add_Int("NODE_GRID",
@@ -356,23 +357,23 @@ CWKSP_Data_Manager::~CWKSP_Data_Manager(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
 wxFileName Get_SAGA_GUI_CFG(void)
 {
 #ifdef _SAGA_LINUX
-//	wxFileName	fProject(wxString(getenv( "HOME"), wxConvFile ), wxT("saga_gui"), wxT("cfg"));
+//	wxFileName	fProject(wxString(getenv( "HOME"), wxConvFile ), wxT("saga_gui"), wxT("sg-project"));
 	CSG_String	sHome(getenv("HOME"));
-	wxFileName	fProject(sHome.c_str(), "saga_gui", "cfg");
+	wxFileName	fProject(sHome.c_str(), "saga_gui", "sg-project");
 #else
-	wxFileName	fProject(g_pSAGA->Get_App_Path(), "saga_gui", "cfg");
+	wxFileName	fProject(g_pSAGA->Get_App_Path(), "saga_gui", "sg-project");
 
 	if(	( fProject.FileExists() && (!fProject.IsFileReadable() || !fProject.IsFileWritable()))
 	||	(!fProject.FileExists() && (!fProject.IsDirReadable () || !fProject.IsDirWritable ())) )
 	{
-		fProject.Assign(wxGetHomeDir(), "saga_gui", "cfg");
+		fProject.Assign(wxGetHomeDir(), "saga_gui", "sg-project");
 	}
 #endif
 
@@ -385,11 +386,11 @@ wxFileName Get_SAGA_GUI_CFG(void)
 bool CWKSP_Data_Manager::Initialise(void)
 {
 	//-----------------------------------------------------
-	if( m_pProject->Has_File_Name() )	{	return( m_pProject->Load(false) );	}
+	if( m_pProject->Has_File_Name() ) { return( m_pProject->Load(false) ); }
 	//-----------------------------------------------------
 
 	//-----------------------------------------------------
-	wxFileName	fProject, fLastState	= Get_SAGA_GUI_CFG();
+	wxFileName fProject, fLastState = Get_SAGA_GUI_CFG();
 
 	switch( m_Parameters("PROJECT_START")->asInt() )
 	{
@@ -401,18 +402,18 @@ bool CWKSP_Data_Manager::Initialise(void)
 
 	case 2:	// always ask what to do
 		{
-			wxArrayString	Projects;
+			wxArrayString Projects;
 
 			Projects.Add(wxString::Format("[%s]", _TL("empty")));
 
-			if( fLastState.FileExists() )
+			if( fLastState.FileExists() && g_pTools->Get_Parameter("SAVE_CONFIG")->asBool() )
 			{
 				Projects.Add(wxString::Format("[%s]", _TL("last state")));
 			}
 
 			m_pMenu_Files->Recent_Get(SG_DATAOBJECT_TYPE_Undefined, Projects, true);
 
-			wxSingleChoiceDialog	dlg(MDI_Get_Top_Window(), _TL("Startup Project"), _TL("Select Startup Project"), Projects);
+			wxSingleChoiceDialog dlg(MDI_Get_Top_Window(), _TL("Startup Project"), _TL("Select Startup Project"), Projects);
 
 			if( Projects.Count() <= 1 || dlg.ShowModal() != wxID_OK || dlg.GetSelection() == 0 )
 			{	// empty
@@ -431,17 +432,15 @@ bool CWKSP_Data_Manager::Initialise(void)
 	}
 
 	//-----------------------------------------------------
-	//wxString	FileName	= Get_FilePath_Absolute(g_pSAGA->Get_App_Path(), fProject.GetFullPath());
-
 	return( false );
 }
 
 //---------------------------------------------------------
 bool CWKSP_Data_Manager::Finalise(void)
 {
-	wxFileName	fProject	= Get_SAGA_GUI_CFG();
+	wxFileName fProject = Get_SAGA_GUI_CFG();
 
-	if( Get_Count() > 0 )
+	if( Get_Count() > 0 && g_pTools->Get_Parameter("SAVE_CONFIG")->asBool() )
 	{	// last state
 		m_pProject->Save(fProject.GetFullPath(), false);
 
@@ -460,7 +459,7 @@ bool CWKSP_Data_Manager::Finalise(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -549,7 +548,7 @@ wxMenu * CWKSP_Data_Manager::Get_Menu(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -691,7 +690,7 @@ bool CWKSP_Data_Manager::On_Command_UI(wxUpdateUIEvent &event)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -745,7 +744,7 @@ void CWKSP_Data_Manager::Parameters_Changed(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -797,7 +796,7 @@ int CWKSP_Data_Manager::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Pa
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -863,7 +862,8 @@ bool CWKSP_Data_Manager::Open(const wxString &File)
 	}
 
 	//-----------------------------------------------------
-	if( SG_File_Cmp_Extension(&File, "sprj") )
+	if( SG_File_Cmp_Extension(&File, "sg-project")
+	||  SG_File_Cmp_Extension(&File, "sprj"      ) )
 	{
 		return( m_pProject->Load(File, false, true) );
 	}
@@ -908,12 +908,8 @@ bool CWKSP_Data_Manager::Open(const wxString &File)
 //---------------------------------------------------------
 bool CWKSP_Data_Manager::Open(int DataType)
 {
-	bool	bResult	= false;
+	int ID;
 
-	int				ID;
-	wxArrayString	Files;
-
-	//-----------------------------------------------------
 	switch( DataType )
 	{
 	case SG_DATAOBJECT_TYPE_Table     : ID = ID_DLG_TABLE_OPEN     ; break;
@@ -926,6 +922,8 @@ bool CWKSP_Data_Manager::Open(int DataType)
 	}
 
 	//-----------------------------------------------------
+	bool bResult = false; wxArrayString Files;
+
 	if( DLG_Open(Files, ID) )
 	{
 		MSG_General_Add_Line();
@@ -934,12 +932,12 @@ bool CWKSP_Data_Manager::Open(int DataType)
 		{
 			if( Open(Files[i], DataType) )
 			{
-				bResult	= true;
+				bResult = true;
 			}
 		}
 	}
 
-	return( true );
+	return( bResult );
 }
 
 //---------------------------------------------------------
@@ -950,7 +948,7 @@ bool CWKSP_Data_Manager::Open_CMD(int Cmd_ID)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1025,7 +1023,7 @@ bool CWKSP_Data_Manager::Open_Browser(wxArrayString &Projects, const wxString &D
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1107,8 +1105,6 @@ int CWKSP_Data_Manager::_Modified_Changed(CSG_Parameter *pParameter, int Flags)
 //---------------------------------------------------------
 bool CWKSP_Data_Manager::_Modified_Get(CSG_Parameters *pParameters, CWKSP_Base_Item *pItem, const wxString &Directory, bool bSelections)
 {
-	int		i;
-
 	if( pItem && pParameters )
 	{
 		switch( pItem->Get_Type() )
@@ -1125,7 +1121,7 @@ bool CWKSP_Data_Manager::_Modified_Get(CSG_Parameters *pParameters, CWKSP_Base_I
 		case WKSP_ITEM_PointCloud_Manager:
 		case WKSP_ITEM_Grid_Manager      :
 		case WKSP_ITEM_Grid_System       :
-			for(i=0; i<((CWKSP_Base_Manager *)pItem)->Get_Count(); i++)
+			for(int i=0; i<((CWKSP_Base_Manager *)pItem)->Get_Count(); i++)
 			{
 				_Modified_Get(pParameters, ((CWKSP_Base_Manager *)pItem)->Get_Item(i), Directory, bSelections && !pItem->is_Selected());
 			}
@@ -1164,7 +1160,7 @@ bool CWKSP_Data_Manager::_Modified_Get(CSG_Parameters *pParameters, CWKSP_Base_I
 	}
 
 	//-----------------------------------------------------
-	wxString	Filter, Extension;
+	wxString Filter, Extension;
 
 	switch( pItem->Get_Type() )
 	{
@@ -1174,18 +1170,20 @@ bool CWKSP_Data_Manager::_Modified_Get(CSG_Parameters *pParameters, CWKSP_Base_I
 	case WKSP_ITEM_PointCloud: Filter = DLG_Get_FILE_Filter(ID_DLG_POINTCLOUD_SAVE); Extension = "sg-pts-z"; break;
 	case WKSP_ITEM_Grid      : Filter = DLG_Get_FILE_Filter(ID_DLG_GRID_SAVE      ); Extension = SG_Grid_Get_File_Extension_Default().c_str(); break;
 	case WKSP_ITEM_Grids     : Filter = DLG_Get_FILE_Filter(ID_DLG_GRIDS_SAVE     ); Extension = "sg-gds-z"; break;
-	default:	return( false );
+	default: return( false );
 	}
 
 	//-----------------------------------------------------
-	wxFileName	Path(pObject->Get_File_Name());
+	wxFileName Path(pObject->Get_File_Name());
 
 	if( !Path.FileExists() )
 	{
-		wxString	Name(pObject->Get_Name());
+		wxString Name(pObject->Get_Name());
 
-		Name.Replace(".", "-");
-		Name.Replace(":", "-");
+		Name.Replace("." , "_");
+		Name.Replace(":" , "_");
+		Name.Replace("/" , "_");
+		Name.Replace("\\", "_");
 
 		Path.SetPath(Directory);
 		Path.SetExt (Extension);
@@ -1201,15 +1199,15 @@ bool CWKSP_Data_Manager::_Modified_Get(CSG_Parameters *pParameters, CWKSP_Base_I
 				Path.SetName(Name + wxString::Format("_%d", i));
 			}
 
-			bOkay	= !Path.FileExists();
+			bOkay = !Path.FileExists();
 
 			for(int j=0; bOkay && j<pParameters->Get_Count(); j++)
 			{
-				CSG_Parameter	*p	= pParameters->Get_Parameter(j);
+				CSG_Parameter &P = *pParameters->Get_Parameter(j);
 
-				if( p->Get_Type() == PARAMETER_TYPE_FilePath && Path == p->asString() )
+				if( P.Get_Type() == PARAMETER_TYPE_FilePath && Path == P.asString() )
 				{
-					bOkay	= false;
+					bOkay = false;
 				}
 			}
 		}
@@ -1308,7 +1306,7 @@ bool CWKSP_Data_Manager::Close(bool bSilent)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1461,7 +1459,7 @@ void CWKSP_Data_Manager::Del_Manager(CWKSP_Base_Item *pItem)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1573,7 +1571,7 @@ bool CWKSP_Data_Manager::Show_Diagram(CSG_Table *pTable, CSG_Parameters *pParame
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1757,7 +1755,7 @@ bool CWKSP_Data_Manager::MultiSelect_Update(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1823,9 +1821,9 @@ CSG_Parameters * CWKSP_Data_Manager::Get_Settings_Dialog(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
