@@ -50,6 +50,7 @@
 #include <wx/dcmemory.h>
 #include <wx/image.h>
 #include <wx/filename.h>
+#include <wx/clipbrd.h>
 
 #include <saga_gdi/sgdi_helper.h>
 
@@ -96,12 +97,12 @@ CWKSP_Grids::CWKSP_Grids(CSG_Grids *pGrids)
 //---------------------------------------------------------
 wxString CWKSP_Grids::Get_Description(void)
 {
-	wxString	s;
+	wxString s;
 
 	//-----------------------------------------------------
-	s	+= wxString::Format("<h4>%s</h4>", _TL("Grids"));
+	s += wxString::Format("<h4>%s</h4>", _TL("Grids"));
 
-	s	+= "<table border=\"0\">";
+	s += "<table border=\"0\">";
 
 	DESC_ADD_STR (_TL("Name"               ), m_pObject->Get_Name());
 	DESC_ADD_STR (_TL("Description"        ), m_pObject->Get_Description());
@@ -120,7 +121,7 @@ wxString CWKSP_Grids::Get_Description(void)
 	{
 		DESC_ADD_STR(_TL("Data Source"     ), m_pObject->Get_File_Name(false));
 
-		//	const CSG_MetaData	&DB	= m_pObject->Get_MetaData_DB();
+	//	const CSG_MetaData	&DB	= m_pObject->Get_MetaData_DB();
 	//	if( DB("DBMS") ) DESC_ADD_STR(_TL("DBMS"    ), DB["DBMS"].Get_Content().c_str());
 	//	if( DB("HOST") ) DESC_ADD_STR(_TL("Host"    ), DB["DBMS"].Get_Content().c_str());
 	//	if( DB("PORT") ) DESC_ADD_STR(_TL("Port"    ), DB["DBMS"].Get_Content().c_str());
@@ -132,7 +133,7 @@ wxString CWKSP_Grids::Get_Description(void)
 	}
 
 	DESC_ADD_STR (_TL("Modified"          ), m_pObject->is_Modified() ? _TL("yes") : _TL("no"));
-	DESC_ADD_STR (_TL("Projection"        ), m_pObject->Get_Projection().Get_Description().c_str());
+	DESC_ADD_STR (_TL("Spatial Reference" ), m_pObject->Get_Projection().Get_Description().c_str());
 	DESC_ADD_STR (_TL("West"              ), SG_Get_String(Get_Grids()->Get_XMin        (), -CSG_Grid_System::Get_Precision()).c_str());
 	DESC_ADD_STR (_TL("East"              ), SG_Get_String(Get_Grids()->Get_XMax        (), -CSG_Grid_System::Get_Precision()).c_str());
 	DESC_ADD_STR (_TL("West-East"         ), SG_Get_String(Get_Grids()->Get_XRange      (), -CSG_Grid_System::Get_Precision()).c_str());
@@ -144,20 +145,36 @@ wxString CWKSP_Grids::Get_Description(void)
 	DESC_ADD_INT (_TL("Number of Rows"    ), Get_Grids()->Get_NY          ());
 	DESC_ADD_INT (_TL("Number of Bands"   ), Get_Grids()->Get_NZ          ());
 	DESC_ADD_LONG(_TL("Number of Cells"   ), Get_Grids()->Get_NCells      ());
-	DESC_ADD_LONG(_TL("No Data Cells"     ), Get_Grids()->Get_NoData_Count());
+	DESC_ADD_STR (_TL("Memory Size"       ), Get_nBytes_asString(Get_Grids()->Get_Memory_Size(), 2).c_str());
 	DESC_ADD_STR (_TL("Z-Attribute"       ), Get_Grids()->Get_Attributes().Get_Field_Name(Get_Grids()->Get_Z_Attribute()));
 	DESC_ADD_STR (_TL("Value Type"        ), SG_Data_Type_Get_Name(Get_Grids()->Get_Type()).c_str());
-	DESC_ADD_FLT (_TL("Value Minimum"     ), Get_Grids()->Get_Min         ());
-	DESC_ADD_FLT (_TL("Value Maximum"     ), Get_Grids()->Get_Max         ());
-	DESC_ADD_FLT (_TL("Value Range"       ), Get_Grids()->Get_Range       ());
 	DESC_ADD_STR (_TL("No Data Value"     ), Get_Grids()->Get_NoData_Value() < Get_Grids()->Get_NoData_Value(true) ? CSG_String::Format("%f - %f", Get_Grids()->Get_NoData_Value(), Get_Grids()->Get_NoData_Value(true)).c_str() : SG_Get_String(Get_Grids()->Get_NoData_Value(), -2).c_str());
-	DESC_ADD_FLT (_TL("Arithmetic Mean"   ), Get_Grids()->Get_Mean        ());
-	DESC_ADD_FLT (_TL("Standard Deviation"), Get_Grids()->Get_StdDev      ());
-	DESC_ADD_STR (_TL("Memory Size"       ), Get_nBytes_asString(Get_Grids()->Get_Memory_Size(), 2).c_str());
 
-	s	+= "</table>";
+	double Samples = 100. * (double)Get_Grid()->Get_Max_Samples() / (double)Get_Grid()->Get_NCells();
 
-	s	+= Get_TableInfo_asHTML(&Get_Grids()->Get_Attributes());
+	DESC_ADD_STR (_TL("No Data Cells"     ), wxString::Format("%lld%s", Get_Grids()->Get_NoData_Count(), Samples < 100. ? " (*)" : ""));
+	DESC_ADD_STR (_TL("Value Minimum"     ), wxString::Format("%s%s", SG_Get_String(Get_Grids()->Get_Min   (), -20).c_str(), Samples < 100. ? "*" : ""));
+	DESC_ADD_STR (_TL("Value Maximum"     ), wxString::Format("%s%s", SG_Get_String(Get_Grids()->Get_Max   (), -20).c_str(), Samples < 100. ? "*" : ""));
+	DESC_ADD_STR (_TL("Value Range"       ), wxString::Format("%s%s", SG_Get_String(Get_Grids()->Get_Range (), -20).c_str(), Samples < 100. ? "*" : ""));
+	DESC_ADD_STR (_TL("Arithmetic Mean"   ), wxString::Format("%s%s", SG_Get_String(Get_Grids()->Get_Mean  (), -20).c_str(), Samples < 100. ? "*" : ""));
+	DESC_ADD_STR (_TL("Standard Deviation"), wxString::Format("%s%s", SG_Get_String(Get_Grids()->Get_StdDev(), -20).c_str(), Samples < 100. ? "*" : ""));
+
+	if( Samples < 100. )
+	{
+		DESC_ADD_STR(_TL("Sample Size"    ), wxString::Format("%lld (%.02f%%)", Get_Grids()->Get_Max_Samples(), Samples));
+	}
+
+	s += "</table>";
+
+	if( Samples < 100. )
+	{
+		s += wxString::Format("<small>*) <i>%s", _TL("Statistics are based on a subset of the data set. The sample size to be used can be changed in the settings.</i></small>"));
+	}
+
+	s += wxString::Format("<hr><h4>%s</h4>", _TL("Coordinate System Details"));
+	s += m_pObject->Get_Projection().Get_Description(true).c_str();
+
+	s += Get_TableInfo_asHTML(&Get_Grids()->Get_Attributes());
 
 	//-----------------------------------------------------
 	return( s );
@@ -761,8 +778,6 @@ void CWKSP_Grids::_LUT_Create(void)
 
 			double	Minimum, Maximum	= Get_Grids()->Get_Histogram().Get_Quantile(0.);
 
-			double	Step	= 1. / Colors.Get_Count();
-
 			for(int iClass=0; iClass<Colors.Get_Count(); iClass++)
 			{
 				Minimum	= Maximum;
@@ -978,19 +993,22 @@ bool CWKSP_Grids::_Fit_Colors(const CSG_Rect &rWorld, CSG_Data_Object *pObject,
 //---------------------------------------------------------
 bool CWKSP_Grids::asImage(CSG_Grid *pImage)
 {
-	wxBitmap	BMP;
+	wxImage Image;
 
-	if( pImage && Get_Image_Grid(BMP) )
+	if( pImage && Get_Image(Image) )
 	{
-		wxImage	IMG(BMP.ConvertToImage());
-
 		pImage->Create(Get_Grids()->Get_System(), SG_DATATYPE_Int);
 
-		for(int y=0; y<pImage->Get_NY() && PROGRESSBAR_Set_Position(y, pImage->Get_NY()); y++)
+		#pragma omp parallel for
+		for(int y=0; y<pImage->Get_NY(); y++) for(int x=0; x<pImage->Get_NX(); x++)
 		{
-			for(int x=0; x<pImage->Get_NX(); x++)
+			if( Image.HasAlpha() )
 			{
-				pImage->Set_Value(x, y, SG_GET_RGB(IMG.GetRed(x, y), IMG.GetGreen(x, y), IMG.GetBlue(x, y)));
+				pImage->Set_Value(x, y, SG_GET_RGBA(Image.GetRed(x, y), Image.GetGreen(x, y), Image.GetBlue(x, y), Image.GetAlpha(x, y)));
+			}
+			else
+			{
+				pImage->Set_Value(x, y, SG_GET_RGB (Image.GetRed(x, y), Image.GetGreen(x, y), Image.GetBlue(x, y)));
 			}
 		}
 
@@ -1001,90 +1019,100 @@ bool CWKSP_Grids::asImage(CSG_Grid *pImage)
 }
 
 //---------------------------------------------------------
-void CWKSP_Grids::_Save_Image(void)
+bool CWKSP_Grids::_Save_Image(void)
 {
-	int				type;
-	wxString		file;
-	wxBitmap		BMP;
-	CSG_File		Stream;
-	CSG_Parameters	Parms;
+	static CSG_Parameters P(NULL, _TL("Save Grid Collection as Image..."), _TL(""), SG_T(""));
 
-	//-----------------------------------------------------
-	Parms.Set_Name(_TL("Save Grid as Image..."));
-
-	Parms.Add_Bool  ("", "WORLD", _TL("Save Georeference"), _TL(""), true);
-	Parms.Add_Bool  ("", "LG"   , _TL("Legend: Save"     ), _TL(""), true);
-	Parms.Add_Double("", "LZ"   , _TL("Legend: Zoom"     ), _TL(""), 1., 0., true);
-
-	//-----------------------------------------------------
-	if( DLG_Image_Save(file, type) && DLG_Parameters(&Parms) )
+	if( P.Get_Count() == 0 )
 	{
-		if( Get_Image_Grid(BMP) )
+		P.Add_Bool  ("", "WORLD", _TL("Save Georeference"), _TL(""),  true);
+		P.Add_Bool  ("", "LG"   , _TL("Legend: Save"     ), _TL(""), false);
+		P.Add_Double("", "LZ"   , _TL("Legend: Zoom"     ), _TL(""), 1., 0., true);
+	}
+
+	//-----------------------------------------------------
+	wxString File; int Type; wxImage Image;
+
+	if( !DLG_Image_Save(File, Type) || !DLG_Parameters(&P) || !Get_Image(Image) )
+	{
+		return( false );
+	}
+
+	Image.SaveFile(File, (wxBitmapType)Type);
+
+	//-----------------------------------------------------
+	wxBitmap Bitmap;
+
+	if( P("LG")->asBool() && Get_Bitmap_Legend(Bitmap, P("LZ")->asDouble()) )
+	{
+		wxFileName fn(File); fn.SetName(wxString::Format("%s_legend", fn.GetName().c_str()));
+
+		Bitmap.SaveFile(fn.GetFullPath(), (wxBitmapType)Type);
+	}
+
+	if( P("WORLD")->asBool() )
+	{
+		wxFileName fn(File);
+
+		switch( Type )
 		{
-			BMP.SaveFile(file, (wxBitmapType)type);
+		default                : fn.SetExt("world"); break;
+		case wxBITMAP_TYPE_BMP : fn.SetExt("bpw"  ); break;
+		case wxBITMAP_TYPE_GIF : fn.SetExt("gfw"  ); break;
+		case wxBITMAP_TYPE_JPEG: fn.SetExt("jgw"  ); break;
+		case wxBITMAP_TYPE_PNG : fn.SetExt("pgw"  ); break;
+		case wxBITMAP_TYPE_PCX : fn.SetExt("pxw"  ); break;
+		case wxBITMAP_TYPE_TIF : fn.SetExt("tfw"  ); break; 
 		}
 
-		if( Parms("LG")->asBool() && Get_Image_Legend(BMP, Parms("LZ")->asDouble()) )
+		CSG_File Stream;
+
+		if( Stream.Open(fn.GetFullPath().wx_str(), SG_FILE_W, false) )
 		{
-			wxFileName	fn(file);
-			fn.SetName(wxString::Format("%s_legend", fn.GetName().c_str()));
-
-			BMP.SaveFile(fn.GetFullPath(), (wxBitmapType)type);
-		}
-
-		if( Parms("WORLD")->asBool() )
-		{
-			wxFileName	fn(file);
-
-			switch( type )
-			{
-			default                : fn.SetExt("world");	break;
-			case wxBITMAP_TYPE_BMP : fn.SetExt("bpw"  );	break;
-			case wxBITMAP_TYPE_GIF : fn.SetExt("gfw"  );	break;
-			case wxBITMAP_TYPE_JPEG: fn.SetExt("jgw"  );	break;
-			case wxBITMAP_TYPE_PNG : fn.SetExt("pgw"  );	break;
-			case wxBITMAP_TYPE_PCX : fn.SetExt("pxw"  );	break;
-			case wxBITMAP_TYPE_TIF : fn.SetExt("tfw"  );	break; 
-			}
-
-			if( Stream.Open(fn.GetFullPath().wx_str(), SG_FILE_W, false) )
-			{
-				Stream.Printf("%.10f\n%.10f\n%.10f\n%.10f\n%.10f\n%.10f\n",
-					 Get_Grids()->Get_Cellsize(), 0., 0.,
-					-Get_Grids()->Get_Cellsize(),
-					 Get_Grids()->Get_XMin(),
-					 Get_Grids()->Get_YMax()
-				);
-			}
+			Stream.Printf("%.10f\n%.10f\n%.10f\n%.10f\n%.10f\n%.10f\n",
+				 Get_Grid()->Get_Cellsize(), 0., 0.,
+				-Get_Grid()->Get_Cellsize(),
+				 Get_Grid()->Get_XMin(),
+				 Get_Grid()->Get_YMax()
+			);
 		}
 	}
+
+	return( true );
 }
 
 //---------------------------------------------------------
-bool CWKSP_Grids::Get_Image_Grid(wxBitmap &BMP, bool bFitSize)
+bool CWKSP_Grids::_Save_Image_Clipboard(void)
 {
-	if( bFitSize || (BMP.GetWidth() > 0 && BMP.GetHeight() > 0) )
+	wxBitmap Bitmap;
+
+	if( Get_Bitmap(Bitmap) && wxTheClipboard->Open() )
+	{
+		wxBitmapDataObject *pBitmap = new wxBitmapDataObject(Bitmap);
+		wxTheClipboard->SetData(pBitmap);
+		wxTheClipboard->Close();
+
+		return( true );
+	}
+
+	return( false );
+}
+
+//---------------------------------------------------------
+bool CWKSP_Grids::Get_Image(wxImage &Image, bool bFitSize, int Width, int Height)
+{
+	if( bFitSize || Width  < 1 ) { Width  = Get_Grid()->Get_NX(); }
+	if( bFitSize || Height < 1 ) { Height = Get_Grid()->Get_NY(); }
+
+	if( Width > 0 && Height > 0 && Image.Create(Width, Height) )
 	{
 		Set_Buisy_Cursor(true);
 
-		if( bFitSize )
-		{
-			BMP.Create(Get_Grids()->Get_NX(), Get_Grids()->Get_NY());
-		}
-
-		wxMemoryDC		dc;
-		wxRect			r(0, 0, BMP.GetWidth(), BMP.GetHeight());
-		CWKSP_Map_DC	dc_Map(Get_Extent(), r, 1., SG_GET_RGB(255, 255, 255));
+		CSG_Map_DC dc_Map(Get_Extent(), Image.GetSize(), 1., -1, true);
 
 		On_Draw(dc_Map, false);
 
-		dc.SelectObject(BMP);
-		dc.SetBackground(*wxWHITE_BRUSH);
-		dc.Clear();
-
-		dc_Map.Draw(dc);
-
-		dc.SelectObject(wxNullBitmap);
+		dc_Map.Get_Image(Image);
 
 		Set_Buisy_Cursor(false);
 
@@ -1095,16 +1123,39 @@ bool CWKSP_Grids::Get_Image_Grid(wxBitmap &BMP, bool bFitSize)
 }
 
 //---------------------------------------------------------
-bool CWKSP_Grids::Get_Image_Legend(wxBitmap &BMP, double Zoom)
+bool CWKSP_Grids::Get_Bitmap(wxBitmap &Bitmap, bool bFitSize, int Width, int Height)
+{
+	if( bFitSize || Width  < 1 ) { Width  = bFitSize ? Get_Grid()->Get_NX() : Bitmap.GetWidth (); }
+	if( bFitSize || Height < 1 ) { Height = bFitSize ? Get_Grid()->Get_NY() : Bitmap.GetHeight(); }
+
+	if( Width > 0 && Height > 0 && Bitmap.Create(Width, Height) )
+	{
+		Set_Buisy_Cursor(true);
+
+		CSG_Map_DC dc_Map(Get_Extent(), Bitmap.GetSize(), 1., -1, true);
+
+		On_Draw(dc_Map, false);
+
+		dc_Map.Get_Bitmap(Bitmap);
+
+		Set_Buisy_Cursor(false);
+
+		return( true );
+	}
+
+	return( false );
+}
+
+//---------------------------------------------------------
+bool CWKSP_Grids::Get_Bitmap_Legend(wxBitmap &Bitmap, double Zoom)
 {
 	if( Zoom > 0. )
 	{
-		wxMemoryDC	dc;
-		wxSize		s(Get_Legend()->Get_Size(Zoom, 1.));
+		wxMemoryDC dc; wxSize s(Get_Legend()->Get_Size(Zoom, 1.));
 
-		BMP.Create(s.GetWidth(), s.GetHeight());
+		Bitmap.Create(s.GetWidth(), s.GetHeight());
 
-		dc.SelectObject(BMP);
+		dc.SelectObject(Bitmap);
 		dc.SetBackground(*wxWHITE_BRUSH);
 		dc.Clear();
 
@@ -1124,17 +1175,17 @@ bool CWKSP_Grids::Get_Image_Legend(wxBitmap &BMP, double Zoom)
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-void CWKSP_Grids::On_Draw(CWKSP_Map_DC &dc_Map, int Flags)
+void CWKSP_Grids::On_Draw(CSG_Map_DC &dc_Map, int Flags)
 {
-	if( Get_Grid() == NULL || Get_Grids()->Get_NZ() < 1 || Get_Extent().Intersects(dc_Map.m_rWorld) == INTERSECTION_None )
+	if( Get_Grid() == NULL || Get_Grids()->Get_NZ() < 1 || Get_Extent().Intersects(dc_Map.rWorld()) == INTERSECTION_None )
 	{
 		return;
 	}
 
 	//-----------------------------------------------------
-	int	Mode = m_pClassify->Get_Mode() == CLASSIFY_OVERLAY && Get_Grid(3) ? IMG_MODE_TRANSPARENT_ALPHA : IMG_MODE_TRANSPARENT;
+	CSG_Map_DC::Mode Mode = m_pClassify->Get_Mode() == CLASSIFY_OVERLAY && Get_Grid(3) ? CSG_Map_DC::Mode::Alpha : CSG_Map_DC::Mode::Transparent;
 
-	if( !dc_Map.IMG_Draw_Begin(m_Parameters("DISPLAY_TRANSPARENCY")->asDouble() / 100., Mode) )
+	if( !dc_Map.Draw_Image_Begin(m_Parameters("DISPLAY_TRANSPARENCY")->asDouble() / 100., Mode) )
 	{
 		return;
 	}
@@ -1168,7 +1219,7 @@ void CWKSP_Grids::On_Draw(CWKSP_Map_DC &dc_Map, int Flags)
 	}
 
 	//-----------------------------------------------------
-	if(	dc_Map.m_DC2World >= Get_Grids()->Get_Cellsize() || Resampling != GRID_RESAMPLING_NearestNeighbour )
+	if(	dc_Map.DC2World() >= Get_Grids()->Get_Cellsize() || Resampling != GRID_RESAMPLING_NearestNeighbour )
 	{
 		_Draw_Grid_Nodes(dc_Map, Resampling);
 	}
@@ -1178,11 +1229,11 @@ void CWKSP_Grids::On_Draw(CWKSP_Map_DC &dc_Map, int Flags)
 	}
 
 	//-----------------------------------------------------
-	dc_Map.IMG_Draw_End();
+	dc_Map.Draw_Image_End();
 }
 
 //---------------------------------------------------------
-void CWKSP_Grids::_Draw_Grid_Nodes(CWKSP_Map_DC &dc_Map, TSG_Grid_Resampling Resampling)
+void CWKSP_Grids::_Draw_Grid_Nodes(CSG_Map_DC &dc_Map, TSG_Grid_Resampling Resampling)
 {
 	CSG_Grid	*pBands[4];
 
@@ -1200,11 +1251,11 @@ void CWKSP_Grids::_Draw_Grid_Nodes(CWKSP_Map_DC &dc_Map, TSG_Grid_Resampling Res
 	}
 
 	//-----------------------------------------------------
-	CSG_Rect	rMap(dc_Map.m_rWorld);	rMap.Intersect(Get_Grids()->Get_Extent(true));
+	CSG_Rect	rMap(dc_Map.rWorld());	rMap.Intersect(Get_Grids()->Get_Extent(true));
 
 	int	axDC	= (int)dc_Map.xWorld2DC(rMap.Get_XMin());	if( axDC < 0 )	axDC	= 0;
-	int	bxDC	= (int)dc_Map.xWorld2DC(rMap.Get_XMax());	if( bxDC >= dc_Map.m_rDC.GetWidth () )	bxDC	= dc_Map.m_rDC.GetWidth () - 1;
-	int	ayDC	= (int)dc_Map.yWorld2DC(rMap.Get_YMin());	if( ayDC >= dc_Map.m_rDC.GetHeight() )	ayDC	= dc_Map.m_rDC.GetHeight() - 1;
+	int	bxDC	= (int)dc_Map.xWorld2DC(rMap.Get_XMax());	if( bxDC >= dc_Map.rDC().GetWidth () )	bxDC	= dc_Map.rDC().GetWidth () - 1;
+	int	ayDC	= (int)dc_Map.yWorld2DC(rMap.Get_YMin());	if( ayDC >= dc_Map.rDC().GetHeight() )	ayDC	= dc_Map.rDC().GetHeight() - 1;
 	int	byDC	= (int)dc_Map.yWorld2DC(rMap.Get_YMax());	if( byDC < 0 )	byDC	= 0;
 	int	nyDC	= abs(ayDC - byDC);
 
@@ -1218,80 +1269,75 @@ void CWKSP_Grids::_Draw_Grid_Nodes(CWKSP_Map_DC &dc_Map, TSG_Grid_Resampling Res
 }
 
 //---------------------------------------------------------
-void CWKSP_Grids::_Draw_Grid_Nodes(CWKSP_Map_DC &dc_Map, TSG_Grid_Resampling Resampling, CSG_Grid *pBands[4], bool bBandWise, int yDC, int axDC, int bxDC)
+void CWKSP_Grids::_Draw_Grid_Nodes(CSG_Map_DC &dc_Map, TSG_Grid_Resampling Resampling, CSG_Grid *pBands[4], bool bBandWise, int yDC, int axDC, int bxDC)
 {
-	double	xMap	= dc_Map.xDC2World(axDC);
-	double	yMap	= dc_Map.yDC2World( yDC);
+	double xMap = dc_Map.xDC2World(axDC);
+	double yMap = dc_Map.yDC2World( yDC);
 
-	for(int xDC=axDC; xDC<=bxDC; xMap+=dc_Map.m_DC2World, xDC++)
+	for(int xDC=axDC; xDC<=bxDC; xMap+=dc_Map.DC2World(), xDC++)
 	{
 		if( m_pClassify->Get_Mode() != CLASSIFY_OVERLAY )
 		{
-			double	z;
+			double z; int c;
 
-			if( pBands[0]->Get_Value(xMap, yMap, z, Resampling, false) )
+			if( pBands[0]->Get_Value(xMap, yMap, z, Resampling, false) && m_pClassify->Get_Class_Color_byValue(z, c) )
 			{
-				int  c;
-
-				if( m_pClassify->Get_Class_Color_byValue(z, c) )
-				{
-					dc_Map.IMG_Set_Pixel(xDC, yDC, c);
-				}
+				dc_Map.Draw_Image_Pixel(xDC, yDC, c);
 			}
 		}
 		else
 		{
-			double	z[4];	bool	bOkay;
+			double z[4]; bool bOkay;
 
 			if( pBands[3] == NULL )
 			{
-				bOkay	= pBands[0]->Get_Value(xMap, yMap, z[0], Resampling, false)
-					&&    pBands[1]->Get_Value(xMap, yMap, z[1], Resampling, false)
-					&&    pBands[2]->Get_Value(xMap, yMap, z[2], Resampling, false);
-				z[3]	= 255.;
+				bOkay = pBands[0]->Get_Value(xMap, yMap, z[0], Resampling, false)
+				     && pBands[1]->Get_Value(xMap, yMap, z[1], Resampling, false)
+				     && pBands[2]->Get_Value(xMap, yMap, z[2], Resampling, false);
+				z[3]  = 255.;
 			}
 			else
 			{
-				z[3]	= (pBands[3]->Get_Value(xMap, yMap, Resampling) - m_Alpha[0]) * m_Alpha[1];
+				z[3] = (pBands[3]->Get_Value(xMap, yMap, Resampling) - m_Alpha[0]) * m_Alpha[1];
 
 				if( (bOkay = z[3] > 0.) == true )
 				{
 					if( z[3] > 255. )
 					{
-						z[3]	= 255.;
+						z[3] = 255.;
 					}
 
-					z[0]	= pBands[0]->Get_Value(xMap, yMap, Resampling);
-					z[1]	= pBands[1]->Get_Value(xMap, yMap, Resampling);
-					z[2]	= pBands[2]->Get_Value(xMap, yMap, Resampling);
+					z[0] = pBands[0]->Get_Value(xMap, yMap, Resampling);
+					z[1] = pBands[1]->Get_Value(xMap, yMap, Resampling);
+					z[2] = pBands[2]->Get_Value(xMap, yMap, Resampling);
 				}
 			}
 
 			if( bOkay )
 			{
-				BYTE c[4];	c[3] = (BYTE)z[3];
+				BYTE c[4]; c[3] = (BYTE)z[3];
 
 				for(int i=0; i<3; i++)
 				{
-					double	d	= bBandWise
+					double d = bBandWise
 						? 255. * m_Classify[i].Get_MetricToRelative(z[i])
 						: 255. * m_pClassify ->Get_MetricToRelative(z[i]);
 
 					c[i] = d < 0. ? 0 : d > 255. ? 255 : (BYTE)d;
 				}
 
-				dc_Map.IMG_Set_Pixel(xDC, yDC, *(int *)&c);
+				dc_Map.Draw_Image_Pixel(xDC, yDC, *(int *)&c);
 			}
 		}
 	}
 }
 
 //---------------------------------------------------------
-void CWKSP_Grids::_Draw_Grid_Cells(CWKSP_Map_DC &dc_Map)
+void CWKSP_Grids::_Draw_Grid_Cells(CSG_Map_DC &dc_Map)
 {
-	bool	bBandWise	= m_Parameters("OVERLAY_FIT")->asInt() != 0;	// bandwise statistics
+	bool bBandWise = m_Parameters("OVERLAY_FIT")->asInt() != 0;	// bandwise statistics
 
-	CSG_Grid	*pBands[4];
+	CSG_Grid *pBands[4];
 
 	if( m_pClassify->Get_Mode() == CLASSIFY_OVERLAY )
 	{
@@ -1307,32 +1353,32 @@ void CWKSP_Grids::_Draw_Grid_Cells(CWKSP_Map_DC &dc_Map)
 	}
 
 	//-----------------------------------------------------
-	int xa	= Get_Grids()->Get_System().Get_xWorld_to_Grid(dc_Map.m_rWorld.Get_XMin()); if( xa <  0                     ) xa = 0;
-	int	ya	= Get_Grids()->Get_System().Get_yWorld_to_Grid(dc_Map.m_rWorld.Get_YMin()); if( ya <  0                     ) ya = 0;
-	int	xb	= Get_Grids()->Get_System().Get_xWorld_to_Grid(dc_Map.m_rWorld.Get_XMax()); if( xb >= Get_Grids()->Get_NX() ) xb = Get_Grids()->Get_NX() - 1;
-	int	yb	= Get_Grids()->Get_System().Get_yWorld_to_Grid(dc_Map.m_rWorld.Get_YMax()); if( yb >= Get_Grids()->Get_NY() ) yb = Get_Grids()->Get_NY() - 1;
+	int xa = Get_Grids()->Get_System().Get_xWorld_to_Grid(dc_Map.rWorld().Get_XMin()); if( xa <  0                     ) xa = 0;
+	int ya = Get_Grids()->Get_System().Get_yWorld_to_Grid(dc_Map.rWorld().Get_YMin()); if( ya <  0                     ) ya = 0;
+	int xb = Get_Grids()->Get_System().Get_xWorld_to_Grid(dc_Map.rWorld().Get_XMax()); if( xb >= Get_Grids()->Get_NX() ) xb = Get_Grids()->Get_NX() - 1;
+	int yb = Get_Grids()->Get_System().Get_yWorld_to_Grid(dc_Map.rWorld().Get_YMax()); if( yb >= Get_Grids()->Get_NY() ) yb = Get_Grids()->Get_NY() - 1;
 
-	double	dDC  = Get_Grids()->Get_Cellsize() * dc_Map.m_World2DC;
+	double  dDC = Get_Grids()->Get_Cellsize() * dc_Map.World2DC();
 
-	double	axDC = dc_Map.xWorld2DC(Get_Grids()->Get_System().Get_xGrid_to_World(xa)) + dDC / 2.;
-	double	ayDC = dc_Map.yWorld2DC(Get_Grids()->Get_System().Get_yGrid_to_World(ya)) - dDC / 2.;
+	double axDC = dc_Map.xWorld2DC(Get_Grids()->Get_System().Get_xGrid_to_World(xa)) + dDC / 2.;
+	double ayDC = dc_Map.yWorld2DC(Get_Grids()->Get_System().Get_yGrid_to_World(ya)) - dDC / 2.;
 
 	//-----------------------------------------------------
-	double	yDC	= ayDC;
+	double  yDC = ayDC;
 
 	for(int y=ya, yaDC=(int)(ayDC), ybDC=(int)(ayDC+dDC); y<=yb; y++, ybDC=yaDC, yaDC=(int)(yDC-=dDC))
 	{
-		double	xDC	= axDC;
+		double xDC = axDC;
 
 		for(int x=xa, xaDC=(int)(axDC-dDC), xbDC=(int)(axDC); x<=xb; x++, xaDC=xbDC, xbDC=(int)(xDC+=dDC))
 		{
 			if( m_pClassify->Get_Mode() != CLASSIFY_OVERLAY )
 			{
-				int  c;
+				int c;
 
 				if( pBands[0]->is_InGrid(x, y) && m_pClassify->Get_Class_Color_byValue(pBands[0]->asDouble(x, y), c) )
 				{
-					dc_Map.IMG_Set_Rect(xaDC, yaDC, xbDC, ybDC, c);
+					dc_Map.Draw_Image_Pixels(xaDC, yaDC, xbDC, ybDC, c);
 				}
 			}
 			else if( pBands[0]->is_InGrid(x, y, !pBands[3])
@@ -1344,7 +1390,7 @@ void CWKSP_Grids::_Draw_Grid_Cells(CWKSP_Map_DC &dc_Map)
 
 				for(int i=0; i<3; i++)
 				{
-					double	d	= bBandWise
+					double d = bBandWise
 						? 255. * m_Classify[i].Get_MetricToRelative(pBands[i]->asDouble(x, y))
 						: 255. * m_pClassify ->Get_MetricToRelative(pBands[i]->asDouble(x, y));
 
@@ -1353,18 +1399,18 @@ void CWKSP_Grids::_Draw_Grid_Cells(CWKSP_Map_DC &dc_Map)
 
 				if( pBands[3] )
 				{
-					double	d	= (pBands[3]->asDouble(x, y) - m_Alpha[0]) * m_Alpha[1];
+					double d = (pBands[3]->asDouble(x, y) - m_Alpha[0]) * m_Alpha[1];
 
 					if( d > 0. )
 					{
 						c[3] = d < 255. ? (BYTE)d : 255;
 
-						dc_Map.IMG_Set_Rect(xaDC, yaDC, xbDC, ybDC, *(int *)&c);
+						dc_Map.Draw_Image_Pixels(xaDC, yaDC, xbDC, ybDC, *(int *)&c);
 					}
 				}
 				else
 				{
-					dc_Map.IMG_Set_Rect(xaDC, yaDC, xbDC, ybDC, *(int *)&c);
+					dc_Map.Draw_Image_Pixels(xaDC, yaDC, xbDC, ybDC, *(int *)&c);
 				}
 			}
 		}
