@@ -47,6 +47,7 @@
 
 //---------------------------------------------------------
 #include "res_commands.h"
+#include "res_controls.h"
 #include "res_dialogs.h"
 
 #include "saga_frame.h"
@@ -74,6 +75,7 @@
 
 #include "wksp_shapes.h"
 
+#include "view_map.h"
 #include "view_histogram.h"
 
 
@@ -123,12 +125,12 @@ CWKSP_Layer *	Get_Active_Layer(void)
 CWKSP_Layer::CWKSP_Layer(CSG_Data_Object *pObject)
 	: CWKSP_Data_Item(pObject)
 {
-	m_pClassify		= new CWKSP_Layer_Classify;
-	m_pLegend		= new CWKSP_Layer_Legend(this);
+	m_pClassify  = new CWKSP_Layer_Classify;
+	m_pLegend    = new CWKSP_Layer_Legend(this);
 
-	m_pHistogram	= NULL;
+	m_pHistogram = NULL;
 
-	m_Edit_Index	= 0;
+	m_Edit_Index = 0;
 }
 
 //---------------------------------------------------------
@@ -158,14 +160,14 @@ bool CWKSP_Layer::On_Command(int Cmd_ID)
 		return( CWKSP_Data_Item::On_Command(Cmd_ID) );
 
 	case ID_CMD_WKSP_ITEM_RETURN:
-	case ID_CMD_SHAPES_SHOW:
-	case ID_CMD_GRID_SHOW:
-	case ID_CMD_TIN_SHOW:
-	case ID_CMD_POINTCLOUD_SHOW:
+	case ID_CMD_SHAPES_SHOW     :
+	case ID_CMD_GRID_SHOW       :
+	case ID_CMD_TIN_SHOW        :
+	case ID_CMD_POINTCLOUD_SHOW :
 		g_pMaps->Add(this);
 		break;
 
-	case ID_CMD_DATA_PROJECTION:
+	case ID_CMD_DATA_PROJECTION :
 		_Set_Projection();
 		break;
 	}
@@ -332,7 +334,7 @@ void CWKSP_Layer::On_Create_Parameters(void)
 	// Classification: Classified...
 
 	m_Parameters.Add_Node("NODE_COLORS",
-		"NODE_LUT"			, _TL("Classified"),
+		"NODE_LUT"		, _TL("Classified"),
 		_TL("")
 	);
 
@@ -343,8 +345,8 @@ void CWKSP_Layer::On_Create_Parameters(void)
 		m_Parameters.Add_Choice("NODE_LUT", "LUT_ATTRIB", _TL("Attribute"), _TL(""), _TL("<default>"));
 	}
 
-	CSG_Table	*pLUT	= m_Parameters.Add_FixedTable("NODE_LUT",
-		"LUT"				, _TL("Table"),
+	CSG_Table *pLUT = m_Parameters.Add_FixedTable("NODE_LUT",
+		"LUT"			, _TL("Table"),
 		_TL("")
 	)->asTable();
 
@@ -358,6 +360,19 @@ void CWKSP_Layer::On_Create_Parameters(void)
 
 	m_pClassify->Initialise(this, pLUT, g_pData->Get_Parameter("COLORS_DEFAULT")->asColors());
 
+	if( m_pObject->Get_ObjectType() == SG_DATAOBJECT_TYPE_Grid
+	||  m_pObject->Get_ObjectType() == SG_DATAOBJECT_TYPE_Grids )
+	{
+		m_Parameters.Add_Choice("NODE_LUT", "LUT_RESAMPLING", _TL("Resampling"), _TL(""),
+			CSG_String::Format("%s|%s|%s|%s",
+				_TL("Nearest Neighbour"),
+				_TL("Bilinear Interpolation"),
+				_TL("Bicubic Spline Interpolation"),
+				_TL("B-Spline Interpolation")
+			), 0
+		);
+	}
+
 	//-----------------------------------------------------
 	// Classification: Colors...
 
@@ -425,19 +440,20 @@ void CWKSP_Layer::ColorsParms_Add(void)
 				_TL("Standard Deviation"),
 				_TL("Percent Clip"),
 				_TL("Manual")
-			), g_pData->Get_Parameter("GRID_STRETCH_DEFAULT")->asInt()
+			), g_pData->Get_Parameter("STRETCH_DEFAULT")->asInt()
 		);
 
 		m_Parameters.Add_Range("STRETCH_DEFAULT",
 			"STRETCH_LINEAR"	, _TL("Linear Percent Stretch"),
 			_TL("Linear percent stretch allows you to trim extreme values from both ends of the histogram using the percentage specified here."),
-			5., 95., 0., true, 100., true
+			g_pData->Get_Parameter("STRETCH_LINEAR.MIN")->asDouble(),
+			g_pData->Get_Parameter("STRETCH_LINEAR.MAX")->asDouble(), 0., true, 100., true
 		);
 
 		m_Parameters.Add_Double("STRETCH_DEFAULT",
 			"STRETCH_STDDEV"	, _TL("Standard Deviation"),
 			_TL(""),
-			2., 0., true
+			g_pData->Get_Parameter("STRETCH_STDDEV")->asDouble(), 0., true
 		);
 
 		m_Parameters.Add_Bool("STRETCH_STDDEV",
@@ -449,7 +465,8 @@ void CWKSP_Layer::ColorsParms_Add(void)
 		m_Parameters.Add_Range("STRETCH_DEFAULT",
 			"STRETCH_PCTL"		, _TL("Percent Clip"),
 			_TL(""),
-			2., 98., 0., true, 100., true
+			g_pData->Get_Parameter("STRETCH_PCTL.MIN")->asDouble(),
+			g_pData->Get_Parameter("STRETCH_PCTL.MAX")->asDouble(), 0., true, 100., true
 		);
 	}
 
@@ -828,26 +845,28 @@ bool CWKSP_Layer::_Set_Thumbnail(bool bRefresh)
 {
 	if( m_pObject && m_Thumbnail.IsOk() && m_Thumbnail.GetWidth() > 0 && m_Thumbnail.GetHeight() > 0 )
 	{
-		wxMemoryDC		dc;
-		wxRect			r(0, 0, m_Thumbnail.GetWidth(), m_Thumbnail.GetHeight());
-		CWKSP_Map_DC	dc_Map(Get_Extent(), r, 1., SG_GET_RGB(255, 255, 255));
+		CSG_Map_DC dc_Map(Get_Extent(), m_Thumbnail.GetSize(), 1., Get_Color_asInt(SYS_Get_Color(wxSYS_COLOUR_WINDOW)));
 
-		Draw(dc_Map, LAYER_DRAW_FLAG_NOEDITS|LAYER_DRAW_FLAG_NOLABELS|LAYER_DRAW_FLAG_THUMBNAIL);
-
-		dc.SelectObject(m_Thumbnail);
-		dc.SetBackground(*wxWHITE_BRUSH);
-		dc.Clear();
-
-		dc_Map.Draw(dc);
-
-		dc.SelectObject(wxNullBitmap);
-
-		if( bRefresh )
+		if( Draw(dc_Map, LAYER_DRAW_FLAG_NOEDITS|LAYER_DRAW_FLAG_NOLABELS|LAYER_DRAW_FLAG_THUMBNAIL) )
 		{
-			g_pData_Buttons->Refresh(false);
-		}
+			wxBitmap Bitmap;
 
-		return( true );
+			if( dc_Map.Get_Bitmap(Bitmap) )
+			{
+				wxMemoryDC dc;
+
+				dc.SelectObject(m_Thumbnail);
+				dc.DrawBitmap(Bitmap, 0, 0, false);
+				dc.SelectObject(wxNullBitmap);
+
+				if( bRefresh && g_pData_Buttons )
+				{
+					g_pData_Buttons->Refresh(false);
+				}
+
+				return( true );
+			}
+		}
 	}
 
 	return( false );
@@ -896,32 +915,14 @@ CSG_Rect CWKSP_Layer::Get_Extent(void)
 //---------------------------------------------------------
 void CWKSP_Layer::_Set_Projection(void)
 {
-	CSG_Tool	*pTool	= SG_Get_Tool_Library_Manager().Create_Tool("pj_proj4", 15, true);	// CCRS_Picker
+	CSG_Projection Projection(Get_Object()->Get_Projection());
 
-	CSG_Projection	Projection(Get_Object()->Get_Projection());
+	CSG_Tool *pTool = SG_Get_Tool_Library_Manager().Create_Tool("pj_proj4", 15, true);	// CCRS_Picker
 
-	if(	pTool
-	&&  pTool->Set_Parameter("CRS_EPSG"     , Projection.Get_Authority_ID())
-	&&  pTool->Set_Parameter("CRS_EPSG_AUTH", Projection.Get_Authority   ())
-	&&  pTool->Set_Parameter("CRS_PROJ4"    , Projection.Get_Proj4       ())
+	if(	pTool && pTool->Set_Parameter("CRS_STRING", Projection.Get_WKT())
 	&&	pTool->On_Before_Execution() && DLG_Parameters(pTool->Get_Parameters()) )
 	{
-		Projection.Destroy();
-
-		if( pTool->Get_Parameter("CRS_EPSG")->asInt() > 0 )
-		{
-			Projection.Create(
-				pTool->Get_Parameter("CRS_EPSG"     )->asInt   (),
-				pTool->Get_Parameter("CRS_EPSG_AUTH")->asString()
-			);
-		}
-		
-		if( !Projection.is_Okay() )
-		{
-			Projection.Create(
-				pTool->Get_Parameter("CRS_PROJ4")->asString(), SG_PROJ_FMT_Proj4
-			);
-		}
+		Projection.Create(pTool->Get_Parameter("CRS_WKT")->asString());
 
 		if( Projection.is_Okay() && !Projection.is_Equal(Get_Object()->Get_Projection()) )
 		{
@@ -1023,25 +1024,25 @@ bool CWKSP_Layer::do_Show(CSG_Rect const &Map_Extent, bool bIntersects)
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-bool CWKSP_Layer::Draw(CWKSP_Map_DC &dc_Map, int Flags, CSG_Data_Object *pObject)
+bool CWKSP_Layer::Draw(CSG_Map_DC &dc_Map, int Flags, CSG_Data_Object *pObject)
 {
 	if( pObject && pObject->is_Valid() && pObject->Get_ObjectType() == m_pObject->Get_ObjectType() )
 	{
-		CSG_Data_Object	*pOriginal	= m_pObject;
+		CSG_Data_Object	*pOriginal = m_pObject;
 
-		m_pObject	= pObject;
+		m_pObject = pObject;
 
 		On_Draw(dc_Map, Flags);
 
-		m_pObject	= pOriginal;
+		m_pObject = pOriginal;
 	}
 	else
 	{
 		On_Draw(dc_Map, Flags);
 	}
 
-	dc_Map.dc.SetBrush(wxNullBrush);
-	dc_Map.dc.SetPen  (wxNullPen  );
+	dc_Map.SetBrush(wxNullBrush);
+	dc_Map.SetPen  (wxNullPen  );
 
 	return( true );
 }
@@ -1062,28 +1063,22 @@ bool CWKSP_Layer::Show(CWKSP_Map *pMap)
 
 			return( true );
 		}
+
+		return( false );
 	}
-	else
+
+	//-----------------------------------------------------
+	for(int i=0; i<g_pMaps->Get_Count(); i++) // find first map that includes this layer
 	{
-		for(int i=0; i<g_pMaps->Get_Count(); i++)
+		if( g_pMaps->Get_Map(i)->Get_Map_Layer(this) != NULL )
 		{
-			if( g_pMaps->Get_Map(i)->Get_Map_Layer(this) != NULL )
-			{
-				pMap	= g_pMaps->Get_Map(i);
+			g_pMaps->Get_Map(i)->View_Show(true);
 
-				pMap->View_Show(true);
-
-				return( true );
-			}
-		}
-
-		if( g_pMaps->Add(this, NULL) )
-		{
-			return( Show((CWKSP_Map *)NULL) );
+			return( true );
 		}
 	}
 
-	return( false );
+	return( g_pMaps->Add(this, NULL) && Show((CWKSP_Map *)NULL) ); // not found? add to new map and show
 }
 
 //---------------------------------------------------------
@@ -1091,17 +1086,21 @@ bool CWKSP_Layer::Show(int Flags)
 {
 	switch( Flags )
 	{
-	case SG_UI_DATAOBJECT_SHOW:
+	case SG_UI_DATAOBJECT_SHOW_MAP:
 		return( Show((CWKSP_Map *)NULL) );
 
-	case SG_UI_DATAOBJECT_SHOW_NEW_MAP:
+	case SG_UI_DATAOBJECT_SHOW_MAP_NEW:
 		g_pMaps->Add(this, NULL);
 
-	case SG_UI_DATAOBJECT_SHOW_LAST_MAP:
+	case SG_UI_DATAOBJECT_SHOW_MAP_LAST:
 		return( Show(g_pMaps->Get_Map(g_pMaps->Get_Count() - 1)) );
+
+	case SG_UI_DATAOBJECT_SHOW_MAP_ACTIVE: {
+		CVIEW_Map *pView = (CVIEW_Map *)g_pSAGA_Frame->Get_Active_Child(ID_VIEW_MAP);
+		return( Show(pView ? pView->Get_Map() : NULL) ); }
 	}
 
-	return( true );
+	return( false );
 }
 
 //---------------------------------------------------------
