@@ -87,7 +87,7 @@ CWKSP_Map_Manager *g_pMaps = NULL;
 //---------------------------------------------------------
 CWKSP_Map_Manager::CWKSP_Map_Manager(void)
 {
-	g_pMaps = this; m_Numbering = 0;
+	g_pMaps = this; m_Numbering = 0; m_Parameters.Set_Name(_TL("Maps"));
 
 	//-----------------------------------------------------
 	m_Parameters.Add_Bool (""          , "THUMBNAILS"        , _TL("Thumbnails"     ), _TL(""), true);
@@ -128,6 +128,9 @@ CWKSP_Map_Manager::CWKSP_Map_Manager(void)
 	//-----------------------------------------------------
 	m_Parameters.Add_Node  ("NODE_DEFAULTS", "NODE_NEW_MAPS", _TL("New Maps"), _TL(""));
 
+	m_Parameters.Add_Choice("NODE_NEW_MAPS", "NAMING"       , _TL("Naming"             ), _TL(""), CSG_String::Format("\'%s\'|%s", _TL("Map"), _TL("first added layer name")));
+	m_Parameters.Add_Int   ("NAMING"       , "NAMING_LENGTH", _TL("Maximum Characters" ), _TL(""), 256, 5, true);
+	m_Parameters.Add_Color ("NODE_NEW_MAPS", "BACKGROUND"   , _TL("Background Color"   ), _TL(""), SG_COLOR_WHITE);
 	m_Parameters.Add_Bool  ("NODE_NEW_MAPS", "GOTO_NEWLAYER", _TL("Zoom to added layer"), _TL(""), false);
 	m_Parameters.Add_Bool  ("NODE_NEW_MAPS", "CRS_CHECK"    , _TL("CRS Check"          ), _TL("Perform a coordinate system compatibility check before a layer is added."), true);
 	m_Parameters.Add_Bool  ("NODE_NEW_MAPS", "SCALE_BAR"    , _TL("Scale Bar"          ), _TL(""), false);
@@ -331,7 +334,7 @@ int CWKSP_Map_Manager::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Par
 		{
 			if( pParameter->Cmp_Identifier("THUMBNAILS") )
 			{
-				if( DLG_Message_Confirm(_TL("Close now ?"), _TL("Restart SAGA to apply the changes")) )
+				if( pParameter->asBool() != m_Parameters["THUMBNAILS"].asBool() && DLG_Message_Confirm(_TL("Close now ?"), _TL("Restart SAGA to apply the changes")) )
 				{
 					m_Parameters.Assign_Values(pParameters);
 
