@@ -109,12 +109,12 @@ CWKSP_PointCloud::~CWKSP_PointCloud(void)
 //---------------------------------------------------------
 wxString CWKSP_PointCloud::Get_Description(void)
 {
-	wxString	s;
+	wxString s;
 
 	//-----------------------------------------------------
-	s	+= wxString::Format("<h4>%s</h4>", _TL("Point Cloud"));
+	s += wxString::Format("<h4>%s</h4>", _TL("Point Cloud"));
 
-	s	+= "<table border=\"0\">";
+	s += "<table border=\"0\">";
 
 	DESC_ADD_STR  (_TL("Name"            ), m_pObject->Get_Name());
 	DESC_ADD_STR  (_TL("Description"     ), m_pObject->Get_Description());
@@ -129,28 +129,31 @@ wxString CWKSP_PointCloud::Get_Description(void)
 		DESC_ADD_STR(_TL("Data Source"   ), _TL("memory"));
 	}
 
-	DESC_ADD_STR (_TL("Modified"        ), m_pObject->is_Modified() ? _TL("yes") : _TL("no"));
-	DESC_ADD_STR (_TL("Projection"      ), m_pObject->Get_Projection().Get_Description().c_str());
-	DESC_ADD_FLT (_TL("West"            ), Get_PointCloud()->Get_Extent().Get_XMin());
-	DESC_ADD_FLT (_TL("East"            ), Get_PointCloud()->Get_Extent().Get_XMax());
-	DESC_ADD_FLT (_TL("West-East"       ), Get_PointCloud()->Get_Extent().Get_XRange());
-	DESC_ADD_FLT (_TL("South"           ), Get_PointCloud()->Get_Extent().Get_YMin());
-	DESC_ADD_FLT (_TL("North"           ), Get_PointCloud()->Get_Extent().Get_YMax());
-	DESC_ADD_FLT (_TL("South-North"     ), Get_PointCloud()->Get_Extent().Get_YRange());
-	DESC_ADD_FLT (_TL("Z Minimum"       ), Get_PointCloud()->Get_ZMin());
-	DESC_ADD_FLT (_TL("Z Maximum"       ), Get_PointCloud()->Get_ZMax());
-	DESC_ADD_FLT (_TL("Z Range"         ), Get_PointCloud()->Get_ZMax() - Get_PointCloud()->Get_ZMin());
-	DESC_ADD_LONG(_TL("Number of Points"), Get_PointCloud()->Get_Count());
-	DESC_ADD_LONG(_TL("Selected"        ), Get_PointCloud()->Get_Selection_Count());
+	DESC_ADD_STR (_TL("Modified"         ), m_pObject->is_Modified() ? _TL("yes") : _TL("no"));
+	DESC_ADD_STR (_TL("Spatial Reference"), m_pObject->Get_Projection().Get_Description().c_str());
+	DESC_ADD_FLT (_TL("West"             ), Get_PointCloud()->Get_Extent().Get_XMin());
+	DESC_ADD_FLT (_TL("East"             ), Get_PointCloud()->Get_Extent().Get_XMax());
+	DESC_ADD_FLT (_TL("West-East"        ), Get_PointCloud()->Get_Extent().Get_XRange());
+	DESC_ADD_FLT (_TL("South"            ), Get_PointCloud()->Get_Extent().Get_YMin());
+	DESC_ADD_FLT (_TL("North"            ), Get_PointCloud()->Get_Extent().Get_YMax());
+	DESC_ADD_FLT (_TL("South-North"      ), Get_PointCloud()->Get_Extent().Get_YRange());
+	DESC_ADD_FLT (_TL("Z Minimum"        ), Get_PointCloud()->Get_ZMin());
+	DESC_ADD_FLT (_TL("Z Maximum"        ), Get_PointCloud()->Get_ZMax());
+	DESC_ADD_FLT (_TL("Z Range"          ), Get_PointCloud()->Get_ZMax() - Get_PointCloud()->Get_ZMin());
+	DESC_ADD_LONG(_TL("Number of Points" ), Get_PointCloud()->Get_Count());
+	DESC_ADD_LONG(_TL("Selected"         ), Get_PointCloud()->Get_Selection_Count());
 
-	s	+= "</table>";
+	s += "</table>";
 
-	s	+= Get_TableInfo_asHTML(Get_PointCloud());
+	s += wxString::Format("<hr><h4>%s</h4>", _TL("Coordinate System Details"));
+	s += m_pObject->Get_Projection().Get_Description(true).c_str();
+
+	s += Get_TableInfo_asHTML(Get_PointCloud());
 
 	//-----------------------------------------------------
-//	s	+= wxString::Format("<hr><b>%s</b><font size=\"-1\">", _TL("Data History"));
-//	s	+= Get_PointCloud()->Get_History().Get_HTML();
-//	s	+= wxString::Format("</font");
+//	s += wxString::Format("<hr><b>%s</b><font size=\"-1\">", _TL("Data History"));
+//	s += Get_PointCloud()->Get_History().Get_HTML();
+//	s += wxString::Format("</font");
 
 	//-----------------------------------------------------
 	return( s );
@@ -159,7 +162,7 @@ wxString CWKSP_PointCloud::Get_Description(void)
 //---------------------------------------------------------
 wxMenu * CWKSP_PointCloud::Get_Menu(void)
 {
-	wxMenu	*pMenu	= new wxMenu(m_pObject->Get_Name());
+	wxMenu *pMenu = new wxMenu(m_pObject->Get_Name());
 
 	CMD_Menu_Add_Item(pMenu, false, ID_CMD_WKSP_ITEM_CLOSE);
 	CMD_Menu_Add_Item(pMenu, false, ID_CMD_POINTCLOUD_SHOW);
@@ -191,7 +194,7 @@ wxMenu * CWKSP_PointCloud::Get_Menu(void)
 	pMenu->AppendSeparator();
 
 	//-----------------------------------------------------
-	wxMenu	*pSubMenu	= new wxMenu(_TL("Classification"));
+	wxMenu *pSubMenu = new wxMenu(_TL("Classification"));
 
 	CMD_Menu_Add_Item(pSubMenu	, false, ID_CMD_POINTCLOUD_RANGE_MINMAX);
 	CMD_Menu_Add_Item(pSubMenu	, false, ID_CMD_POINTCLOUD_RANGE_STDDEV150);
@@ -200,7 +203,7 @@ wxMenu * CWKSP_PointCloud::Get_Menu(void)
 	pMenu->Append(ID_CMD_WKSP_FIRST, _TL("Classification"), pSubMenu);
 
 	//-----------------------------------------------------
-	wxMenu	*pTable	= new wxMenu(_TL("Table"));
+	wxMenu *pTable = new wxMenu(_TL("Table"));
 
 	CMD_Menu_Add_Item(pTable,  true, ID_CMD_TABLE_SHOW);
 //	CMD_Menu_Add_Item(pTable,  true, ID_CMD_TABLE_DIAGRAM);
@@ -952,9 +955,9 @@ bool CWKSP_PointCloud::Edit_Set_Attributes(void)
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-void CWKSP_PointCloud::On_Draw(CWKSP_Map_DC &dc_Map, int Flags)
+void CWKSP_PointCloud::On_Draw(CSG_Map_DC &dc_Map, int Flags)
 {
-	if( Get_Extent().Intersects(dc_Map.m_rWorld) && dc_Map.IMG_Draw_Begin(m_Parameters("DISPLAY_TRANSPARENCY")->asDouble() / 100.) )
+	if( Get_Extent().Intersects(dc_Map.rWorld()) && dc_Map.Draw_Image_Begin(m_Parameters("DISPLAY_TRANSPARENCY")->asDouble() / 100.) )
 	{
 		if( (Flags & LAYER_DRAW_FLAG_THUMBNAIL) == 0 )
 		{
@@ -965,7 +968,7 @@ void CWKSP_PointCloud::On_Draw(CWKSP_Map_DC &dc_Map, int Flags)
 			_Draw_Thumbnail(dc_Map);
 		}
 
-		dc_Map.IMG_Draw_End();
+		dc_Map.Draw_Image_End();
 	}
 }
 
@@ -975,11 +978,11 @@ void CWKSP_PointCloud::On_Draw(CWKSP_Map_DC &dc_Map, int Flags)
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-inline void CWKSP_PointCloud::_Draw_Point(CWKSP_Map_DC &dc_Map, int x, int y, double z, int Color)
+inline void CWKSP_PointCloud::_Draw_Point(CSG_Map_DC &dc_Map, int x, int y, double z, int Color)
 {
 	if( m_Aggregation == 1 )	// last value
 	{
-		dc_Map.IMG_Set_Pixel(x, y, Color);
+		dc_Map.Draw_Image_Pixel(x, y, Color);
 	}
 	else if( m_Z.is_InGrid(x, y) )
 	{
@@ -988,14 +991,14 @@ inline void CWKSP_PointCloud::_Draw_Point(CWKSP_Map_DC &dc_Map, int x, int y, do
 		case 0:	// first value
 			if( m_N.asInt(x, y) == 0 )
 			{
-				dc_Map.IMG_Set_Pixel(x, y, Color);
+				dc_Map.Draw_Image_Pixel(x, y, Color);
 			}
 			break;
 
 		case 2:	// lowest z
 			if( m_N.asInt(x, y) == 0 || z < m_Z.asDouble(x, y) )
 			{
-				dc_Map.IMG_Set_Pixel(x, y, Color);
+				dc_Map.Draw_Image_Pixel(x, y, Color);
 				m_Z.Set_Value(x, y, z);
 			}
 			break;
@@ -1003,7 +1006,7 @@ inline void CWKSP_PointCloud::_Draw_Point(CWKSP_Map_DC &dc_Map, int x, int y, do
 		case 3:	// highest z
 			if( m_N.asInt(x, y) == 0 || z > m_Z.asDouble(x, y) )
 			{
-				dc_Map.IMG_Set_Pixel(x, y, Color);
+				dc_Map.Draw_Image_Pixel(x, y, Color);
 				m_Z.Set_Value(x, y, z);
 			}
 			break;
@@ -1014,7 +1017,7 @@ inline void CWKSP_PointCloud::_Draw_Point(CWKSP_Map_DC &dc_Map, int x, int y, do
 }
 
 //---------------------------------------------------------
-void CWKSP_PointCloud::_Draw_Point(CWKSP_Map_DC &dc_Map, int x, int y, double z, int Color, int Radius)
+void CWKSP_PointCloud::_Draw_Point(CSG_Map_DC &dc_Map, int x, int y, double z, int Color, int Radius)
 {
 	_Draw_Point(dc_Map, x, y, z, Color);
 
@@ -1034,14 +1037,14 @@ void CWKSP_PointCloud::_Draw_Point(CWKSP_Map_DC &dc_Map, int x, int y, double z,
 }
 
 //---------------------------------------------------------
-void CWKSP_PointCloud::_Draw_Points(CWKSP_Map_DC &dc_Map)
+void CWKSP_PointCloud::_Draw_Points(CSG_Map_DC &dc_Map)
 {
 	m_Aggregation = m_Parameters("DISPLAY_VALUE_AGGREGATE")->asInt();
 
 	if( m_Aggregation != 1 )
 	{
-		m_Z.Create(SG_DATATYPE_Double, dc_Map.m_rDC.GetWidth(), dc_Map.m_rDC.GetHeight());
-		m_N.Create(SG_DATATYPE_Int   , dc_Map.m_rDC.GetWidth(), dc_Map.m_rDC.GetHeight());
+		m_Z.Create(SG_DATATYPE_Double, dc_Map.rDC().GetWidth(), dc_Map.rDC().GetHeight());
+		m_N.Create(SG_DATATYPE_Int   , dc_Map.rDC().GetWidth(), dc_Map.rDC().GetHeight());
 	}
 
 	//-----------------------------------------------------
@@ -1057,7 +1060,7 @@ void CWKSP_PointCloud::_Draw_Points(CWKSP_Map_DC &dc_Map)
 		{
 			TSG_Point_3D Point = pPoints->Get_Point();
 
-			if( dc_Map.m_rWorld.Contains(Point.x, Point.y) )
+			if( dc_Map.rWorld().Contains(Point.x, Point.y) )
 			{
 				int x = (int)dc_Map.xWorld2DC(Point.x);
 				int y = (int)dc_Map.yWorld2DC(Point.y);
@@ -1081,11 +1084,11 @@ void CWKSP_PointCloud::_Draw_Points(CWKSP_Map_DC &dc_Map)
 }
 
 //---------------------------------------------------------
-void CWKSP_PointCloud::_Draw_Thumbnail(CWKSP_Map_DC &dc_Map)
+void CWKSP_PointCloud::_Draw_Thumbnail(CSG_Map_DC &dc_Map)
 {
 	CSG_PointCloud *pPoints = Get_PointCloud();
 
-	sLong n = 1 + (sLong)(pPoints->Get_Count() / (2 * dc_Map.m_rDC.GetWidth() * dc_Map.m_rDC.GetHeight()));
+	sLong n = 1 + (sLong)(pPoints->Get_Count() / (2 * dc_Map.rDC().GetWidth() * dc_Map.rDC().GetHeight()));
 
 	for(sLong i=0; i<pPoints->Get_Count(); i+=n)
 	{
@@ -1100,7 +1103,7 @@ void CWKSP_PointCloud::_Draw_Thumbnail(CWKSP_Map_DC &dc_Map)
 
 			int Color; m_pClassify->Get_Class_Color_byValue(pPoints->Get_Value(m_fValue), Color);
 
-			dc_Map.IMG_Set_Pixel(x, y, Color);
+			dc_Map.Draw_Image_Pixel(x, y, Color);
 		}
 	}
 }
