@@ -541,18 +541,28 @@ bool CWKSP_Shapes::_Edit_Merge(void)
 	}
 
 	//-----------------------------------------------------
-	CSG_Shape	*pMerged	= Get_Shapes()->Get_Selection(0);
+	CSG_Shape *pMerged = Get_Shapes()->Get_Selection(0);
+
+	if( pMerged->asPolygon() )
+	{
+		for(int iPart=0; iPart<pMerged->Get_Part_Count(); iPart++)
+		{
+			if( pMerged->asPolygon()->is_Lake(iPart) == pMerged->asPolygon()->is_Clockwise(iPart) ) // reverse point order?!
+			{
+				pMerged->asPolygon()->Revert_Points(iPart);
+			}
+		}
+	}
 
 	for(sLong i=1; i<Get_Shapes()->Get_Selection_Count(); i++)
 	{
-		CSG_Shape	*pShape	= Get_Shapes()->Get_Selection(i);
+		CSG_Shape *pShape = Get_Shapes()->Get_Selection(i);
 
 		for(int iPart=0, jPart=pMerged->Get_Part_Count(); iPart<pShape->Get_Part_Count(); iPart++, jPart++)
 		{
-			for(int iPoint=0; iPoint<pShape->Get_Point_Count(iPart); iPoint++)
-			{
-				pMerged->Add_Point(pShape->Get_Point(iPoint, iPart), jPart);
-			}
+			pMerged->Add_Part(pShape->Get_Part(iPart),
+				pShape->asPolygon() && pShape->asPolygon()->is_Lake(iPart) == pShape->asPolygon()->is_Clockwise(iPart) // reverse point order?!
+			);
 		}
 	}
 
@@ -672,7 +682,7 @@ bool CWKSP_Shapes::_Edit_Split(void)
 						{
 							CSG_Shape	*pSplit	= Get_Shapes()->Add_Shape(Split.Get_Shape(iSplit));
 
-							((CSG_Table_Record *)pSplit)->Assign(pSelection);
+							pSplit->Assign( pSelection, SHAPE_COPY_ATTR );
 
 							Get_Shapes()->Select(pSplit, true);
 						}
@@ -1063,7 +1073,7 @@ void CWKSP_Shapes::Edit_Shape_Draw_Move(wxDC &dc, const CSG_Rect &rWorld, const
 }
 
 //---------------------------------------------------------
-void CWKSP_Shapes::Edit_Shape_Draw(CWKSP_Map_DC &dc_Map)
+void CWKSP_Shapes::Edit_Shape_Draw(CSG_Map_DC &dc_Map)
 {
 	if( m_Edit_pShape )
 	{
@@ -1071,30 +1081,30 @@ void CWKSP_Shapes::Edit_Shape_Draw(CWKSP_Map_DC &dc_Map)
 		{
 			for(int iPoint=0; iPoint<m_Edit_pShape->Get_Point_Count(iPart); iPoint++)
 			{
-				_Edit_Shape_Draw_Point(dc_Map.dc, dc_Map.World2DC(m_Edit_pShape->Get_Point(iPoint, iPart)), false);
+				_Edit_Shape_Draw_Point(dc_Map.Get_DC(), dc_Map.World2DC(m_Edit_pShape->Get_Point(iPoint, iPart)), false);
 			}
 		}
 
 		if( m_Edit_iPart >= 0 && m_Edit_iPoint >= 0 )
 		{
-			_Edit_Shape_Draw_Point(dc_Map.dc, dc_Map.World2DC(m_Edit_pShape->Get_Point(m_Edit_iPoint, m_Edit_iPart)), true);
+			_Edit_Shape_Draw_Point(dc_Map.Get_DC(), dc_Map.World2DC(m_Edit_pShape->Get_Point(m_Edit_iPoint, m_Edit_iPart)), true);
 		}
 
 		if( m_Parameters("EDIT_SNAP_LIST")->asShapesList()->Get_Item_Count() > 0 )
 		{
 			int	iPoint	= m_Parameters("EDIT_SNAP_DIST")->asInt();
 
-			dc_Map.dc.SetBrush(wxNullBrush);
-			dc_Map.dc.SetPen  (*wxWHITE);
-			dc_Map.dc.DrawCircle(1 + iPoint, 1 + iPoint, iPoint - 1);
-			dc_Map.dc.DrawCircle(1 + iPoint, 1 + iPoint, iPoint + 1);
+			dc_Map.SetBrush(wxNullBrush);
+			dc_Map.SetPen  (*wxWHITE);
+			dc_Map.DrawCircle(1 + iPoint, 1 + iPoint, iPoint - 1);
+			dc_Map.DrawCircle(1 + iPoint, 1 + iPoint, iPoint + 1);
 
-			dc_Map.dc.SetPen  (*wxBLACK);
-			dc_Map.dc.DrawCircle(1 + iPoint, 1 + iPoint, iPoint);
+			dc_Map.SetPen  (*wxBLACK);
+			dc_Map.DrawCircle(1 + iPoint, 1 + iPoint, iPoint);
 
-			dc_Map.dc.SetBrush(*wxBLACK);
-			dc_Map.dc.SetPen  (*wxBLACK);
-			dc_Map.dc.DrawCircle(1 + iPoint, 1 + iPoint, 1);
+			dc_Map.SetBrush(*wxBLACK);
+			dc_Map.SetPen  (*wxBLACK);
+			dc_Map.DrawCircle(1 + iPoint, 1 + iPoint, 1);
 		}
 	}
 }
