@@ -72,7 +72,7 @@
 CWKSP_TIN::CWKSP_TIN(CSG_TIN *pTIN)
 	: CWKSP_Layer(pTIN)
 {
-	m_pTable	= new CWKSP_Table(pTIN);
+	m_pTable = new CWKSP_Table(pTIN);
 
 	m_Edit_Attributes.Destroy();
 	m_Edit_Attributes.Add_Field(_TL("Name" ), SG_DATATYPE_String);
@@ -98,44 +98,47 @@ CWKSP_TIN::~CWKSP_TIN(void)
 //---------------------------------------------------------
 wxString CWKSP_TIN::Get_Description(void)
 {
-	wxString	s;
+	wxString s;
 
 	//-----------------------------------------------------
-	s	+= wxString::Format("<b>%s</b><table border=\"0\">", _TL("TIN"));
+	s += wxString::Format("<b>%s</b><table border=\"0\">", _TL("TIN"));
 
-	s	+= "<table border=\"0\">";
+	s += "<table border=\"0\">";
 
-	DESC_ADD_STR(_TL("Name"            ), m_pObject->Get_Name());
-	DESC_ADD_STR(_TL("Description"     ), m_pObject->Get_Description());
+	DESC_ADD_STR(_TL("Name"              ), m_pObject->Get_Name());
+	DESC_ADD_STR(_TL("Description"       ), m_pObject->Get_Description());
 
 	if( SG_File_Exists(m_pObject->Get_File_Name(false)) )
 	{
-		DESC_ADD_STR(_TL("Data Source" ), SG_File_Get_Path(m_pObject->Get_File_Name(false)      ).c_str());
-		DESC_ADD_STR(_TL("File"        ), SG_File_Get_Name(m_pObject->Get_File_Name(false), true).c_str());
+		DESC_ADD_STR(_TL("Data Source"   ), SG_File_Get_Path(m_pObject->Get_File_Name(false)      ).c_str());
+		DESC_ADD_STR(_TL("File"          ), SG_File_Get_Name(m_pObject->Get_File_Name(false), true).c_str());
 	}
 	else
 	{
-		DESC_ADD_STR(_TL("Data Source" ), _TL("memory"));
+		DESC_ADD_STR(_TL("Data Source"   ), _TL("memory"));
 	}
 
-	DESC_ADD_STR (_TL("Modified"        ), m_pObject->is_Modified() ? _TL("yes") : _TL("no"));
-	DESC_ADD_STR (_TL("Projection"      ), m_pObject->Get_Projection().Get_Description().c_str());
-	DESC_ADD_FLT (_TL("West"            ), asTIN()->Get_Extent().Get_XMin());
-	DESC_ADD_FLT (_TL("East"            ), asTIN()->Get_Extent().Get_XMax());
-	DESC_ADD_FLT (_TL("West-East"       ), asTIN()->Get_Extent().Get_XRange());
-	DESC_ADD_FLT (_TL("South"           ), asTIN()->Get_Extent().Get_YMin());
-	DESC_ADD_FLT (_TL("North"           ), asTIN()->Get_Extent().Get_YMax());
-	DESC_ADD_FLT (_TL("South-North"     ), asTIN()->Get_Extent().Get_YRange());
-	DESC_ADD_LONG(_TL("Number of Points"), asTIN()->Get_Node_Count());
+	DESC_ADD_STR (_TL("Modified"         ), m_pObject->is_Modified() ? _TL("yes") : _TL("no"));
+	DESC_ADD_STR (_TL("Spatial Reference"), m_pObject->Get_Projection().Get_Description().c_str());
+	DESC_ADD_FLT (_TL("West"             ), asTIN()->Get_Extent().Get_XMin  ());
+	DESC_ADD_FLT (_TL("East"             ), asTIN()->Get_Extent().Get_XMax  ());
+	DESC_ADD_FLT (_TL("West-East"        ), asTIN()->Get_Extent().Get_XRange());
+	DESC_ADD_FLT (_TL("South"            ), asTIN()->Get_Extent().Get_YMin  ());
+	DESC_ADD_FLT (_TL("North"            ), asTIN()->Get_Extent().Get_YMax  ());
+	DESC_ADD_FLT (_TL("South-North"      ), asTIN()->Get_Extent().Get_YRange());
+	DESC_ADD_LONG(_TL("Number of Points" ), asTIN()->Get_Node_Count());
 
-	s	+= "</table>";
+	s += "</table>";
 
-	s	+= Get_TableInfo_asHTML(asTIN());
+	s += wxString::Format("<hr><h4>%s</h4>", _TL("Coordinate System Details"));
+	s += m_pObject->Get_Projection().Get_Description(true).c_str();
+
+	s += Get_TableInfo_asHTML(asTIN());
 
 	//-----------------------------------------------------
-//	s	+= wxString::Format(wxT("<hr><b>%s</b><font size=\"-1\">"), _TL("Data History"));
-//	s	+= asTIN()->Get_History().Get_HTML();
-//	s	+= wxString::Format(wxT("</font"));
+//	s += wxString::Format(wxT("<hr><b>%s</b><font size=\"-1\">"), _TL("Data History"));
+//	s += asTIN()->Get_History().Get_HTML();
+//	s += wxString::Format(wxT("</font"));
 
 	//-----------------------------------------------------
 	return( s );
@@ -367,9 +370,9 @@ bool CWKSP_TIN::Edit_Set_Attributes(void)
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-void CWKSP_TIN::On_Draw(CWKSP_Map_DC &dc_Map, int Flags)
+void CWKSP_TIN::On_Draw(CSG_Map_DC &dc_Map, int Flags)
 {
-	if( Get_Extent().Intersects(dc_Map.m_rWorld) != INTERSECTION_None )
+	if( Get_Extent().Intersects(dc_Map.rWorld()) != INTERSECTION_None )
 	{
 		if( m_fValue >= 0 )
 		{
@@ -394,18 +397,18 @@ void CWKSP_TIN::On_Draw(CWKSP_Map_DC &dc_Map, int Flags)
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-void CWKSP_TIN::_Draw_Points(CWKSP_Map_DC &dc_Map)
+void CWKSP_TIN::_Draw_Points(CSG_Map_DC &dc_Map)
 {
 	for(int i=0; i<asTIN()->Get_Node_Count(); i++)
 	{
 		TSG_Point_Int	Point	= dc_Map.World2DC(asTIN()->Get_Node(i)->Get_Point());
 
-		dc_Map.dc.DrawCircle(Point.x, Point.y, 5);
+		dc_Map.DrawCircle(Point.x, Point.y, 5);
 	}
 }
 
 //---------------------------------------------------------
-void CWKSP_TIN::_Draw_Edges(CWKSP_Map_DC &dc_Map)
+void CWKSP_TIN::_Draw_Edges(CSG_Map_DC &dc_Map)
 {
 	for(int i=0; i<asTIN()->Get_Edge_Count(); i++)
 	{
@@ -415,20 +418,20 @@ void CWKSP_TIN::_Draw_Edges(CWKSP_Map_DC &dc_Map)
 		Point[0]	= dc_Map.World2DC(pEdge->Get_Node(0)->Get_Point());
 		Point[1]	= dc_Map.World2DC(pEdge->Get_Node(1)->Get_Point());
 
-		dc_Map.dc.DrawLine(Point[0].x, Point[0].y, Point[1].x, Point[1].y);
+		dc_Map.DrawLine(Point[0].x, Point[0].y, Point[1].x, Point[1].y);
 	}
 }
 
 //---------------------------------------------------------
-void CWKSP_TIN::_Draw_Triangles(CWKSP_Map_DC &dc_Map)
+void CWKSP_TIN::_Draw_Triangles(CSG_Map_DC &dc_Map)
 {
-	if(	m_Parameters("DISPLAY_TRIANGES")->asBool() && dc_Map.IMG_Draw_Begin(m_Parameters("DISPLAY_TRANSPARENCY")->asDouble() / 100.) )
+	if(	m_Parameters("DISPLAY_TRIANGES")->asBool() && dc_Map.Draw_Image_Begin(m_Parameters("DISPLAY_TRANSPARENCY")->asDouble() / 100.) )
 	{
 		for(sLong iTriangle=0; iTriangle<asTIN()->Get_Triangle_Count(); iTriangle++)
 		{
 			CSG_TIN_Triangle	*pTriangle	= asTIN()->Get_Triangle(iTriangle);
 
-			if( dc_Map.m_rWorld.Intersects(pTriangle->Get_Extent()) != INTERSECTION_None )
+			if( dc_Map.rWorld().Intersects(pTriangle->Get_Extent()) != INTERSECTION_None )
 			{
 				TPoint	p[3];
 
@@ -446,7 +449,7 @@ void CWKSP_TIN::_Draw_Triangles(CWKSP_Map_DC &dc_Map)
 			}
 		}
 
-		dc_Map.IMG_Draw_End();
+		dc_Map.Draw_Image_End();
 	}
 }
 
@@ -459,10 +462,10 @@ void CWKSP_TIN::_Draw_Triangles(CWKSP_Map_DC &dc_Map)
 #define SORT_POINTS_Y(a, b)	if( p[a].y < p[b].y ) {	pp = p[a]; p[a] = p[b]; p[b] = pp;	}
 #define SORT_POINTS_X(a, b)	if( p[a].x < p[b].x ) {	pp = p[a]; p[a] = p[b]; p[b] = pp;	}
 
-#define DRAW_PIXEL(x, y, z)	if( m_pClassify->Get_Class_Color_byValue(z, Color) )	{	dc_Map.IMG_Set_Pixel(x, y, Color);	}
+#define DRAW_PIXEL(x, y, z)	if( m_pClassify->Get_Class_Color_byValue(z, Color) ) { dc_Map.Draw_Image_Pixel(x, y, Color); }
 
 //---------------------------------------------------------
-void CWKSP_TIN::_Draw_Triangle(CWKSP_Map_DC &dc_Map, TPoint p[3])
+void CWKSP_TIN::_Draw_Triangle(CSG_Map_DC &dc_Map, TPoint p[3])
 {
 	int		i, j, y, y_j, Color;
 	double	x, x_a, dx, dx_a, dy, z, z_a, dz, dz_a;
@@ -476,7 +479,7 @@ void CWKSP_TIN::_Draw_Triangle(CWKSP_Map_DC &dc_Map, TPoint p[3])
 	//-----------------------------------------------------
 	if( p[2].y == p[0].y )
 	{
-		if( p[0].y >= 0 && p[0].y < dc_Map.m_rDC.GetHeight() )
+		if( p[0].y >= 0 && p[0].y < dc_Map.rDC().GetHeight() )
 		{
 			SORT_POINTS_X(1, 0);
 			SORT_POINTS_X(2, 0);
@@ -485,7 +488,7 @@ void CWKSP_TIN::_Draw_Triangle(CWKSP_Map_DC &dc_Map, TPoint p[3])
 			//---------------------------------------------
 			if( p[2].x == p[0].x )
 			{
-				if(	p[0].x >= 0 && p[0].x < dc_Map.m_rDC.GetWidth() )
+				if(	p[0].x >= 0 && p[0].x < dc_Map.rDC().GetWidth() )
 				{
 					DRAW_PIXEL(p[0].x, p[0].y, p[0].z > p[1].z
 						? (p[0].z > p[2].z ? p[0].z : p[2].z)
@@ -504,7 +507,7 @@ void CWKSP_TIN::_Draw_Triangle(CWKSP_Map_DC &dc_Map, TPoint p[3])
 	}
 
 	//-----------------------------------------------------
-	else if( !((p[0].y < 0 && p[2].y < 0) || (p[0].y >= dc_Map.m_rDC.GetHeight() && p[2].y >= dc_Map.m_rDC.GetHeight())) )
+	else if( !((p[0].y < 0 && p[2].y < 0) || (p[0].y >= dc_Map.rDC().GetHeight() && p[2].y >= dc_Map.rDC().GetHeight())) )
 	{
 		dy		=  p[2].y - p[0].y;
 		dx_a	= (p[2].x - p[0].x) / dy;
@@ -530,9 +533,9 @@ void CWKSP_TIN::_Draw_Triangle(CWKSP_Map_DC &dc_Map, TPoint p[3])
 					z_a		 = p[0].z - p[0].y * dz_a;
 				}
 
-				if( (y_j = p[j].y) > dc_Map.m_rDC.GetHeight() )
+				if( (y_j = p[j].y) > dc_Map.rDC().GetHeight() )
 				{
-					y_j		= dc_Map.m_rDC.GetHeight();
+					y_j		= dc_Map.rDC().GetHeight();
 				}
 
 				for( ; y<y_j; y++, x+=dx, z+=dz, x_a+=dx_a, z_a+=dz_a)
@@ -552,7 +555,7 @@ void CWKSP_TIN::_Draw_Triangle(CWKSP_Map_DC &dc_Map, TPoint p[3])
 }
 
 //---------------------------------------------------------
-inline void CWKSP_TIN::_Draw_Triangle_Line(CWKSP_Map_DC &dc_Map, int xa, int xb, int y, double za, double zb)
+inline void CWKSP_TIN::_Draw_Triangle_Line(CSG_Map_DC &dc_Map, int xa, int xb, int y, double za, double zb)
 {
 	int		Color;
 	double	dz;
@@ -567,9 +570,9 @@ inline void CWKSP_TIN::_Draw_Triangle_Line(CWKSP_Map_DC &dc_Map, int xa, int xb,
 			xa	 = 0;
 		}
 
-		if( xb >= dc_Map.m_rDC.GetWidth() )
+		if( xb >= dc_Map.rDC().GetWidth() )
 		{
-			xb	= dc_Map.m_rDC.GetWidth() - 1;
+			xb	= dc_Map.rDC().GetWidth() - 1;
 		}
 
 		for(int x=xa; x<=xb; x++, za+=dz)
@@ -577,7 +580,7 @@ inline void CWKSP_TIN::_Draw_Triangle_Line(CWKSP_Map_DC &dc_Map, int xa, int xb,
 			DRAW_PIXEL(x, y, za);
 		}
 	}
-	else if( xa >= 0 && xa < dc_Map.m_rDC.GetWidth() )
+	else if( xa >= 0 && xa < dc_Map.rDC().GetWidth() )
 	{
 		DRAW_PIXEL(xa, y, za);
 	}
