@@ -600,45 +600,45 @@ CSG_String CSG_PG_Connection::Get_Field_Names(const CSG_String &Table_Name) cons
 //---------------------------------------------------------
 bool CSG_PG_Connection::Execute(const CSG_String &SQL, CSG_Table *pTable, bool bToUTF8)
 {
-	if( !is_Connected() )	{	_Error_Message(_TL("no database connection"));	return( false );	}
+	if( !is_Connected() ) { _Error_Message(_TL("no database connection")); return( false ); }
 
-	PGresult	*pResult;
+	PGresult *pResult;
 
 	if( bToUTF8 )
 	{
-		CSG_Buffer	SQL_UTF8	= SQL.to_UTF8();
+		CSG_Buffer SQL_UTF8 = SQL.to_UTF8();
 
-		pResult	= PQexec(m_pgConnection, SQL_UTF8.Get_Data());
+		pResult = PQexec(m_pgConnection, SQL_UTF8.Get_Data());
 	}
 	else
 	{
-		pResult	= PQexec(m_pgConnection, SQL);
+		pResult = PQexec(m_pgConnection, SQL);
 	}
 
-	bool	bResult;
+	bool bResult;
 
 	switch( PQresultStatus(pResult) )
 	{
 	default:
-		bResult	= false;
+		bResult = false;
 		PQclear(pResult);
 		_Error_Message(_TL("SQL execution failed"), m_pgConnection);
 		break;
 
 	case PGRES_COMMAND_OK:
-		bResult	= true;
+		bResult = true;
 		PQclear(pResult);
 		break;
 
 	case PGRES_TUPLES_OK:
 		if( pTable )
 		{
-			bResult	= _Table_Load(*pTable, pResult);
+			bResult = _Table_Load(*pTable, pResult);
 			pTable->Set_Name(_TL("Query Result"));
 		}
 		else
 		{
-			bResult	= true;
+			bResult = true;
 			PQclear(pResult);
 		}
 		break;
@@ -1162,63 +1162,29 @@ bool CSG_PG_Connection::Table_Load(CSG_Table &Table, const CSG_String &Table_Nam
 //---------------------------------------------------------
 bool CSG_PG_Connection::Table_Load(CSG_Table &Table, const CSG_String &Tables, const CSG_String &Fields, const CSG_String &Where, const CSG_String &Group, const CSG_String &Having, const CSG_String &Order, bool bDistinct, bool bVerbose)
 {
-	CSG_String	Select("SELECT");
+	CSG_String Select("SELECT");
 
-	Select	+= bDistinct ? " DISTINCT" : " ALL";
+	Select += bDistinct ? " DISTINCT " : " ALL ";
 
-	if( Fields.is_Empty() )
-	{
-		Select	+= " *";
-	}
-	else
-	{
-		Select	+= " " + Fields;
-	}
+	if( !Fields.is_Empty() ) { Select += Fields; } else { Select += "*"; }
 
-	Select	+= " FROM ";
+	Select += " FROM " + Tables;
 
-	CSG_Strings	s	= SG_String_Tokenize(Tables, ",");
-
-	for(int i=0; i<s.Get_Count(); i++)
-	{
-		s[i].Trim_Both();
-
-		if( s[i][0] != '\"')
-		{
-			s[i].Prepend("\"").Append("\"");
-		}
-
-		if( i > 0 )
-		{
-			Select	+= ",";
-		}
-
-		Select	+= s[i];
-	}
-
-	if( Where.Length() )
-	{
-		Select	+= " WHERE " + Where;
-	}
-
-	if( Group.Length() )
-	{
-		Select	+= " GROUP BY " + Group;
-
-		if( Having.Length() )
-		{
-			Select	+= " HAVING " + Having;
-		}
-	}
-
-	if( Order.Length() )
-	{
-		Select	+= " ORDER BY " + Order;
-	}
+	if( !Where .is_Empty() ) { Select += " WHERE "    + Where ; }
+	if( !Group .is_Empty() ) { Select += " GROUP BY " + Group ; }
+	if( !Having.is_Empty() ) { Select += " HAVING "   + Having; }
+	if( !Order .is_Empty() ) { Select += " ORDER BY " + Order ; }
 
 	if( bVerbose )
 	{
-		SG_UI_Msg_Add_Execution(CSG_String::Format("\n%s: '%s'", _TL("SQL Query"), Select.c_str()), false);
+		if( Select.Length() > 256 )
+		{
+			SG_UI_Msg_Add_Execution(CSG_String::Format("\n%s: '%s...'", _TL("SQL Query"), Select.Left(256).c_str()), false);
+		}
+		else
+		{
+			SG_UI_Msg_Add_Execution(CSG_String::Format("\n%s: '%s'"   , _TL("SQL Query"), Select          .c_str()), false);
+		}
 	}
 
 	if( _Table_Load(Table, Select, Table.Get_Name()) )
@@ -1287,13 +1253,14 @@ bool CSG_PG_Connection::_Shapes_Load(const CSG_String &geoTable, CSG_String &Fie
 }
 
 //---------------------------------------------------------
-bool CSG_PG_Connection::_Shapes_Load(const CSG_String &geoTable, const CSG_String &Tables, const CSG_String &Fields, const CSG_String &Where, const CSG_String &Geometry, bool bBinary, int &SRID, CSG_String &Select)
+bool CSG_PG_Connection::_Shapes_Load(const CSG_String &geoTable, const CSG_String &Geometry, bool bBinary, const CSG_String &Tables, const CSG_String &Fields, const CSG_String &Where, const CSG_String &Group, const CSG_String &Having, const CSG_String &Order, bool bDistinct, int &SRID, CSG_String &Select, bool bVerbose)
 {
 	CSG_String geoField;
 
 	if( Shapes_Geometry_Info(geoTable, &geoField, &SRID) )
 	{
-		Select.Printf("SELECT %s, ST_As%s(%s) AS %s FROM \"%s\" ",
+		Select.Printf("SELECT %s %s, ST_As%s(%s) AS %s FROM \"%s\" ",
+			bDistinct ? SG_T("DISTINCT") : SG_T("ALL"),
 			Fields.c_str(),
 			bBinary ? SG_T("Binary") : SG_T("Text"),
 			geoField.c_str(),
@@ -1301,8 +1268,16 @@ bool CSG_PG_Connection::_Shapes_Load(const CSG_String &geoTable, const CSG_Strin
 			geoTable.c_str()
 		);
 
-		if( !Tables.is_Empty() ) { Select +=       "," + Tables; }
-		if( !Where .is_Empty() ) { Select += " WHERE " + Where ; }
+		if( !Tables.is_Empty() ) { Select += ", "         + Tables; }
+		if( !Where .is_Empty() ) { Select += " WHERE "    + Where ; }
+		if( !Group .is_Empty() ) { Select += " GROUP BY " + Group ; }
+		if( !Having.is_Empty() ) { Select += " HAVING "   + Having; }
+		if( !Order .is_Empty() ) { Select += " ORDER BY " + Order ; }
+
+		if( bVerbose )
+		{
+			SG_UI_Msg_Add_Execution(CSG_String::Format("\n%s: '%s'", _TL("SQL Query"), Select.c_str()), false);
+		}
 
 		return( true );
 	}
@@ -1450,12 +1425,12 @@ bool CSG_PG_Connection::Shapes_Load(CSG_Shapes *pShapes, const CSG_String &geoTa
 }
 
 //---------------------------------------------------------
-bool CSG_PG_Connection::Shapes_Load(CSG_Shapes *pShapes, const CSG_String &Name, const CSG_String &geoTable, const CSG_String &Tables, const CSG_String &Fields, const CSG_String &Where)
+bool CSG_PG_Connection::Shapes_Load(CSG_Shapes *pShapes, const CSG_String &Name, const CSG_String &geoTable, const CSG_String &Tables, const CSG_String &Fields, const CSG_String &Where, const CSG_String &Group, const CSG_String &Having, const CSG_String &Order, bool bDistinct, bool bVerbose)
 {
 	CSG_String Select; int SRID;
 
-	return( _Shapes_Load(geoTable, Tables, Fields, Where, GEOMETRY_FIELD, has_Version(9), SRID, Select)
-		&&   Shapes_Load(pShapes, Name, Select          , GEOMETRY_FIELD, has_Version(9), SRID) );
+	return( _Shapes_Load(geoTable, GEOMETRY_FIELD, has_Version(9), Tables, Fields, Where, Group, Having, Order, bDistinct, SRID, Select, bVerbose)
+	      && Shapes_Load(pShapes, Name, Select, GEOMETRY_FIELD, has_Version(9), SRID) );
 }
 
 //---------------------------------------------------------
@@ -1523,12 +1498,12 @@ int CSG_PG_Connection::Shapes_Load(CSG_Shapes *pShapes[4], const CSG_String &geo
 }
 
 //---------------------------------------------------------
-int CSG_PG_Connection::Shapes_Load(CSG_Shapes *pShapes[4], const CSG_String &Name, const CSG_String &geoTable, const CSG_String &Tables, const CSG_String &Fields, const CSG_String &Where)
+int CSG_PG_Connection::Shapes_Load(CSG_Shapes *pShapes[4], const CSG_String &Name, const CSG_String &geoTable, const CSG_String &Tables, const CSG_String &Fields, const CSG_String &Where, const CSG_String &Group, const CSG_String &Having, const CSG_String &Order, bool bDistinct, bool bVerbose)
 {
 	CSG_String Select; int SRID;
 
-	return( _Shapes_Load(geoTable, Tables, Fields, Where, GEOMETRY_FIELD, has_Version(9), SRID, Select)
-		?    Shapes_Load(pShapes, Name, Select          , GEOMETRY_FIELD, has_Version(9), SRID) : 0 );
+	return( _Shapes_Load(geoTable, GEOMETRY_FIELD, has_Version(9), Tables, Fields, Where, Group, Having, Order, bDistinct, SRID, Select, bVerbose)
+	       ? Shapes_Load(pShapes, Name, Select, GEOMETRY_FIELD, has_Version(9), SRID) : 0 );
 }
 
 //---------------------------------------------------------
@@ -2491,34 +2466,28 @@ int CSG_PG_Tool::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter
 	{
 		CSG_Projection Projection;
 
-		if(	pParameter->Cmp_Identifier("CRS_EPSG") || pParameter->Cmp_Identifier("CRS_EPSG_AUTH") )
+		if(	pParameter->Cmp_Identifier("CRS_CODE") || pParameter->Cmp_Identifier("CRS_AUTHORITY") )
 		{
-			int Code = (*pParameters)("CRS_EPSG")->asInt();
-
-			if( Code >= 0 && !Projection.Create(Code) ) //, (*pParameters)("CRS_EPSG_AUTH")->asString()) )
-			{
-				SG_UI_Dlg_Message(_TL("Unknown Authority Code"), _TL("Warning"));
-			}
+			Projection.Create((*pParameters)("CRS_CODE")->asInt(), (*pParameters)("CRS_AUTHORITY")->asString());
 		}
 
-		if(	pParameter->Cmp_Identifier("CRS_EPSG_GEOGCS")
-		||  pParameter->Cmp_Identifier("CRS_EPSG_PROJCS") )
+		if(	pParameter->Cmp_Identifier("CRS_GEOGCS") || pParameter->Cmp_Identifier("CRS_PROJCS") )
 		{
-			int EPSG;
+			CSG_String Authority_Code;
 
-			if( pParameter->asChoice()->Get_Data(EPSG) )
+			if( pParameter->asChoice()->Get_Data(Authority_Code) )
 			{
-				Projection.Create(EPSG);
+				Projection.Create(Authority_Code);
 			}
 		}
 
 		if( Projection.is_Okay() )
 		{
-			pParameters->Set_Parameter("CRS_EPSG"     , Projection.Get_Authority_ID());
-			pParameters->Set_Parameter("CRS_EPSG_AUTH", Projection.Get_Authority   ());
+			pParameters->Set_Parameter("CRS_CODE"     , Projection.Get_Code     ());
+			pParameters->Set_Parameter("CRS_AUTHORITY", Projection.Get_Authority());
 
-			if(	!pParameter->Cmp_Identifier("CRS_EPSG_GEOGCS") ) { pParameters->Set_Parameter("CRS_EPSG_GEOGCS", 0); }
-			if(	!pParameter->Cmp_Identifier("CRS_EPSG_PROJCS") ) { pParameters->Set_Parameter("CRS_EPSG_PROJCS", 0); }
+			if(	!pParameter->Cmp_Identifier("CRS_GEOGCS") ) { pParameters->Set_Parameter("CRS_GEOGCS", 0); }
+			if(	!pParameter->Cmp_Identifier("CRS_PROJCS") ) { pParameters->Set_Parameter("CRS_PROJCS", 0); }
 		}
 	}
 
@@ -2552,24 +2521,18 @@ bool CSG_PG_Tool::Add_SRID_Picker(CSG_Parameters *pParameters)
 		pParameters = &Parameters;
 	}
 
-	if( pParameters->Get_Parameter("CRS_EPSG") )
+	if( pParameters->Get_Parameter("CRS_CODE") )
 	{
 		return( false ); // don't add twice ...
 	}
 
-	pParameters->Add_Int("", "CRS_EPSG", _TL("EPSG Code"), _TL(""), -1, -1, true);
+	pParameters->Add_Int   (""        , "CRS_CODE"     , _TL("Authority Code"), _TL(""), -1, -1, true);
+	pParameters->Add_String("CRS_CODE", "CRS_AUTHORITY", _TL("Authority"     ), _TL(""), "EPSG");
 
 	if( has_CMD() == false )
 	{
-		pParameters->Add_Choice(
-			"CRS_EPSG", "CRS_EPSG_GEOGCS", _TL("Geographic Coordinate Systems"), _TL(""),
-			CSG_String::Format("{0}<%s>|", _TL("select")) + SG_Get_Projections().Get_Names_List(SG_PROJ_TYPE_CS_Geographic)
-		);
-
-		pParameters->Add_Choice(
-			"CRS_EPSG", "CRS_EPSG_PROJCS", _TL("Projected Coordinate Systems" ), _TL(""),
-			CSG_String::Format("{0}<%s>|", _TL("select")) + SG_Get_Projections().Get_Names_List(SG_PROJ_TYPE_CS_Projected)
-		);
+		pParameters->Add_Choice("CRS_CODE", "CRS_GEOGCS", _TL("Geographic Coordinate Systems"), _TL(""), SG_Get_Projections().Get_Names_List(ESG_CRS_Type::Geographic));
+		pParameters->Add_Choice("CRS_CODE", "CRS_PROJCS", _TL("Projected Coordinate Systems" ), _TL(""), SG_Get_Projections().Get_Names_List(ESG_CRS_Type::Projection));
 	}
 
 	return( true );
@@ -2578,7 +2541,7 @@ bool CSG_PG_Tool::Add_SRID_Picker(CSG_Parameters *pParameters)
 //---------------------------------------------------------
 bool CSG_PG_Tool::Set_SRID_Picker_Enabled(CSG_Parameters *pParameters, bool bEnable)
 {
-	CSG_Parameter *pParameter = pParameters ? pParameters->Get_Parameter("CRS_EPSG") : NULL;
+	CSG_Parameter *pParameter = pParameters ? pParameters->Get_Parameter("CRS_CODE") : NULL;
 
 	if( pParameter )
 	{
@@ -2591,20 +2554,14 @@ bool CSG_PG_Tool::Set_SRID_Picker_Enabled(CSG_Parameters *pParameters, bool bEna
 }
 
 //---------------------------------------------------------
-bool CSG_PG_Tool::Set_SRID(CSG_Parameters *pParameters, int SRID)
+bool CSG_PG_Tool::Set_SRID(CSG_Parameters *pParameters, const CSG_Projection &CRS)
 {
-	CSG_Parameter *pParameter = pParameters ? pParameters->Get_Parameter("CRS_EPSG") : NULL;
-
-	if( pParameter )
+	if( pParameters )
 	{
-		CSG_Projection Projection;
+		pParameters->Set_Parameter("CRS_CODE"     , CRS.Get_Code     ());
+		pParameters->Set_Parameter("CRS_AUTHORITY", CRS.Get_Authority());
 
-		if( SG_Get_Projections().Get_Projection(Projection, SRID) )
-		{
-			pParameter->Set_Value(SRID);
-
-			return( true );
-		}
+		return( true );
 	}
 
 	return( false );
@@ -2618,7 +2575,7 @@ int CSG_PG_Tool::Get_SRID(CSG_Parameters *pParameters)
 		pParameters = &Parameters;
 	}
 
-	CSG_Parameter *pParameter = pParameters->Get_Parameter("CRS_EPSG");
+	CSG_Parameter *pParameter = pParameters->Get_Parameter("CRS_CODE");
 
 	return( pParameter ? pParameter->asInt() : -1 );
 }
