@@ -191,14 +191,14 @@ CSentinel_2_Scene_Import::CSentinel_2_Scene_Import(void)
 
 	Parameters.Add_Choice("",
 		"PROJECTION"	, _TL("Coordinate System"),
-		_TL(""),
+		_TL("If using the extent option in combination with \'Different UTM Zone\' or \'Geographic Coordinates\' extent is expected to be defined with UTM North coordinates."),
 		CSG_String::Format("%s|%s|%s|%s|%s",
+			_TL("original"),
 			_TL("UTM North"),
 			_TL("UTM South"),
-			_TL("Geographic Coordinates"),
 			_TL("Different UTM Zone"),
-			_TL("original")
-		), 4
+			_TL("Geographic Coordinates")
+		), 0
 	);
 
 	Parameters.Add_Choice("PROJECTION",
@@ -279,10 +279,10 @@ int CSentinel_2_Scene_Import::On_Parameters_Enable(CSG_Parameters *pParameters,
 
 	if( pParameter->Cmp_Identifier("PROJECTION") )
 	{
-		pParameters->Set_Enabled("RESAMPLING", pParameter->asInt() == 2 || pParameter->asInt() == 3);
+		pParameters->Set_Enabled("RESAMPLING", pParameter->asInt() == 3 || pParameter->asInt() == 4);
 		pParameters->Set_Enabled("UTM_ZONE"  , pParameter->asInt() == 3);
 		pParameters->Set_Enabled("UTM_SOUTH" , pParameter->asInt() == 3);
-		pParameters->Set_Enabled("RESOLUTION", pParameter->asInt() != 2 && pParameter->asInt() != 3);
+		pParameters->Set_Enabled("RESOLUTION", pParameter->asInt() != 3 && pParameter->asInt() != 4);
 	}
 
 	if(	pParameter->Cmp_Identifier("EXTENT") )
@@ -329,7 +329,7 @@ bool CSentinel_2_Scene_Import::On_Execute(void)
 	bool bLoadSCL = Parameters("LOAD_SCL") && Parameters("LOAD_SCL")->asBool() && bLevel2;
 	bool bLoad60m = Parameters("LOAD_60M") && Parameters("LOAD_60M")->asBool();
 
-	int Resolution = Parameters("PROJECTION")->asInt() != 2 && Parameters("PROJECTION")->asInt() != 3 ? Parameters("RESOLUTION")->asInt() : 0;
+	int Resolution = Parameters("PROJECTION")->asInt() != 3 && Parameters("PROJECTION")->asInt() != 4 ? Parameters("RESOLUTION")->asInt() : 0;
 
 	bool bMultiGrids = Parameters("MULTI2GRIDS")->asBool();
 
@@ -587,83 +587,54 @@ CSG_Grid * CSentinel_2_Scene_Import::Load_Band(const CSG_String &Path, const CSG
 		return( NULL );
 	}
 
-	pBand->Set_NoData_Value(0);	// landsat 8 pretends to use a value of 65535 (2^16 - 1)
+	pBand->Set_NoData_Value(0);
 
 	if( !pBand->Get_Projection().is_Okay() )
 	{
-		// undefined coordinate system, nothing to do be further done...
+		// undefined coordinate system, nothing that further can be done...
 	}
 
 	//-----------------------------------------------------
-	else if( Parameters("PROJECTION")->asInt() >= 4 ) // keep as it is provided
+	else if( Parameters("PROJECTION")->asInt() == 1 || Parameters("PROJECTION")->asInt() == 2 ) // UTM North/South
 	{
-		// nothing to do be further done...
-	}
+		CSG_Projection Target, Source = pBand->Get_Projection();
 
-	//-----------------------------------------------------
-	else if( Parameters("PROJECTION")->asInt() <= 1 ) // UTM North or South
-	{
-		CSG_Grid *pTmp = pBand; CSG_String Projection = pTmp->Get_Projection().Get_Proj4();
-
-		if( Projection.Find("+proj=utm") >= 0
-		&&  (  (Projection.Find("+south") >= 0 && Parameters("PROJECTION")->asInt() == 0)
-		    || (Projection.Find("+south") <  0 && Parameters("PROJECTION")->asInt() == 1))
-		&&  (pBand = SG_Create_Grid(pTmp->Get_Type(), pTmp->Get_NX(), pTmp->Get_NY(), pTmp->Get_Cellsize(),
-				pTmp->Get_XMin(), pTmp->Get_YMin() + (Parameters("PROJECTION")->asInt() == 1 ? 10000000 : -10000000)
-			)) != NULL )
+		if( Source.Get_PROJ().Find("+proj=utm") >= 0 && Source.Get_PROJ().Find("+zone") >= 0 )
 		{
-			if( Parameters("PROJECTION")->asInt() == 1 )
-				Projection.Append (" +south");
-			else
-				Projection.Replace(" +south", "");
+			CSG_String Zone = Source.Get_PROJ().Right(Source.Get_PROJ().Length() - Source.Get_PROJ().Find("+zone")).AfterFirst('=');
 
-			pBand->Get_Projection().Create(Projection, SG_PROJ_FMT_Proj4);
-
-			pBand->Set_Name              (pTmp->Get_Name());
-			pBand->Set_Description       (pTmp->Get_Description());
-			pBand->Set_NoData_Value_Range(pTmp->Get_NoData_Value(), pTmp->Get_NoData_Value(true));
-			pBand->Set_Scaling           (pTmp->Get_Scaling(), pTmp->Get_Offset());
-
-			#pragma omp parallel for
-			for(int y=0; y<pBand->Get_NY(); y++) for(int x=0; x<pBand->Get_NX(); x++)
+			if( Target.Set_UTM_WGS84(Zone.asInt(), Parameters("PROJECTION")->asInt() == 2) && Target != Source
+			&& ((Parameters("PROJECTION")->asInt() == 1 && Source.Get_PROJ().Find("+south") >= 0)
+			 || (Parameters("PROJECTION")->asInt() == 2 && Source.Get_PROJ().Find("+south") <  0) ) )
 			{
-				pBand->Set_Value(x, y, pTmp->asDouble(x, y));
+				CSG_Grid *pTmp = pBand; pBand = SG_Create_Grid(pTmp->Get_Type(), pTmp->Get_NX(), pTmp->Get_NY(), pTmp->Get_Cellsize(), pTmp->Get_XMin(),
+					pTmp->Get_YMin() + (Parameters("PROJECTION")->asInt() == 1 ? -10000000 : 10000000)
+				);
+
+				if( pBand )
+				{
+					pBand->Get_Projection().Create(Target);
+					pBand->Set_Name              (pTmp->Get_Name());
+					pBand->Set_Description       (pTmp->Get_Description());
+					pBand->Set_NoData_Value_Range(pTmp->Get_NoData_Value(), pTmp->Get_NoData_Value(true));
+					pBand->Set_Scaling           (pTmp->Get_Scaling(), pTmp->Get_Offset());
+
+					#pragma omp parallel for
+					for(int y=0; y<pBand->Get_NY(); y++) for(int x=0; x<pBand->Get_NX(); x++)
+					{
+						pBand->Set_Value(x, y, pTmp->asDouble(x, y));
+					}
+
+					delete(pTmp);
+				}
 			}
-
-			delete(pTmp);
-		}
-	}
-
-	//-----------------------------------------------------
-	else if( Parameters("PROJECTION")->asInt() == 2 )	// Geographic Coordinates
-	{
-		CSG_Tool *pTool = SG_Get_Tool_Library_Manager().Create_Tool("pj_proj4", 4);	// Coordinate Transformation (Grid)
-
-		if(	pTool )
-		{
-			Message_Fmt("\n%s (%s: %s)\n", _TL("re-projection to geographic coordinates"), _TL("original"), pBand->Get_Projection().Get_Name().c_str());
-
-			pTool->Set_Manager(NULL);
-
-			if( pTool->Set_Parameter("CRS_PROJ4" , SG_T("+proj=longlat +ellps=WGS84 +datum=WGS84"))
-			&&  pTool->Set_Parameter("SOURCE"    , pBand)
-			&&  pTool->Set_Parameter("RESAMPLING", Parameters("RESAMPLING"))
-		//	&&  pTool->Set_Parameter("DATA_TYPE" , 10) // "Preserve" => is already default!
-			&&  pTool->Execute() )
-			{
-				delete(pBand);
-
-				pBand = pTool->Get_Parameters()->Get_Parameter("GRID")->asGrid();
-			}
-
-			SG_Get_Tool_Library_Manager().Delete_Tool(pTool);
 		}
 	}
 
 	//-----------------------------------------------------
 	else if( Parameters("PROJECTION")->asInt() == 3 )	// Different UTM Zone
 	{
-		CSG_Projection Projection = CSG_Projections::Get_UTM_WGS84(
+		CSG_Projection Projection = CSG_Projection::Get_UTM_WGS84(
 			Parameters("UTM_ZONE" )->asInt (),
 			Parameters("UTM_SOUTH")->asBool()
 		);
@@ -674,11 +645,11 @@ CSG_Grid * CSentinel_2_Scene_Import::Load_Band(const CSG_String &Path, const CSG
 
 			if(	pTool )
 			{
-				Message_Fmt("\n%s (%s: %s >> %s)\n", _TL("re-projection to different UTM Zone"), _TL("original"), pBand->Get_Projection().Get_Proj4().c_str(), Projection.Get_Proj4().c_str());
+				Message_Fmt("\n%s (%s: %s >> %s)\n", _TL("re-projection to different UTM Zone"), _TL("original"), pBand->Get_Projection().Get_PROJ().c_str(), Projection.Get_PROJ().c_str());
 
 				pTool->Set_Manager(NULL);
 
-				if( pTool->Set_Parameter("CRS_PROJ4"       , Projection.Get_Proj4())
+				if( pTool->Set_Parameter("CRS_STRING"      , Projection.Get_WKT())
 				&&  pTool->Set_Parameter("SOURCE"          , pBand)
 				&&  pTool->Set_Parameter("RESAMPLING"      , Parameters("RESAMPLING"))
 			//	&&  pTool->Set_Parameter("DATA_TYPE"       , 10) // "Preserve" => is already default!
@@ -696,6 +667,34 @@ CSG_Grid * CSentinel_2_Scene_Import::Load_Band(const CSG_String &Path, const CSG
 	}
 
 	//-----------------------------------------------------
+	else if( Parameters("PROJECTION")->asInt() == 4 )	// Geographic Coordinates
+	{
+		CSG_Tool *pTool = SG_Get_Tool_Library_Manager().Create_Tool("pj_proj4", 4);	// Coordinate Transformation (Grid)
+
+		if(	pTool )
+		{
+			Message_Fmt("\n%s (%s: %s)\n", _TL("re-projection to geographic coordinates"), _TL("original"), pBand->Get_Projection().Get_Name().c_str());
+
+			pTool->Set_Manager(NULL);
+
+			if( pTool->Set_Parameter("CRS_STRING", CSG_Projection::Get_GCS_WGS84().Get_WKT())
+			&&  pTool->Set_Parameter("SOURCE"    , pBand)
+			&&  pTool->Set_Parameter("RESAMPLING", Parameters("RESAMPLING"))
+		//	&&  pTool->Set_Parameter("DATA_TYPE" , 10) // "Preserve" => is already default!
+			&&  pTool->Execute() )
+			{
+				delete(pBand);
+
+				pBand = pTool->Get_Parameters()->Get_Parameter("GRID")->asGrid();
+			}
+
+			SG_Get_Tool_Library_Manager().Delete_Tool(pTool);
+		}
+	}
+
+	//-----------------------------------------------------
+	pBand->Set_File_Name("");
+
 	return( pBand );
 }
 
@@ -730,8 +729,7 @@ CSG_Grid * CSentinel_2_Scene_Import::Load_Grid(const CSG_String &File)
 	}
 
 	//-----------------------------------------------------
-	CSG_Grid *pGrid = NULL;
-	CSG_Tool *pTool = SG_Get_Tool_Library_Manager().Create_Tool("io_gdal", 0);	// Import Raster
+	CSG_Grid *pGrid = NULL; CSG_Tool *pTool = SG_Get_Tool_Library_Manager().Create_Tool("io_gdal", 0);	// Import Raster
 
 	if( pTool && pTool->Set_Manager(NULL)
 	&&  pTool->Set_Parameter("FILES"      , File)
