@@ -401,7 +401,7 @@ bool COverland_Flow::Initialize(void)
 		DataObject_Set_Colors(m_pVelocity , Colors);
 	}
 
-	DataObject_Update(m_pFlow, SG_UI_DATAOBJECT_SHOW);	// show in new map
+	DataObject_Update(m_pFlow, SG_UI_DATAOBJECT_SHOW_MAP);	// show in new map
 
 	//-----------------------------------------------------
 	m_Flow.Create(Get_System()       , SG_DATATYPE_Float);
@@ -543,7 +543,7 @@ bool COverland_Flow::Do_Time_Step(void)
 	//-----------------------------------------------------
 	if( m_vMax > 0. )
 	{
-		m_dTime	= Parameters("TIME_STEP")->asDouble() * Get_Cellsize() / m_vMax;	// CourantFriedrichsLewy (CFL) condition
+		m_dTime	= Parameters("TIME_STEP")->asDouble() * Get_Cellsize() / m_vMax;	// Courant–Friedrichs–Lewy (CFL) condition
 
 		#pragma omp parallel for
 		for(int y=0; y<Get_NY(); y++) for(int x=0; x<Get_NX(); x++)
