@@ -1,3 +1,4 @@
+
 ///////////////////////////////////////////////////////////
 //                                                       //
 //                         SAGA                          //
@@ -53,9 +54,9 @@
 		SG_T("online")\
 	);\
 \
-	Add_Reference("Martnez lvarez, V.; Dal-R Tenreiro, R.; Garca Garca, A. I.; Ayuga Tllez, F.", "",\
-		"Modelacin distribuida de la escorrenta superficial en pequeas cuencas mediante SIG",\
-		"Evaluacin experimental."\
+	Add_Reference("Martínez Álvarez, V.; Dal-Ré Tenreiro, R.; García García, A. I.; Ayuga Téllez, F.", "",\
+		"Modelación distribuida de la escorrentía superficial en pequeñas cuencas mediante SIG",\
+		"Evaluación experimental."\
 	);\
 \
 	Add_Reference("Olaya, V.", "2004",\
@@ -135,7 +136,7 @@ bool CIsochronesVar_Tool_Interactive::On_Execute_Position(CSG_Point ptWorld, TSG
     m_Calculator.Calculate(iX, iY);
 	
 
-	DataObject_Update(Parameters("TIME")->asGrid(), SG_UI_DATAOBJECT_SHOW_LAST_MAP);
+	DataObject_Update(Parameters("TIME")->asGrid(), SG_UI_DATAOBJECT_SHOW_MAP_ACTIVE);
 
 	return( true );
 }
@@ -197,7 +198,7 @@ bool CIsochronesVar_Tool::On_Execute(void)
             return (false);
         }
 
-        TSG_Point p = pPoint->Get_Shape(0)->Get_Point(0);
+        TSG_Point p = pPoint->Get_Shape(0)->Get_Point();
 
         iX = Parameters("DEM")->asGrid()->Get_System().Get_xWorld_to_Grid(p.x);
         iY = Parameters("DEM")->asGrid()->Get_System().Get_yWorld_to_Grid(p.y);
@@ -560,7 +561,7 @@ double CIsochronesVar::Runoff(double dRainfall, double dCN)
     dS = (25400.0 / dCN) - 254;
 
     if (dRainfall < (0.2 * dS)) {
-        return 0.1; //cant be 0, because that would mean speed = 0
+        return 0.1; //can´t be 0, because that would mean speed = 0
     }// if
 
     dRunoff = pow(dRainfall - 0.2 * dS, 2)
