@@ -1088,6 +1088,10 @@ protected:
 		{
 		default: CSG_3DView_Dialog::On_Menu(event); return;
 
+		#ifdef __WXMAC__
+		case MENU_PROPERTIES: if( SG_UI_Dlg_Parameters(&m_pPanel->Get_Parameters(), "") ) { m_pPanel->Set_Parameters(); } return;
+		#endif
+
 		case MENU_USAGE       : SG_UI_Dlg_Info(C3D_Viewer_Grids_Panel::Get_Usage(), _TL("Usage")); return;
 
 		case MENU_SCALE_Z_DEC : pPanel->Inc_ZScale(-0.5); break;
