@@ -648,6 +648,10 @@ void C3D_Viewer_Scatterplot_Dialog::On_Menu(wxCommandEvent &event)
 	{
 	default: CSG_3DView_Dialog::On_Menu(event); break;
 
+	#ifdef __WXMAC__
+	case MENU_PROPERTIES: if( SG_UI_Dlg_Parameters(&m_pPanel->Get_Parameters(), "") ) { m_pPanel->Set_Parameters(); } return;
+	#endif
+
 	case MENU_USAGE         : SG_UI_Dlg_Info(C3D_Viewer_Scatterplot_Panel::Get_Usage(), _TL("Usage")); return;
 
 	case MENU_SCALE_Z_DEC   : m_pPanel->Parameter_Value_Add("Z_SCALE"   , -0.5); break;
